/*******************************************************************************
* File Name: CLKGEN1.c
* Version 2.50
*
* Description:
*  This file provides all API functionality of the SPI Master component.
*
* Note:
*  None.
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CLKGEN1_PVT.h"

#if(CLKGEN1_TX_SOFTWARE_BUF_ENABLED)
    volatile uint8 CLKGEN1_txBuffer[CLKGEN1_TX_BUFFER_SIZE];
    volatile uint8 CLKGEN1_txBufferFull;
    volatile uint8 CLKGEN1_txBufferRead;
    volatile uint8 CLKGEN1_txBufferWrite;
#endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED) */

#if(CLKGEN1_RX_SOFTWARE_BUF_ENABLED)
    volatile uint8 CLKGEN1_rxBuffer[CLKGEN1_RX_BUFFER_SIZE];
    volatile uint8 CLKGEN1_rxBufferFull;
    volatile uint8 CLKGEN1_rxBufferRead;
    volatile uint8 CLKGEN1_rxBufferWrite;
#endif /* (CLKGEN1_RX_SOFTWARE_BUF_ENABLED) */

uint8 CLKGEN1_initVar = 0u;

volatile uint8 CLKGEN1_swStatusTx;
volatile uint8 CLKGEN1_swStatusRx;


/*******************************************************************************
* Function Name: CLKGEN1_Init
********************************************************************************
*
* Summary:
*  Inits/Restores default SPIM configuration provided with customizer.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Side Effects:
*  When this function is called it initializes all of the necessary parameters
*  for execution. i.e. setting the initial interrupt mask, configuring the
*  interrupt service routine, configuring the bit-counter parameters and
*  clearing the FIFO and Status Register.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN1_Init(void) 
{
    /* Initialize the Bit counter */
    CLKGEN1_COUNTER_PERIOD_REG = CLKGEN1_BITCTR_INIT;

    /* Init TX ISR  */
    #if(0u != CLKGEN1_INTERNAL_TX_INT_ENABLED)
        CyIntDisable         (CLKGEN1_TX_ISR_NUMBER);
        CyIntSetPriority     (CLKGEN1_TX_ISR_NUMBER,  CLKGEN1_TX_ISR_PRIORITY);
        (void) CyIntSetVector(CLKGEN1_TX_ISR_NUMBER, &CLKGEN1_TX_ISR);
    #endif /* (0u != CLKGEN1_INTERNAL_TX_INT_ENABLED) */

    /* Init RX ISR  */
    #if(0u != CLKGEN1_INTERNAL_RX_INT_ENABLED)
        CyIntDisable         (CLKGEN1_RX_ISR_NUMBER);
        CyIntSetPriority     (CLKGEN1_RX_ISR_NUMBER,  CLKGEN1_RX_ISR_PRIORITY);
        (void) CyIntSetVector(CLKGEN1_RX_ISR_NUMBER, &CLKGEN1_RX_ISR);
    #endif /* (0u != CLKGEN1_INTERNAL_RX_INT_ENABLED) */

    /* Clear any stray data from the RX and TX FIFO */
    CLKGEN1_ClearFIFO();

    #if(CLKGEN1_RX_SOFTWARE_BUF_ENABLED)
        CLKGEN1_rxBufferFull  = 0u;
        CLKGEN1_rxBufferRead  = 0u;
        CLKGEN1_rxBufferWrite = 0u;
    #endif /* (CLKGEN1_RX_SOFTWARE_BUF_ENABLED) */

    #if(CLKGEN1_TX_SOFTWARE_BUF_ENABLED)
        CLKGEN1_txBufferFull  = 0u;
        CLKGEN1_txBufferRead  = 0u;
        CLKGEN1_txBufferWrite = 0u;
    #endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED) */

    (void) CLKGEN1_ReadTxStatus(); /* Clear Tx status and swStatusTx */
    (void) CLKGEN1_ReadRxStatus(); /* Clear Rx status and swStatusRx */

    /* Configure TX and RX interrupt mask */
    CLKGEN1_TX_STATUS_MASK_REG = CLKGEN1_TX_INIT_INTERRUPTS_MASK;
    CLKGEN1_RX_STATUS_MASK_REG = CLKGEN1_RX_INIT_INTERRUPTS_MASK;
}


/*******************************************************************************
* Function Name: CLKGEN1_Enable
********************************************************************************
*
* Summary:
*  Enable SPIM component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CLKGEN1_Enable(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    CLKGEN1_COUNTER_CONTROL_REG |= CLKGEN1_CNTR_ENABLE;
    CLKGEN1_TX_STATUS_ACTL_REG  |= CLKGEN1_INT_ENABLE;
    CLKGEN1_RX_STATUS_ACTL_REG  |= CLKGEN1_INT_ENABLE;
    CyExitCriticalSection(enableInterrupts);

    #if(0u != CLKGEN1_INTERNAL_CLOCK)
        CLKGEN1_IntClock_Enable();
    #endif /* (0u != CLKGEN1_INTERNAL_CLOCK) */

    CLKGEN1_EnableTxInt();
    CLKGEN1_EnableRxInt();
}


/*******************************************************************************
* Function Name: CLKGEN1_Start
********************************************************************************
*
* Summary:
*  Initialize and Enable the SPI Master component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  CLKGEN1_initVar - used to check initial configuration, modified on
*  first function call.
*
* Theory:
*  Enable the clock input to enable operation.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN1_Start(void) 
{
    if(0u == CLKGEN1_initVar)
    {
        CLKGEN1_Init();
        CLKGEN1_initVar = 1u;
    }

    CLKGEN1_Enable();
}


/*******************************************************************************
* Function Name: CLKGEN1_Stop
********************************************************************************
*
* Summary:
*  Disable the SPI Master component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the clock input to enable operation.
*
*******************************************************************************/
void CLKGEN1_Stop(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    CLKGEN1_TX_STATUS_ACTL_REG &= ((uint8) ~CLKGEN1_INT_ENABLE);
    CLKGEN1_RX_STATUS_ACTL_REG &= ((uint8) ~CLKGEN1_INT_ENABLE);
    CyExitCriticalSection(enableInterrupts);

    #if(0u != CLKGEN1_INTERNAL_CLOCK)
        CLKGEN1_IntClock_Disable();
    #endif /* (0u != CLKGEN1_INTERNAL_CLOCK) */

    CLKGEN1_DisableTxInt();
    CLKGEN1_DisableRxInt();
}


/*******************************************************************************
* Function Name: CLKGEN1_EnableTxInt
********************************************************************************
*
* Summary:
*  Enable internal Tx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal Tx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN1_EnableTxInt(void) 
{
    #if(0u != CLKGEN1_INTERNAL_TX_INT_ENABLED)
        CyIntEnable(CLKGEN1_TX_ISR_NUMBER);
    #endif /* (0u != CLKGEN1_INTERNAL_TX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN1_EnableRxInt
********************************************************************************
*
* Summary:
*  Enable internal Rx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal Rx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN1_EnableRxInt(void) 
{
    #if(0u != CLKGEN1_INTERNAL_RX_INT_ENABLED)
        CyIntEnable(CLKGEN1_RX_ISR_NUMBER);
    #endif /* (0u != CLKGEN1_INTERNAL_RX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN1_DisableTxInt
********************************************************************************
*
* Summary:
*  Disable internal Tx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal Tx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN1_DisableTxInt(void) 
{
    #if(0u != CLKGEN1_INTERNAL_TX_INT_ENABLED)
        CyIntDisable(CLKGEN1_TX_ISR_NUMBER);
    #endif /* (0u != CLKGEN1_INTERNAL_TX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN1_DisableRxInt
********************************************************************************
*
* Summary:
*  Disable internal Rx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal Rx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN1_DisableRxInt(void) 
{
    #if(0u != CLKGEN1_INTERNAL_RX_INT_ENABLED)
        CyIntDisable(CLKGEN1_RX_ISR_NUMBER);
    #endif /* (0u != CLKGEN1_INTERNAL_RX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN1_SetTxInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void CLKGEN1_SetTxInterruptMode(uint8 intSrc) 
{
    CLKGEN1_TX_STATUS_MASK_REG = intSrc;
}


/*******************************************************************************
* Function Name: CLKGEN1_SetRxInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void CLKGEN1_SetRxInterruptMode(uint8 intSrc) 
{
    CLKGEN1_RX_STATUS_MASK_REG  = intSrc;
}


/*******************************************************************************
* Function Name: CLKGEN1_ReadTxStatus
********************************************************************************
*
* Summary:
*  Read the Tx status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the Tx status register.
*
* Global variables:
*  CLKGEN1_swStatusTx - used to store in software status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the Tx status register for error
*  detection and flow control.
*
* Side Effects:
*  Clear Tx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 CLKGEN1_ReadTxStatus(void) 
{
    uint8 tmpStatus;

    #if(CLKGEN1_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        CLKGEN1_DisableTxInt();

        tmpStatus = CLKGEN1_GET_STATUS_TX(CLKGEN1_swStatusTx);
        CLKGEN1_swStatusTx = 0u;

        CLKGEN1_EnableTxInt();

    #else

        tmpStatus = CLKGEN1_TX_STATUS_REG;

    #endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/*******************************************************************************
* Function Name: CLKGEN1_ReadRxStatus
********************************************************************************
*
* Summary:
*  Read the Rx status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the Rx status register.
*
* Global variables:
*  CLKGEN1_swStatusRx - used to store in software Rx status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the Rx status register for error
*  detection and flow control.
*
* Side Effects:
*  Clear Rx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 CLKGEN1_ReadRxStatus(void) 
{
    uint8 tmpStatus;

    #if(CLKGEN1_RX_SOFTWARE_BUF_ENABLED)
        /* Disable RX interrupt to protect global veriables */
        CLKGEN1_DisableRxInt();

        tmpStatus = CLKGEN1_GET_STATUS_RX(CLKGEN1_swStatusRx);
        CLKGEN1_swStatusRx = 0u;

        CLKGEN1_EnableRxInt();

    #else

        tmpStatus = CLKGEN1_RX_STATUS_REG;

    #endif /* (CLKGEN1_RX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/*******************************************************************************
* Function Name: CLKGEN1_WriteTxData
********************************************************************************
*
* Summary:
*  Write a byte of data to be sent across the SPI.
*
* Parameters:
*  txDataByte: The data value to send across the SPI.
*
* Return:
*  None.
*
* Global variables:
*  CLKGEN1_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer, modified every function
*  call if TX Software Buffer is used.
*  CLKGEN1_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer.
*  CLKGEN1_txBuffer[CLKGEN1_TX_BUFFER_SIZE] - used to store
*  data to sending, modified every function call if TX Software Buffer is used.
*
* Theory:
*  Allows the user to transmit any byte of data in a single transfer.
*
* Side Effects:
*  If this function is called again before the previous byte is finished then
*  the next byte will be appended to the transfer with no time between
*  the byte transfers. Clear Tx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN1_WriteTxData(uint8 txData) 
{
    #if(CLKGEN1_TX_SOFTWARE_BUF_ENABLED)

        uint8 tempStatus;
        uint8 tmpTxBufferRead;

        /* Block if TX buffer is FULL: don't overwrite */
        do
        {
            tmpTxBufferRead = CLKGEN1_txBufferRead;
            if(0u == tmpTxBufferRead)
            {
                tmpTxBufferRead = (CLKGEN1_TX_BUFFER_SIZE - 1u);
            }
            else
            {
                tmpTxBufferRead--;
            }

        }while(tmpTxBufferRead == CLKGEN1_txBufferWrite);

        /* Disable TX interrupt to protect global veriables */
        CLKGEN1_DisableTxInt();

        tempStatus = CLKGEN1_GET_STATUS_TX(CLKGEN1_swStatusTx);
        CLKGEN1_swStatusTx = tempStatus;


        if((CLKGEN1_txBufferRead == CLKGEN1_txBufferWrite) &&
           (0u != (CLKGEN1_swStatusTx & CLKGEN1_STS_TX_FIFO_NOT_FULL)))
        {
            /* Put data element into the TX FIFO */
            CY_SET_REG8(CLKGEN1_TXDATA_PTR, txData);
        }
        else
        {
            /* Add to the TX software buffer */
            CLKGEN1_txBufferWrite++;
            if(CLKGEN1_txBufferWrite >= CLKGEN1_TX_BUFFER_SIZE)
            {
                CLKGEN1_txBufferWrite = 0u;
            }

            if(CLKGEN1_txBufferWrite == CLKGEN1_txBufferRead)
            {
                CLKGEN1_txBufferRead++;
                if(CLKGEN1_txBufferRead >= CLKGEN1_TX_BUFFER_SIZE)
                {
                    CLKGEN1_txBufferRead = 0u;
                }
                CLKGEN1_txBufferFull = 1u;
            }

            CLKGEN1_txBuffer[CLKGEN1_txBufferWrite] = txData;

            CLKGEN1_TX_STATUS_MASK_REG |= CLKGEN1_STS_TX_FIFO_NOT_FULL;
        }

        CLKGEN1_EnableTxInt();

    #else
        /* Wait until TX FIFO has a place */
        while(0u == (CLKGEN1_TX_STATUS_REG & CLKGEN1_STS_TX_FIFO_NOT_FULL))
        {
        }

        /* Put data element into the TX FIFO */
        CY_SET_REG8(CLKGEN1_TXDATA_PTR, txData);

    #endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN1_ReadRxData
********************************************************************************
*
* Summary:
*  Read the next byte of data received across the SPI.
*
* Parameters:
*  None.
*
* Return:
*  The next byte of data read from the FIFO.
*
* Global variables:
*  CLKGEN1_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer.
*  CLKGEN1_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer, modified every function
*  call if RX Software Buffer is used.
*  CLKGEN1_rxBuffer[CLKGEN1_RX_BUFFER_SIZE] - used to store
*  received data.
*
* Theory:
*  Allows the user to read a byte of data received.
*
* Side Effects:
*  Will return invalid data if the FIFO is empty. The user should Call
*  GetRxBufferSize() and if it returns a non-zero value then it is safe to call
*  ReadByte() function.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 CLKGEN1_ReadRxData(void) 
{
    uint8 rxData;

    #if(CLKGEN1_RX_SOFTWARE_BUF_ENABLED)

        /* Disable RX interrupt to protect global veriables */
        CLKGEN1_DisableRxInt();

        if(CLKGEN1_rxBufferRead != CLKGEN1_rxBufferWrite)
        {
            if(0u == CLKGEN1_rxBufferFull)
            {
                CLKGEN1_rxBufferRead++;
                if(CLKGEN1_rxBufferRead >= CLKGEN1_RX_BUFFER_SIZE)
                {
                    CLKGEN1_rxBufferRead = 0u;
                }
            }
            else
            {
                CLKGEN1_rxBufferFull = 0u;
            }
        }

        rxData = CLKGEN1_rxBuffer[CLKGEN1_rxBufferRead];

        CLKGEN1_EnableRxInt();

    #else

        rxData = CY_GET_REG8(CLKGEN1_RXDATA_PTR);

    #endif /* (CLKGEN1_RX_SOFTWARE_BUF_ENABLED) */

    return(rxData);
}


/*******************************************************************************
* Function Name: CLKGEN1_GetRxBufferSize
********************************************************************************
*
* Summary:
*  Returns the number of bytes/words of data currently held in the RX buffer.
*  If RX Software Buffer not used then function return 0 if FIFO empty or 1 if
*  FIFO not empty. In another case function return size of RX Software Buffer.
*
* Parameters:
*  None.
*
* Return:
*  Integer count of the number of bytes/words in the RX buffer.
*
* Global variables:
*  CLKGEN1_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer.
*  CLKGEN1_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
uint8 CLKGEN1_GetRxBufferSize(void) 
{
    uint8 size;

    #if(CLKGEN1_RX_SOFTWARE_BUF_ENABLED)

        /* Disable RX interrupt to protect global veriables */
        CLKGEN1_DisableRxInt();

        if(CLKGEN1_rxBufferRead == CLKGEN1_rxBufferWrite)
        {
            size = 0u;
        }
        else if(CLKGEN1_rxBufferRead < CLKGEN1_rxBufferWrite)
        {
            size = (CLKGEN1_rxBufferWrite - CLKGEN1_rxBufferRead);
        }
        else
        {
            size = (CLKGEN1_RX_BUFFER_SIZE - CLKGEN1_rxBufferRead) + CLKGEN1_rxBufferWrite;
        }

        CLKGEN1_EnableRxInt();

    #else

        /* We can only know if there is data in the RX FIFO */
        size = (0u != (CLKGEN1_RX_STATUS_REG & CLKGEN1_STS_RX_FIFO_NOT_EMPTY)) ? 1u : 0u;

    #endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED) */

    return(size);
}


/*******************************************************************************
* Function Name: CLKGEN1_GetTxBufferSize
********************************************************************************
*
* Summary:
*  Returns the number of bytes/words of data currently held in the TX buffer.
*  If TX Software Buffer not used then function return 0 - if FIFO empty, 1 - if
*  FIFO not full, 4 - if FIFO full. In another case function return size of TX
*  Software Buffer.
*
* Parameters:
*  None.
*
* Return:
*  Integer count of the number of bytes/words in the TX buffer.
*
* Global variables:
*  CLKGEN1_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer.
*  CLKGEN1_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
uint8  CLKGEN1_GetTxBufferSize(void) 
{
    uint8 size;

    #if(CLKGEN1_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        CLKGEN1_DisableTxInt();

        if(CLKGEN1_txBufferRead == CLKGEN1_txBufferWrite)
        {
            size = 0u;
        }
        else if(CLKGEN1_txBufferRead < CLKGEN1_txBufferWrite)
        {
            size = (CLKGEN1_txBufferWrite - CLKGEN1_txBufferRead);
        }
        else
        {
            size = (CLKGEN1_TX_BUFFER_SIZE - CLKGEN1_txBufferRead) + CLKGEN1_txBufferWrite;
        }

        CLKGEN1_EnableTxInt();

    #else

        size = CLKGEN1_TX_STATUS_REG;

        if(0u != (size & CLKGEN1_STS_TX_FIFO_EMPTY))
        {
            size = 0u;
        }
        else if(0u != (size & CLKGEN1_STS_TX_FIFO_NOT_FULL))
        {
            size = 1u;
        }
        else
        {
            size = CLKGEN1_FIFO_SIZE;
        }

    #endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED) */

    return(size);
}


/*******************************************************************************
* Function Name: CLKGEN1_ClearRxBuffer
********************************************************************************
*
* Summary:
*  Clear the RX RAM buffer by setting the read and write pointers both to zero.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  CLKGEN1_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer, modified every function
*  call - resets to zero.
*  CLKGEN1_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer, modified every function call -
*  resets to zero.
*
* Theory:
*  Setting the pointers to zero makes the system believe there is no data to
*  read and writing will resume at address 0 overwriting any data that may have
*  remained in the RAM.
*
* Side Effects:
*  Any received data not read from the RAM buffer will be lost when overwritten.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN1_ClearRxBuffer(void) 
{
    /* Clear Hardware RX FIFO */
    while(0u !=(CLKGEN1_RX_STATUS_REG & CLKGEN1_STS_RX_FIFO_NOT_EMPTY))
    {
        (void) CY_GET_REG8(CLKGEN1_RXDATA_PTR);
    }

    #if(CLKGEN1_RX_SOFTWARE_BUF_ENABLED)
        /* Disable RX interrupt to protect global veriables */
        CLKGEN1_DisableRxInt();

        CLKGEN1_rxBufferFull  = 0u;
        CLKGEN1_rxBufferRead  = 0u;
        CLKGEN1_rxBufferWrite = 0u;

        CLKGEN1_EnableRxInt();
    #endif /* (CLKGEN1_RX_SOFTWARE_BUF_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN1_ClearTxBuffer
********************************************************************************
*
* Summary:
*  Clear the TX RAM buffer by setting the read and write pointers both to zero.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  CLKGEN1_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer, modified every function
*  call - resets to zero.
*  CLKGEN1_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer, modified every function call -
*  resets to zero.
*
* Theory:
*  Setting the pointers to zero makes the system believe there is no data to
*  read and writing will resume at address 0 overwriting any data that may have
*  remained in the RAM.
*
* Side Effects:
*  Any data not yet transmitted from the RAM buffer will be lost when
*  overwritten.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN1_ClearTxBuffer(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    /* Clear TX FIFO */
    CLKGEN1_AUX_CONTROL_DP0_REG |= ((uint8)  CLKGEN1_TX_FIFO_CLR);
    CLKGEN1_AUX_CONTROL_DP0_REG &= ((uint8) ~CLKGEN1_TX_FIFO_CLR);

    #if(CLKGEN1_USE_SECOND_DATAPATH)
        /* Clear TX FIFO for 2nd Datapath */
        CLKGEN1_AUX_CONTROL_DP1_REG |= ((uint8)  CLKGEN1_TX_FIFO_CLR);
        CLKGEN1_AUX_CONTROL_DP1_REG &= ((uint8) ~CLKGEN1_TX_FIFO_CLR);
    #endif /* (CLKGEN1_USE_SECOND_DATAPATH) */
    CyExitCriticalSection(enableInterrupts);

    #if(CLKGEN1_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        CLKGEN1_DisableTxInt();

        CLKGEN1_txBufferFull  = 0u;
        CLKGEN1_txBufferRead  = 0u;
        CLKGEN1_txBufferWrite = 0u;

        /* Buffer is EMPTY: disable TX FIFO NOT FULL interrupt */
        CLKGEN1_TX_STATUS_MASK_REG &= ((uint8) ~CLKGEN1_STS_TX_FIFO_NOT_FULL);

        CLKGEN1_EnableTxInt();
    #endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED) */
}


#if(0u != CLKGEN1_BIDIRECTIONAL_MODE)
    /*******************************************************************************
    * Function Name: CLKGEN1_TxEnable
    ********************************************************************************
    *
    * Summary:
    *  If the SPI master is configured to use a single bi-directional pin then this
    *  will set the bi-directional pin to transmit.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void CLKGEN1_TxEnable(void) 
    {
        CLKGEN1_CONTROL_REG |= CLKGEN1_CTRL_TX_SIGNAL_EN;
    }


    /*******************************************************************************
    * Function Name: CLKGEN1_TxDisable
    ********************************************************************************
    *
    * Summary:
    *  If the SPI master is configured to use a single bi-directional pin then this
    *  will set the bi-directional pin to receive.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void CLKGEN1_TxDisable(void) 
    {
        CLKGEN1_CONTROL_REG &= ((uint8) ~CLKGEN1_CTRL_TX_SIGNAL_EN);
    }

#endif /* (0u != CLKGEN1_BIDIRECTIONAL_MODE) */


/*******************************************************************************
* Function Name: CLKGEN1_PutArray
********************************************************************************
*
* Summary:
*  Write available data from ROM/RAM to the TX buffer while space is available
*  in the TX buffer. Keep trying until all data is passed to the TX buffer.
*
* Parameters:
*  *buffer: Pointer to the location in RAM containing the data to send
*  byteCount: The number of bytes to move to the transmit buffer.
*
* Return:
*  None.
*
* Side Effects:
*  Will stay in this routine until all data has been sent.  May get locked in
*  this loop if data is not being initiated by the master if there is not
*  enough room in the TX FIFO.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN1_PutArray(const uint8 buffer[], uint8 byteCount)
                                                                          
{
    uint8 bufIndex;

    bufIndex = 0u;

    while(byteCount > 0u)
    {
        CLKGEN1_WriteTxData(buffer[bufIndex]);
        bufIndex++;
        byteCount--;
    }
}


/*******************************************************************************
* Function Name: CLKGEN1_ClearFIFO
********************************************************************************
*
* Summary:
*  Clear the RX and TX FIFO's of all data for a fresh start.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
void CLKGEN1_ClearFIFO(void) 
{
    uint8 enableInterrupts;

    /* Clear Hardware RX FIFO */
    while(0u !=(CLKGEN1_RX_STATUS_REG & CLKGEN1_STS_RX_FIFO_NOT_EMPTY))
    {
        (void) CY_GET_REG8(CLKGEN1_RXDATA_PTR);
    }

    enableInterrupts = CyEnterCriticalSection();
    /* Clear TX FIFO */
    CLKGEN1_AUX_CONTROL_DP0_REG |= ((uint8)  CLKGEN1_TX_FIFO_CLR);
    CLKGEN1_AUX_CONTROL_DP0_REG &= ((uint8) ~CLKGEN1_TX_FIFO_CLR);

    #if(CLKGEN1_USE_SECOND_DATAPATH)
        /* Clear TX FIFO for 2nd Datapath */
        CLKGEN1_AUX_CONTROL_DP1_REG |= ((uint8)  CLKGEN1_TX_FIFO_CLR);
        CLKGEN1_AUX_CONTROL_DP1_REG &= ((uint8) ~CLKGEN1_TX_FIFO_CLR);
    #endif /* (CLKGEN1_USE_SECOND_DATAPATH) */
    CyExitCriticalSection(enableInterrupts);
}


/* Following functions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects.
*/


/*******************************************************************************
* Function Name: CLKGEN1_EnableInt
********************************************************************************
*
* Summary:
*  Enable internal interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN1_EnableInt(void) 
{
    CLKGEN1_EnableRxInt();
    CLKGEN1_EnableTxInt();
}


/*******************************************************************************
* Function Name: CLKGEN1_DisableInt
********************************************************************************
*
* Summary:
*  Disable internal interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN1_DisableInt(void) 
{
    CLKGEN1_DisableTxInt();
    CLKGEN1_DisableRxInt();
}


/*******************************************************************************
* Function Name: CLKGEN1_SetInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void CLKGEN1_SetInterruptMode(uint8 intSrc) 
{
    CLKGEN1_TX_STATUS_MASK_REG  = (intSrc & ((uint8) ~CLKGEN1_STS_SPI_IDLE));
    CLKGEN1_RX_STATUS_MASK_REG  =  intSrc;
}


/*******************************************************************************
* Function Name: CLKGEN1_ReadStatus
********************************************************************************
*
* Summary:
*  Read the status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the status register.
*
* Global variables:
*  CLKGEN1_swStatus - used to store in software status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the status register for error detection
*  and flow control.
*
* Side Effects:
*  Clear status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 CLKGEN1_ReadStatus(void) 
{
    uint8 tmpStatus;

    #if(CLKGEN1_TX_SOFTWARE_BUF_ENABLED || CLKGEN1_RX_SOFTWARE_BUF_ENABLED)

        CLKGEN1_DisableInt();

        tmpStatus  = CLKGEN1_GET_STATUS_RX(CLKGEN1_swStatusRx);
        tmpStatus |= CLKGEN1_GET_STATUS_TX(CLKGEN1_swStatusTx);
        tmpStatus &= ((uint8) ~CLKGEN1_STS_SPI_IDLE);

        CLKGEN1_swStatusTx = 0u;
        CLKGEN1_swStatusRx = 0u;

        CLKGEN1_EnableInt();

    #else

        tmpStatus  = CLKGEN1_RX_STATUS_REG;
        tmpStatus |= CLKGEN1_TX_STATUS_REG;
        tmpStatus &= ((uint8) ~CLKGEN1_STS_SPI_IDLE);

    #endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED || CLKGEN1_RX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/* [] END OF FILE */
