/*******************************************************************************
* File Name: CLKGEN1.h
* Version 2.50
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the SPI Master Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SPIM_CLKGEN1_H)
#define CY_SPIM_CLKGEN1_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define CLKGEN1_INTERNAL_CLOCK             (0u)

#if(0u != CLKGEN1_INTERNAL_CLOCK)
    #include "CLKGEN1_IntClock.h"
#endif /* (0u != CLKGEN1_INTERNAL_CLOCK) */

#define CLKGEN1_MODE                       (1u)
#define CLKGEN1_DATA_WIDTH                 (8u)
#define CLKGEN1_MODE_USE_ZERO              (1u)
#define CLKGEN1_BIDIRECTIONAL_MODE         (0u)

/* Internal interrupt handling */
#define CLKGEN1_TX_BUFFER_SIZE             (4u)
#define CLKGEN1_RX_BUFFER_SIZE             (4u)
#define CLKGEN1_INTERNAL_TX_INT_ENABLED    (0u)
#define CLKGEN1_INTERNAL_RX_INT_ENABLED    (0u)

#define CLKGEN1_SINGLE_REG_SIZE            (8u)
#define CLKGEN1_USE_SECOND_DATAPATH        (CLKGEN1_DATA_WIDTH > CLKGEN1_SINGLE_REG_SIZE)

#define CLKGEN1_FIFO_SIZE                  (4u)
#define CLKGEN1_TX_SOFTWARE_BUF_ENABLED    ((0u != CLKGEN1_INTERNAL_TX_INT_ENABLED) && \
                                                     (CLKGEN1_TX_BUFFER_SIZE > CLKGEN1_FIFO_SIZE))

#define CLKGEN1_RX_SOFTWARE_BUF_ENABLED    ((0u != CLKGEN1_INTERNAL_RX_INT_ENABLED) && \
                                                     (CLKGEN1_RX_BUFFER_SIZE > CLKGEN1_FIFO_SIZE))


/***************************************
*        Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
    uint8 cntrPeriod;
} CLKGEN1_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  CLKGEN1_Init(void)                           ;
void  CLKGEN1_Enable(void)                         ;
void  CLKGEN1_Start(void)                          ;
void  CLKGEN1_Stop(void)                           ;

void  CLKGEN1_EnableTxInt(void)                    ;
void  CLKGEN1_EnableRxInt(void)                    ;
void  CLKGEN1_DisableTxInt(void)                   ;
void  CLKGEN1_DisableRxInt(void)                   ;

void  CLKGEN1_Sleep(void)                          ;
void  CLKGEN1_Wakeup(void)                         ;
void  CLKGEN1_SaveConfig(void)                     ;
void  CLKGEN1_RestoreConfig(void)                  ;

void  CLKGEN1_SetTxInterruptMode(uint8 intSrc)     ;
void  CLKGEN1_SetRxInterruptMode(uint8 intSrc)     ;
uint8 CLKGEN1_ReadTxStatus(void)                   ;
uint8 CLKGEN1_ReadRxStatus(void)                   ;
void  CLKGEN1_WriteTxData(uint8 txData)  \
                                                            ;
uint8 CLKGEN1_ReadRxData(void) \
                                                            ;
uint8 CLKGEN1_GetRxBufferSize(void)                ;
uint8 CLKGEN1_GetTxBufferSize(void)                ;
void  CLKGEN1_ClearRxBuffer(void)                  ;
void  CLKGEN1_ClearTxBuffer(void)                  ;
void  CLKGEN1_ClearFIFO(void)                              ;
void  CLKGEN1_PutArray(const uint8 buffer[], uint8 byteCount) \
                                                            ;

#if(0u != CLKGEN1_BIDIRECTIONAL_MODE)
    void  CLKGEN1_TxEnable(void)                   ;
    void  CLKGEN1_TxDisable(void)                  ;
#endif /* (0u != CLKGEN1_BIDIRECTIONAL_MODE) */

CY_ISR_PROTO(CLKGEN1_TX_ISR);
CY_ISR_PROTO(CLKGEN1_RX_ISR);


/***************************************
*   Variable with external linkage
***************************************/

extern uint8 CLKGEN1_initVar;


/***************************************
*           API Constants
***************************************/

#define CLKGEN1_TX_ISR_NUMBER     ((uint8) (CLKGEN1_TxInternalInterrupt__INTC_NUMBER))
#define CLKGEN1_RX_ISR_NUMBER     ((uint8) (CLKGEN1_RxInternalInterrupt__INTC_NUMBER))

#define CLKGEN1_TX_ISR_PRIORITY   ((uint8) (CLKGEN1_TxInternalInterrupt__INTC_PRIOR_NUM))
#define CLKGEN1_RX_ISR_PRIORITY   ((uint8) (CLKGEN1_RxInternalInterrupt__INTC_PRIOR_NUM))


/***************************************
*    Initial Parameter Constants
***************************************/

#define CLKGEN1_INT_ON_SPI_DONE    ((uint8) (0u   << CLKGEN1_STS_SPI_DONE_SHIFT))
#define CLKGEN1_INT_ON_TX_EMPTY    ((uint8) (0u   << CLKGEN1_STS_TX_FIFO_EMPTY_SHIFT))
#define CLKGEN1_INT_ON_TX_NOT_FULL ((uint8) (0u << \
                                                                           CLKGEN1_STS_TX_FIFO_NOT_FULL_SHIFT))
#define CLKGEN1_INT_ON_BYTE_COMP   ((uint8) (0u  << CLKGEN1_STS_BYTE_COMPLETE_SHIFT))
#define CLKGEN1_INT_ON_SPI_IDLE    ((uint8) (0u   << CLKGEN1_STS_SPI_IDLE_SHIFT))

/* Disable TX_NOT_FULL if software buffer is used */
#define CLKGEN1_INT_ON_TX_NOT_FULL_DEF ((CLKGEN1_TX_SOFTWARE_BUF_ENABLED) ? \
                                                                        (0u) : (CLKGEN1_INT_ON_TX_NOT_FULL))

/* TX interrupt mask */
#define CLKGEN1_TX_INIT_INTERRUPTS_MASK    (CLKGEN1_INT_ON_SPI_DONE  | \
                                                     CLKGEN1_INT_ON_TX_EMPTY  | \
                                                     CLKGEN1_INT_ON_TX_NOT_FULL_DEF | \
                                                     CLKGEN1_INT_ON_BYTE_COMP | \
                                                     CLKGEN1_INT_ON_SPI_IDLE)

#define CLKGEN1_INT_ON_RX_FULL         ((uint8) (0u << \
                                                                          CLKGEN1_STS_RX_FIFO_FULL_SHIFT))
#define CLKGEN1_INT_ON_RX_NOT_EMPTY    ((uint8) (0u << \
                                                                          CLKGEN1_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define CLKGEN1_INT_ON_RX_OVER         ((uint8) (0u << \
                                                                          CLKGEN1_STS_RX_FIFO_OVERRUN_SHIFT))

/* RX interrupt mask */
#define CLKGEN1_RX_INIT_INTERRUPTS_MASK    (CLKGEN1_INT_ON_RX_FULL      | \
                                                     CLKGEN1_INT_ON_RX_NOT_EMPTY | \
                                                     CLKGEN1_INT_ON_RX_OVER)
/* Nubmer of bits to receive/transmit */
#define CLKGEN1_BITCTR_INIT            (((uint8) (CLKGEN1_DATA_WIDTH << 1u)) - 1u)


/***************************************
*             Registers
***************************************/
#if(CY_PSOC3 || CY_PSOC5)
    #define CLKGEN1_TXDATA_REG (* (reg8 *) \
                                                CLKGEN1_BSPIM_sR8_Dp_u0__F0_REG)
    #define CLKGEN1_TXDATA_PTR (  (reg8 *) \
                                                CLKGEN1_BSPIM_sR8_Dp_u0__F0_REG)
    #define CLKGEN1_RXDATA_REG (* (reg8 *) \
                                                CLKGEN1_BSPIM_sR8_Dp_u0__F1_REG)
    #define CLKGEN1_RXDATA_PTR (  (reg8 *) \
                                                CLKGEN1_BSPIM_sR8_Dp_u0__F1_REG)
#else   /* PSOC4 */
    #if(CLKGEN1_USE_SECOND_DATAPATH)
        #define CLKGEN1_TXDATA_REG (* (reg16 *) \
                                          CLKGEN1_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define CLKGEN1_TXDATA_PTR (  (reg16 *) \
                                          CLKGEN1_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define CLKGEN1_RXDATA_REG (* (reg16 *) \
                                          CLKGEN1_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
        #define CLKGEN1_RXDATA_PTR (  (reg16 *) \
                                          CLKGEN1_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
    #else
        #define CLKGEN1_TXDATA_REG (* (reg8 *) \
                                                CLKGEN1_BSPIM_sR8_Dp_u0__F0_REG)
        #define CLKGEN1_TXDATA_PTR (  (reg8 *) \
                                                CLKGEN1_BSPIM_sR8_Dp_u0__F0_REG)
        #define CLKGEN1_RXDATA_REG (* (reg8 *) \
                                                CLKGEN1_BSPIM_sR8_Dp_u0__F1_REG)
        #define CLKGEN1_RXDATA_PTR (  (reg8 *) \
                                                CLKGEN1_BSPIM_sR8_Dp_u0__F1_REG)
    #endif /* (CLKGEN1_USE_SECOND_DATAPATH) */
#endif     /* (CY_PSOC3 || CY_PSOC5) */

#define CLKGEN1_AUX_CONTROL_DP0_REG (* (reg8 *) \
                                        CLKGEN1_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)
#define CLKGEN1_AUX_CONTROL_DP0_PTR (  (reg8 *) \
                                        CLKGEN1_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)

#if(CLKGEN1_USE_SECOND_DATAPATH)
    #define CLKGEN1_AUX_CONTROL_DP1_REG  (* (reg8 *) \
                                        CLKGEN1_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
    #define CLKGEN1_AUX_CONTROL_DP1_PTR  (  (reg8 *) \
                                        CLKGEN1_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
#endif /* (CLKGEN1_USE_SECOND_DATAPATH) */

#define CLKGEN1_COUNTER_PERIOD_REG     (* (reg8 *) CLKGEN1_BSPIM_BitCounter__PERIOD_REG)
#define CLKGEN1_COUNTER_PERIOD_PTR     (  (reg8 *) CLKGEN1_BSPIM_BitCounter__PERIOD_REG)
#define CLKGEN1_COUNTER_CONTROL_REG    (* (reg8 *) CLKGEN1_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)
#define CLKGEN1_COUNTER_CONTROL_PTR    (  (reg8 *) CLKGEN1_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)

#define CLKGEN1_TX_STATUS_REG          (* (reg8 *) CLKGEN1_BSPIM_TxStsReg__STATUS_REG)
#define CLKGEN1_TX_STATUS_PTR          (  (reg8 *) CLKGEN1_BSPIM_TxStsReg__STATUS_REG)
#define CLKGEN1_RX_STATUS_REG          (* (reg8 *) CLKGEN1_BSPIM_RxStsReg__STATUS_REG)
#define CLKGEN1_RX_STATUS_PTR          (  (reg8 *) CLKGEN1_BSPIM_RxStsReg__STATUS_REG)

#define CLKGEN1_CONTROL_REG            (* (reg8 *) \
                                      CLKGEN1_BSPIM_BidirMode_CtrlReg__CONTROL_REG)
#define CLKGEN1_CONTROL_PTR            (  (reg8 *) \
                                      CLKGEN1_BSPIM_BidirMode_CtrlReg__CONTROL_REG)

#define CLKGEN1_TX_STATUS_MASK_REG     (* (reg8 *) CLKGEN1_BSPIM_TxStsReg__MASK_REG)
#define CLKGEN1_TX_STATUS_MASK_PTR     (  (reg8 *) CLKGEN1_BSPIM_TxStsReg__MASK_REG)
#define CLKGEN1_RX_STATUS_MASK_REG     (* (reg8 *) CLKGEN1_BSPIM_RxStsReg__MASK_REG)
#define CLKGEN1_RX_STATUS_MASK_PTR     (  (reg8 *) CLKGEN1_BSPIM_RxStsReg__MASK_REG)

#define CLKGEN1_TX_STATUS_ACTL_REG     (* (reg8 *) CLKGEN1_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define CLKGEN1_TX_STATUS_ACTL_PTR     (  (reg8 *) CLKGEN1_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define CLKGEN1_RX_STATUS_ACTL_REG     (* (reg8 *) CLKGEN1_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)
#define CLKGEN1_RX_STATUS_ACTL_PTR     (  (reg8 *) CLKGEN1_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)

#if(CLKGEN1_USE_SECOND_DATAPATH)
    #define CLKGEN1_AUX_CONTROLDP1     (CLKGEN1_AUX_CONTROL_DP1_REG)
#endif /* (CLKGEN1_USE_SECOND_DATAPATH) */


/***************************************
*       Register Constants
***************************************/

/* Status Register Definitions */
#define CLKGEN1_STS_SPI_DONE_SHIFT             (0x00u)
#define CLKGEN1_STS_TX_FIFO_EMPTY_SHIFT        (0x01u)
#define CLKGEN1_STS_TX_FIFO_NOT_FULL_SHIFT     (0x02u)
#define CLKGEN1_STS_BYTE_COMPLETE_SHIFT        (0x03u)
#define CLKGEN1_STS_SPI_IDLE_SHIFT             (0x04u)
#define CLKGEN1_STS_RX_FIFO_FULL_SHIFT         (0x04u)
#define CLKGEN1_STS_RX_FIFO_NOT_EMPTY_SHIFT    (0x05u)
#define CLKGEN1_STS_RX_FIFO_OVERRUN_SHIFT      (0x06u)

#define CLKGEN1_STS_SPI_DONE           ((uint8) (0x01u << CLKGEN1_STS_SPI_DONE_SHIFT))
#define CLKGEN1_STS_TX_FIFO_EMPTY      ((uint8) (0x01u << CLKGEN1_STS_TX_FIFO_EMPTY_SHIFT))
#define CLKGEN1_STS_TX_FIFO_NOT_FULL   ((uint8) (0x01u << CLKGEN1_STS_TX_FIFO_NOT_FULL_SHIFT))
#define CLKGEN1_STS_BYTE_COMPLETE      ((uint8) (0x01u << CLKGEN1_STS_BYTE_COMPLETE_SHIFT))
#define CLKGEN1_STS_SPI_IDLE           ((uint8) (0x01u << CLKGEN1_STS_SPI_IDLE_SHIFT))
#define CLKGEN1_STS_RX_FIFO_FULL       ((uint8) (0x01u << CLKGEN1_STS_RX_FIFO_FULL_SHIFT))
#define CLKGEN1_STS_RX_FIFO_NOT_EMPTY  ((uint8) (0x01u << CLKGEN1_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define CLKGEN1_STS_RX_FIFO_OVERRUN    ((uint8) (0x01u << CLKGEN1_STS_RX_FIFO_OVERRUN_SHIFT))

/* TX and RX masks for clear on read bits */
#define CLKGEN1_TX_STS_CLR_ON_RD_BYTES_MASK    (0x09u)
#define CLKGEN1_RX_STS_CLR_ON_RD_BYTES_MASK    (0x40u)

/* StatusI Register Interrupt Enable Control Bits */
/* As defined by the Register map for the AUX Control Register */
#define CLKGEN1_INT_ENABLE     (0x10u) /* Enable interrupt from statusi */
#define CLKGEN1_TX_FIFO_CLR    (0x01u) /* F0 - TX FIFO */
#define CLKGEN1_RX_FIFO_CLR    (0x02u) /* F1 - RX FIFO */
#define CLKGEN1_FIFO_CLR       (CLKGEN1_TX_FIFO_CLR | CLKGEN1_RX_FIFO_CLR)

/* Bit Counter (7-bit) Control Register Bit Definitions */
/* As defined by the Register map for the AUX Control Register */
#define CLKGEN1_CNTR_ENABLE    (0x20u) /* Enable CNT7 */

/* Bi-Directional mode control bit */
#define CLKGEN1_CTRL_TX_SIGNAL_EN  (0x01u)

/* Datapath Auxillary Control Register definitions */
#define CLKGEN1_AUX_CTRL_FIFO0_CLR         (0x01u)
#define CLKGEN1_AUX_CTRL_FIFO1_CLR         (0x02u)
#define CLKGEN1_AUX_CTRL_FIFO0_LVL         (0x04u)
#define CLKGEN1_AUX_CTRL_FIFO1_LVL         (0x08u)
#define CLKGEN1_STATUS_ACTL_INT_EN_MASK    (0x10u)

/* Component disabled */
#define CLKGEN1_DISABLED   (0u)


/***************************************
*       Macros
***************************************/

/* Returns true if componentn enabled */
#define CLKGEN1_IS_ENABLED (0u != (CLKGEN1_TX_STATUS_ACTL_REG & CLKGEN1_INT_ENABLE))

/* Retuns TX status register */
#define CLKGEN1_GET_STATUS_TX(swTxSts) ( (uint8)(CLKGEN1_TX_STATUS_REG | \
                                                          ((swTxSts) & CLKGEN1_TX_STS_CLR_ON_RD_BYTES_MASK)) )
/* Retuns RX status register */
#define CLKGEN1_GET_STATUS_RX(swRxSts) ( (uint8)(CLKGEN1_RX_STATUS_REG | \
                                                          ((swRxSts) & CLKGEN1_RX_STS_CLR_ON_RD_BYTES_MASK)) )


/***************************************
* The following code is DEPRECATED and 
* should not be used in new projects.
***************************************/

#define CLKGEN1_WriteByte   CLKGEN1_WriteTxData
#define CLKGEN1_ReadByte    CLKGEN1_ReadRxData
void  CLKGEN1_SetInterruptMode(uint8 intSrc)       ;
uint8 CLKGEN1_ReadStatus(void)                     ;
void  CLKGEN1_EnableInt(void)                      ;
void  CLKGEN1_DisableInt(void)                     ;

#define CLKGEN1_TXDATA                 (CLKGEN1_TXDATA_REG)
#define CLKGEN1_RXDATA                 (CLKGEN1_RXDATA_REG)
#define CLKGEN1_AUX_CONTROLDP0         (CLKGEN1_AUX_CONTROL_DP0_REG)
#define CLKGEN1_TXBUFFERREAD           (CLKGEN1_txBufferRead)
#define CLKGEN1_TXBUFFERWRITE          (CLKGEN1_txBufferWrite)
#define CLKGEN1_RXBUFFERREAD           (CLKGEN1_rxBufferRead)
#define CLKGEN1_RXBUFFERWRITE          (CLKGEN1_rxBufferWrite)

#define CLKGEN1_COUNTER_PERIOD         (CLKGEN1_COUNTER_PERIOD_REG)
#define CLKGEN1_COUNTER_CONTROL        (CLKGEN1_COUNTER_CONTROL_REG)
#define CLKGEN1_STATUS                 (CLKGEN1_TX_STATUS_REG)
#define CLKGEN1_CONTROL                (CLKGEN1_CONTROL_REG)
#define CLKGEN1_STATUS_MASK            (CLKGEN1_TX_STATUS_MASK_REG)
#define CLKGEN1_STATUS_ACTL            (CLKGEN1_TX_STATUS_ACTL_REG)

#define CLKGEN1_INIT_INTERRUPTS_MASK  (CLKGEN1_INT_ON_SPI_DONE     | \
                                                CLKGEN1_INT_ON_TX_EMPTY     | \
                                                CLKGEN1_INT_ON_TX_NOT_FULL_DEF  | \
                                                CLKGEN1_INT_ON_RX_FULL      | \
                                                CLKGEN1_INT_ON_RX_NOT_EMPTY | \
                                                CLKGEN1_INT_ON_RX_OVER      | \
                                                CLKGEN1_INT_ON_BYTE_COMP)
                                                
#define CLKGEN1_DataWidth                  (CLKGEN1_DATA_WIDTH)
#define CLKGEN1_InternalClockUsed          (CLKGEN1_INTERNAL_CLOCK)
#define CLKGEN1_InternalTxInterruptEnabled (CLKGEN1_INTERNAL_TX_INT_ENABLED)
#define CLKGEN1_InternalRxInterruptEnabled (CLKGEN1_INTERNAL_RX_INT_ENABLED)
#define CLKGEN1_ModeUseZero                (CLKGEN1_MODE_USE_ZERO)
#define CLKGEN1_BidirectionalMode          (CLKGEN1_BIDIRECTIONAL_MODE)
#define CLKGEN1_Mode                       (CLKGEN1_MODE)
#define CLKGEN1_DATAWIDHT                  (CLKGEN1_DATA_WIDTH)
#define CLKGEN1_InternalInterruptEnabled   (0u)

#define CLKGEN1_TXBUFFERSIZE   (CLKGEN1_TX_BUFFER_SIZE)
#define CLKGEN1_RXBUFFERSIZE   (CLKGEN1_RX_BUFFER_SIZE)

#define CLKGEN1_TXBUFFER       CLKGEN1_txBuffer
#define CLKGEN1_RXBUFFER       CLKGEN1_rxBuffer

#endif /* (CY_SPIM_CLKGEN1_H) */


/* [] END OF FILE */
