/*******************************************************************************
* File Name: CLKGEN1_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CLKGEN1_PVT.h"

static CLKGEN1_BACKUP_STRUCT CLKGEN1_backup =
{
    CLKGEN1_DISABLED,
    CLKGEN1_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: CLKGEN1_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CLKGEN1_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: CLKGEN1_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CLKGEN1_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: CLKGEN1_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  CLKGEN1_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN1_Sleep(void) 
{
    /* Save components enable state */
    CLKGEN1_backup.enableState = ((uint8) CLKGEN1_IS_ENABLED);

    CLKGEN1_Stop();
}


/*******************************************************************************
* Function Name: CLKGEN1_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  CLKGEN1_backup - used when non-retention registers are restored.
*  CLKGEN1_txBufferWrite - modified every function call - resets to
*  zero.
*  CLKGEN1_txBufferRead - modified every function call - resets to
*  zero.
*  CLKGEN1_rxBufferWrite - modified every function call - resets to
*  zero.
*  CLKGEN1_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN1_Wakeup(void) 
{
    #if(CLKGEN1_RX_SOFTWARE_BUF_ENABLED)
        CLKGEN1_rxBufferFull  = 0u;
        CLKGEN1_rxBufferRead  = 0u;
        CLKGEN1_rxBufferWrite = 0u;
    #endif /* (CLKGEN1_RX_SOFTWARE_BUF_ENABLED) */

    #if(CLKGEN1_TX_SOFTWARE_BUF_ENABLED)
        CLKGEN1_txBufferFull  = 0u;
        CLKGEN1_txBufferRead  = 0u;
        CLKGEN1_txBufferWrite = 0u;
    #endif /* (CLKGEN1_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    CLKGEN1_ClearFIFO();

    /* Restore components block enable state */
    if(0u != CLKGEN1_backup.enableState)
    {
        CLKGEN1_Enable();
    }
}


/* [] END OF FILE */
