/*******************************************************************************
* File Name: CLKGEN2.c
* Version 2.50
*
* Description:
*  This file provides all API functionality of the SPI Master component.
*
* Note:
*  None.
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CLKGEN2_PVT.h"

#if(CLKGEN2_TX_SOFTWARE_BUF_ENABLED)
    volatile uint8 CLKGEN2_txBuffer[CLKGEN2_TX_BUFFER_SIZE];
    volatile uint8 CLKGEN2_txBufferFull;
    volatile uint8 CLKGEN2_txBufferRead;
    volatile uint8 CLKGEN2_txBufferWrite;
#endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED) */

#if(CLKGEN2_RX_SOFTWARE_BUF_ENABLED)
    volatile uint8 CLKGEN2_rxBuffer[CLKGEN2_RX_BUFFER_SIZE];
    volatile uint8 CLKGEN2_rxBufferFull;
    volatile uint8 CLKGEN2_rxBufferRead;
    volatile uint8 CLKGEN2_rxBufferWrite;
#endif /* (CLKGEN2_RX_SOFTWARE_BUF_ENABLED) */

uint8 CLKGEN2_initVar = 0u;

volatile uint8 CLKGEN2_swStatusTx;
volatile uint8 CLKGEN2_swStatusRx;


/*******************************************************************************
* Function Name: CLKGEN2_Init
********************************************************************************
*
* Summary:
*  Inits/Restores default SPIM configuration provided with customizer.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Side Effects:
*  When this function is called it initializes all of the necessary parameters
*  for execution. i.e. setting the initial interrupt mask, configuring the
*  interrupt service routine, configuring the bit-counter parameters and
*  clearing the FIFO and Status Register.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN2_Init(void) 
{
    /* Initialize the Bit counter */
    CLKGEN2_COUNTER_PERIOD_REG = CLKGEN2_BITCTR_INIT;

    /* Init TX ISR  */
    #if(0u != CLKGEN2_INTERNAL_TX_INT_ENABLED)
        CyIntDisable         (CLKGEN2_TX_ISR_NUMBER);
        CyIntSetPriority     (CLKGEN2_TX_ISR_NUMBER,  CLKGEN2_TX_ISR_PRIORITY);
        (void) CyIntSetVector(CLKGEN2_TX_ISR_NUMBER, &CLKGEN2_TX_ISR);
    #endif /* (0u != CLKGEN2_INTERNAL_TX_INT_ENABLED) */

    /* Init RX ISR  */
    #if(0u != CLKGEN2_INTERNAL_RX_INT_ENABLED)
        CyIntDisable         (CLKGEN2_RX_ISR_NUMBER);
        CyIntSetPriority     (CLKGEN2_RX_ISR_NUMBER,  CLKGEN2_RX_ISR_PRIORITY);
        (void) CyIntSetVector(CLKGEN2_RX_ISR_NUMBER, &CLKGEN2_RX_ISR);
    #endif /* (0u != CLKGEN2_INTERNAL_RX_INT_ENABLED) */

    /* Clear any stray data from the RX and TX FIFO */
    CLKGEN2_ClearFIFO();

    #if(CLKGEN2_RX_SOFTWARE_BUF_ENABLED)
        CLKGEN2_rxBufferFull  = 0u;
        CLKGEN2_rxBufferRead  = 0u;
        CLKGEN2_rxBufferWrite = 0u;
    #endif /* (CLKGEN2_RX_SOFTWARE_BUF_ENABLED) */

    #if(CLKGEN2_TX_SOFTWARE_BUF_ENABLED)
        CLKGEN2_txBufferFull  = 0u;
        CLKGEN2_txBufferRead  = 0u;
        CLKGEN2_txBufferWrite = 0u;
    #endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED) */

    (void) CLKGEN2_ReadTxStatus(); /* Clear Tx status and swStatusTx */
    (void) CLKGEN2_ReadRxStatus(); /* Clear Rx status and swStatusRx */

    /* Configure TX and RX interrupt mask */
    CLKGEN2_TX_STATUS_MASK_REG = CLKGEN2_TX_INIT_INTERRUPTS_MASK;
    CLKGEN2_RX_STATUS_MASK_REG = CLKGEN2_RX_INIT_INTERRUPTS_MASK;
}


/*******************************************************************************
* Function Name: CLKGEN2_Enable
********************************************************************************
*
* Summary:
*  Enable SPIM component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CLKGEN2_Enable(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    CLKGEN2_COUNTER_CONTROL_REG |= CLKGEN2_CNTR_ENABLE;
    CLKGEN2_TX_STATUS_ACTL_REG  |= CLKGEN2_INT_ENABLE;
    CLKGEN2_RX_STATUS_ACTL_REG  |= CLKGEN2_INT_ENABLE;
    CyExitCriticalSection(enableInterrupts);

    #if(0u != CLKGEN2_INTERNAL_CLOCK)
        CLKGEN2_IntClock_Enable();
    #endif /* (0u != CLKGEN2_INTERNAL_CLOCK) */

    CLKGEN2_EnableTxInt();
    CLKGEN2_EnableRxInt();
}


/*******************************************************************************
* Function Name: CLKGEN2_Start
********************************************************************************
*
* Summary:
*  Initialize and Enable the SPI Master component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  CLKGEN2_initVar - used to check initial configuration, modified on
*  first function call.
*
* Theory:
*  Enable the clock input to enable operation.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN2_Start(void) 
{
    if(0u == CLKGEN2_initVar)
    {
        CLKGEN2_Init();
        CLKGEN2_initVar = 1u;
    }

    CLKGEN2_Enable();
}


/*******************************************************************************
* Function Name: CLKGEN2_Stop
********************************************************************************
*
* Summary:
*  Disable the SPI Master component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the clock input to enable operation.
*
*******************************************************************************/
void CLKGEN2_Stop(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    CLKGEN2_TX_STATUS_ACTL_REG &= ((uint8) ~CLKGEN2_INT_ENABLE);
    CLKGEN2_RX_STATUS_ACTL_REG &= ((uint8) ~CLKGEN2_INT_ENABLE);
    CyExitCriticalSection(enableInterrupts);

    #if(0u != CLKGEN2_INTERNAL_CLOCK)
        CLKGEN2_IntClock_Disable();
    #endif /* (0u != CLKGEN2_INTERNAL_CLOCK) */

    CLKGEN2_DisableTxInt();
    CLKGEN2_DisableRxInt();
}


/*******************************************************************************
* Function Name: CLKGEN2_EnableTxInt
********************************************************************************
*
* Summary:
*  Enable internal Tx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal Tx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN2_EnableTxInt(void) 
{
    #if(0u != CLKGEN2_INTERNAL_TX_INT_ENABLED)
        CyIntEnable(CLKGEN2_TX_ISR_NUMBER);
    #endif /* (0u != CLKGEN2_INTERNAL_TX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN2_EnableRxInt
********************************************************************************
*
* Summary:
*  Enable internal Rx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal Rx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN2_EnableRxInt(void) 
{
    #if(0u != CLKGEN2_INTERNAL_RX_INT_ENABLED)
        CyIntEnable(CLKGEN2_RX_ISR_NUMBER);
    #endif /* (0u != CLKGEN2_INTERNAL_RX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN2_DisableTxInt
********************************************************************************
*
* Summary:
*  Disable internal Tx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal Tx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN2_DisableTxInt(void) 
{
    #if(0u != CLKGEN2_INTERNAL_TX_INT_ENABLED)
        CyIntDisable(CLKGEN2_TX_ISR_NUMBER);
    #endif /* (0u != CLKGEN2_INTERNAL_TX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN2_DisableRxInt
********************************************************************************
*
* Summary:
*  Disable internal Rx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal Rx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN2_DisableRxInt(void) 
{
    #if(0u != CLKGEN2_INTERNAL_RX_INT_ENABLED)
        CyIntDisable(CLKGEN2_RX_ISR_NUMBER);
    #endif /* (0u != CLKGEN2_INTERNAL_RX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN2_SetTxInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void CLKGEN2_SetTxInterruptMode(uint8 intSrc) 
{
    CLKGEN2_TX_STATUS_MASK_REG = intSrc;
}


/*******************************************************************************
* Function Name: CLKGEN2_SetRxInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void CLKGEN2_SetRxInterruptMode(uint8 intSrc) 
{
    CLKGEN2_RX_STATUS_MASK_REG  = intSrc;
}


/*******************************************************************************
* Function Name: CLKGEN2_ReadTxStatus
********************************************************************************
*
* Summary:
*  Read the Tx status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the Tx status register.
*
* Global variables:
*  CLKGEN2_swStatusTx - used to store in software status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the Tx status register for error
*  detection and flow control.
*
* Side Effects:
*  Clear Tx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 CLKGEN2_ReadTxStatus(void) 
{
    uint8 tmpStatus;

    #if(CLKGEN2_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        CLKGEN2_DisableTxInt();

        tmpStatus = CLKGEN2_GET_STATUS_TX(CLKGEN2_swStatusTx);
        CLKGEN2_swStatusTx = 0u;

        CLKGEN2_EnableTxInt();

    #else

        tmpStatus = CLKGEN2_TX_STATUS_REG;

    #endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/*******************************************************************************
* Function Name: CLKGEN2_ReadRxStatus
********************************************************************************
*
* Summary:
*  Read the Rx status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the Rx status register.
*
* Global variables:
*  CLKGEN2_swStatusRx - used to store in software Rx status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the Rx status register for error
*  detection and flow control.
*
* Side Effects:
*  Clear Rx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 CLKGEN2_ReadRxStatus(void) 
{
    uint8 tmpStatus;

    #if(CLKGEN2_RX_SOFTWARE_BUF_ENABLED)
        /* Disable RX interrupt to protect global veriables */
        CLKGEN2_DisableRxInt();

        tmpStatus = CLKGEN2_GET_STATUS_RX(CLKGEN2_swStatusRx);
        CLKGEN2_swStatusRx = 0u;

        CLKGEN2_EnableRxInt();

    #else

        tmpStatus = CLKGEN2_RX_STATUS_REG;

    #endif /* (CLKGEN2_RX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/*******************************************************************************
* Function Name: CLKGEN2_WriteTxData
********************************************************************************
*
* Summary:
*  Write a byte of data to be sent across the SPI.
*
* Parameters:
*  txDataByte: The data value to send across the SPI.
*
* Return:
*  None.
*
* Global variables:
*  CLKGEN2_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer, modified every function
*  call if TX Software Buffer is used.
*  CLKGEN2_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer.
*  CLKGEN2_txBuffer[CLKGEN2_TX_BUFFER_SIZE] - used to store
*  data to sending, modified every function call if TX Software Buffer is used.
*
* Theory:
*  Allows the user to transmit any byte of data in a single transfer.
*
* Side Effects:
*  If this function is called again before the previous byte is finished then
*  the next byte will be appended to the transfer with no time between
*  the byte transfers. Clear Tx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN2_WriteTxData(uint8 txData) 
{
    #if(CLKGEN2_TX_SOFTWARE_BUF_ENABLED)

        uint8 tempStatus;
        uint8 tmpTxBufferRead;

        /* Block if TX buffer is FULL: don't overwrite */
        do
        {
            tmpTxBufferRead = CLKGEN2_txBufferRead;
            if(0u == tmpTxBufferRead)
            {
                tmpTxBufferRead = (CLKGEN2_TX_BUFFER_SIZE - 1u);
            }
            else
            {
                tmpTxBufferRead--;
            }

        }while(tmpTxBufferRead == CLKGEN2_txBufferWrite);

        /* Disable TX interrupt to protect global veriables */
        CLKGEN2_DisableTxInt();

        tempStatus = CLKGEN2_GET_STATUS_TX(CLKGEN2_swStatusTx);
        CLKGEN2_swStatusTx = tempStatus;


        if((CLKGEN2_txBufferRead == CLKGEN2_txBufferWrite) &&
           (0u != (CLKGEN2_swStatusTx & CLKGEN2_STS_TX_FIFO_NOT_FULL)))
        {
            /* Put data element into the TX FIFO */
            CY_SET_REG8(CLKGEN2_TXDATA_PTR, txData);
        }
        else
        {
            /* Add to the TX software buffer */
            CLKGEN2_txBufferWrite++;
            if(CLKGEN2_txBufferWrite >= CLKGEN2_TX_BUFFER_SIZE)
            {
                CLKGEN2_txBufferWrite = 0u;
            }

            if(CLKGEN2_txBufferWrite == CLKGEN2_txBufferRead)
            {
                CLKGEN2_txBufferRead++;
                if(CLKGEN2_txBufferRead >= CLKGEN2_TX_BUFFER_SIZE)
                {
                    CLKGEN2_txBufferRead = 0u;
                }
                CLKGEN2_txBufferFull = 1u;
            }

            CLKGEN2_txBuffer[CLKGEN2_txBufferWrite] = txData;

            CLKGEN2_TX_STATUS_MASK_REG |= CLKGEN2_STS_TX_FIFO_NOT_FULL;
        }

        CLKGEN2_EnableTxInt();

    #else
        /* Wait until TX FIFO has a place */
        while(0u == (CLKGEN2_TX_STATUS_REG & CLKGEN2_STS_TX_FIFO_NOT_FULL))
        {
        }

        /* Put data element into the TX FIFO */
        CY_SET_REG8(CLKGEN2_TXDATA_PTR, txData);

    #endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN2_ReadRxData
********************************************************************************
*
* Summary:
*  Read the next byte of data received across the SPI.
*
* Parameters:
*  None.
*
* Return:
*  The next byte of data read from the FIFO.
*
* Global variables:
*  CLKGEN2_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer.
*  CLKGEN2_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer, modified every function
*  call if RX Software Buffer is used.
*  CLKGEN2_rxBuffer[CLKGEN2_RX_BUFFER_SIZE] - used to store
*  received data.
*
* Theory:
*  Allows the user to read a byte of data received.
*
* Side Effects:
*  Will return invalid data if the FIFO is empty. The user should Call
*  GetRxBufferSize() and if it returns a non-zero value then it is safe to call
*  ReadByte() function.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 CLKGEN2_ReadRxData(void) 
{
    uint8 rxData;

    #if(CLKGEN2_RX_SOFTWARE_BUF_ENABLED)

        /* Disable RX interrupt to protect global veriables */
        CLKGEN2_DisableRxInt();

        if(CLKGEN2_rxBufferRead != CLKGEN2_rxBufferWrite)
        {
            if(0u == CLKGEN2_rxBufferFull)
            {
                CLKGEN2_rxBufferRead++;
                if(CLKGEN2_rxBufferRead >= CLKGEN2_RX_BUFFER_SIZE)
                {
                    CLKGEN2_rxBufferRead = 0u;
                }
            }
            else
            {
                CLKGEN2_rxBufferFull = 0u;
            }
        }

        rxData = CLKGEN2_rxBuffer[CLKGEN2_rxBufferRead];

        CLKGEN2_EnableRxInt();

    #else

        rxData = CY_GET_REG8(CLKGEN2_RXDATA_PTR);

    #endif /* (CLKGEN2_RX_SOFTWARE_BUF_ENABLED) */

    return(rxData);
}


/*******************************************************************************
* Function Name: CLKGEN2_GetRxBufferSize
********************************************************************************
*
* Summary:
*  Returns the number of bytes/words of data currently held in the RX buffer.
*  If RX Software Buffer not used then function return 0 if FIFO empty or 1 if
*  FIFO not empty. In another case function return size of RX Software Buffer.
*
* Parameters:
*  None.
*
* Return:
*  Integer count of the number of bytes/words in the RX buffer.
*
* Global variables:
*  CLKGEN2_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer.
*  CLKGEN2_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
uint8 CLKGEN2_GetRxBufferSize(void) 
{
    uint8 size;

    #if(CLKGEN2_RX_SOFTWARE_BUF_ENABLED)

        /* Disable RX interrupt to protect global veriables */
        CLKGEN2_DisableRxInt();

        if(CLKGEN2_rxBufferRead == CLKGEN2_rxBufferWrite)
        {
            size = 0u;
        }
        else if(CLKGEN2_rxBufferRead < CLKGEN2_rxBufferWrite)
        {
            size = (CLKGEN2_rxBufferWrite - CLKGEN2_rxBufferRead);
        }
        else
        {
            size = (CLKGEN2_RX_BUFFER_SIZE - CLKGEN2_rxBufferRead) + CLKGEN2_rxBufferWrite;
        }

        CLKGEN2_EnableRxInt();

    #else

        /* We can only know if there is data in the RX FIFO */
        size = (0u != (CLKGEN2_RX_STATUS_REG & CLKGEN2_STS_RX_FIFO_NOT_EMPTY)) ? 1u : 0u;

    #endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED) */

    return(size);
}


/*******************************************************************************
* Function Name: CLKGEN2_GetTxBufferSize
********************************************************************************
*
* Summary:
*  Returns the number of bytes/words of data currently held in the TX buffer.
*  If TX Software Buffer not used then function return 0 - if FIFO empty, 1 - if
*  FIFO not full, 4 - if FIFO full. In another case function return size of TX
*  Software Buffer.
*
* Parameters:
*  None.
*
* Return:
*  Integer count of the number of bytes/words in the TX buffer.
*
* Global variables:
*  CLKGEN2_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer.
*  CLKGEN2_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
uint8  CLKGEN2_GetTxBufferSize(void) 
{
    uint8 size;

    #if(CLKGEN2_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        CLKGEN2_DisableTxInt();

        if(CLKGEN2_txBufferRead == CLKGEN2_txBufferWrite)
        {
            size = 0u;
        }
        else if(CLKGEN2_txBufferRead < CLKGEN2_txBufferWrite)
        {
            size = (CLKGEN2_txBufferWrite - CLKGEN2_txBufferRead);
        }
        else
        {
            size = (CLKGEN2_TX_BUFFER_SIZE - CLKGEN2_txBufferRead) + CLKGEN2_txBufferWrite;
        }

        CLKGEN2_EnableTxInt();

    #else

        size = CLKGEN2_TX_STATUS_REG;

        if(0u != (size & CLKGEN2_STS_TX_FIFO_EMPTY))
        {
            size = 0u;
        }
        else if(0u != (size & CLKGEN2_STS_TX_FIFO_NOT_FULL))
        {
            size = 1u;
        }
        else
        {
            size = CLKGEN2_FIFO_SIZE;
        }

    #endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED) */

    return(size);
}


/*******************************************************************************
* Function Name: CLKGEN2_ClearRxBuffer
********************************************************************************
*
* Summary:
*  Clear the RX RAM buffer by setting the read and write pointers both to zero.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  CLKGEN2_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer, modified every function
*  call - resets to zero.
*  CLKGEN2_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer, modified every function call -
*  resets to zero.
*
* Theory:
*  Setting the pointers to zero makes the system believe there is no data to
*  read and writing will resume at address 0 overwriting any data that may have
*  remained in the RAM.
*
* Side Effects:
*  Any received data not read from the RAM buffer will be lost when overwritten.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN2_ClearRxBuffer(void) 
{
    /* Clear Hardware RX FIFO */
    while(0u !=(CLKGEN2_RX_STATUS_REG & CLKGEN2_STS_RX_FIFO_NOT_EMPTY))
    {
        (void) CY_GET_REG8(CLKGEN2_RXDATA_PTR);
    }

    #if(CLKGEN2_RX_SOFTWARE_BUF_ENABLED)
        /* Disable RX interrupt to protect global veriables */
        CLKGEN2_DisableRxInt();

        CLKGEN2_rxBufferFull  = 0u;
        CLKGEN2_rxBufferRead  = 0u;
        CLKGEN2_rxBufferWrite = 0u;

        CLKGEN2_EnableRxInt();
    #endif /* (CLKGEN2_RX_SOFTWARE_BUF_ENABLED) */
}


/*******************************************************************************
* Function Name: CLKGEN2_ClearTxBuffer
********************************************************************************
*
* Summary:
*  Clear the TX RAM buffer by setting the read and write pointers both to zero.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  CLKGEN2_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer, modified every function
*  call - resets to zero.
*  CLKGEN2_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer, modified every function call -
*  resets to zero.
*
* Theory:
*  Setting the pointers to zero makes the system believe there is no data to
*  read and writing will resume at address 0 overwriting any data that may have
*  remained in the RAM.
*
* Side Effects:
*  Any data not yet transmitted from the RAM buffer will be lost when
*  overwritten.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN2_ClearTxBuffer(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    /* Clear TX FIFO */
    CLKGEN2_AUX_CONTROL_DP0_REG |= ((uint8)  CLKGEN2_TX_FIFO_CLR);
    CLKGEN2_AUX_CONTROL_DP0_REG &= ((uint8) ~CLKGEN2_TX_FIFO_CLR);

    #if(CLKGEN2_USE_SECOND_DATAPATH)
        /* Clear TX FIFO for 2nd Datapath */
        CLKGEN2_AUX_CONTROL_DP1_REG |= ((uint8)  CLKGEN2_TX_FIFO_CLR);
        CLKGEN2_AUX_CONTROL_DP1_REG &= ((uint8) ~CLKGEN2_TX_FIFO_CLR);
    #endif /* (CLKGEN2_USE_SECOND_DATAPATH) */
    CyExitCriticalSection(enableInterrupts);

    #if(CLKGEN2_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        CLKGEN2_DisableTxInt();

        CLKGEN2_txBufferFull  = 0u;
        CLKGEN2_txBufferRead  = 0u;
        CLKGEN2_txBufferWrite = 0u;

        /* Buffer is EMPTY: disable TX FIFO NOT FULL interrupt */
        CLKGEN2_TX_STATUS_MASK_REG &= ((uint8) ~CLKGEN2_STS_TX_FIFO_NOT_FULL);

        CLKGEN2_EnableTxInt();
    #endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED) */
}


#if(0u != CLKGEN2_BIDIRECTIONAL_MODE)
    /*******************************************************************************
    * Function Name: CLKGEN2_TxEnable
    ********************************************************************************
    *
    * Summary:
    *  If the SPI master is configured to use a single bi-directional pin then this
    *  will set the bi-directional pin to transmit.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void CLKGEN2_TxEnable(void) 
    {
        CLKGEN2_CONTROL_REG |= CLKGEN2_CTRL_TX_SIGNAL_EN;
    }


    /*******************************************************************************
    * Function Name: CLKGEN2_TxDisable
    ********************************************************************************
    *
    * Summary:
    *  If the SPI master is configured to use a single bi-directional pin then this
    *  will set the bi-directional pin to receive.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void CLKGEN2_TxDisable(void) 
    {
        CLKGEN2_CONTROL_REG &= ((uint8) ~CLKGEN2_CTRL_TX_SIGNAL_EN);
    }

#endif /* (0u != CLKGEN2_BIDIRECTIONAL_MODE) */


/*******************************************************************************
* Function Name: CLKGEN2_PutArray
********************************************************************************
*
* Summary:
*  Write available data from ROM/RAM to the TX buffer while space is available
*  in the TX buffer. Keep trying until all data is passed to the TX buffer.
*
* Parameters:
*  *buffer: Pointer to the location in RAM containing the data to send
*  byteCount: The number of bytes to move to the transmit buffer.
*
* Return:
*  None.
*
* Side Effects:
*  Will stay in this routine until all data has been sent.  May get locked in
*  this loop if data is not being initiated by the master if there is not
*  enough room in the TX FIFO.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN2_PutArray(const uint8 buffer[], uint8 byteCount)
                                                                          
{
    uint8 bufIndex;

    bufIndex = 0u;

    while(byteCount > 0u)
    {
        CLKGEN2_WriteTxData(buffer[bufIndex]);
        bufIndex++;
        byteCount--;
    }
}


/*******************************************************************************
* Function Name: CLKGEN2_ClearFIFO
********************************************************************************
*
* Summary:
*  Clear the RX and TX FIFO's of all data for a fresh start.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
void CLKGEN2_ClearFIFO(void) 
{
    uint8 enableInterrupts;

    /* Clear Hardware RX FIFO */
    while(0u !=(CLKGEN2_RX_STATUS_REG & CLKGEN2_STS_RX_FIFO_NOT_EMPTY))
    {
        (void) CY_GET_REG8(CLKGEN2_RXDATA_PTR);
    }

    enableInterrupts = CyEnterCriticalSection();
    /* Clear TX FIFO */
    CLKGEN2_AUX_CONTROL_DP0_REG |= ((uint8)  CLKGEN2_TX_FIFO_CLR);
    CLKGEN2_AUX_CONTROL_DP0_REG &= ((uint8) ~CLKGEN2_TX_FIFO_CLR);

    #if(CLKGEN2_USE_SECOND_DATAPATH)
        /* Clear TX FIFO for 2nd Datapath */
        CLKGEN2_AUX_CONTROL_DP1_REG |= ((uint8)  CLKGEN2_TX_FIFO_CLR);
        CLKGEN2_AUX_CONTROL_DP1_REG &= ((uint8) ~CLKGEN2_TX_FIFO_CLR);
    #endif /* (CLKGEN2_USE_SECOND_DATAPATH) */
    CyExitCriticalSection(enableInterrupts);
}


/* Following functions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects.
*/


/*******************************************************************************
* Function Name: CLKGEN2_EnableInt
********************************************************************************
*
* Summary:
*  Enable internal interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN2_EnableInt(void) 
{
    CLKGEN2_EnableRxInt();
    CLKGEN2_EnableTxInt();
}


/*******************************************************************************
* Function Name: CLKGEN2_DisableInt
********************************************************************************
*
* Summary:
*  Disable internal interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void CLKGEN2_DisableInt(void) 
{
    CLKGEN2_DisableTxInt();
    CLKGEN2_DisableRxInt();
}


/*******************************************************************************
* Function Name: CLKGEN2_SetInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void CLKGEN2_SetInterruptMode(uint8 intSrc) 
{
    CLKGEN2_TX_STATUS_MASK_REG  = (intSrc & ((uint8) ~CLKGEN2_STS_SPI_IDLE));
    CLKGEN2_RX_STATUS_MASK_REG  =  intSrc;
}


/*******************************************************************************
* Function Name: CLKGEN2_ReadStatus
********************************************************************************
*
* Summary:
*  Read the status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the status register.
*
* Global variables:
*  CLKGEN2_swStatus - used to store in software status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the status register for error detection
*  and flow control.
*
* Side Effects:
*  Clear status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 CLKGEN2_ReadStatus(void) 
{
    uint8 tmpStatus;

    #if(CLKGEN2_TX_SOFTWARE_BUF_ENABLED || CLKGEN2_RX_SOFTWARE_BUF_ENABLED)

        CLKGEN2_DisableInt();

        tmpStatus  = CLKGEN2_GET_STATUS_RX(CLKGEN2_swStatusRx);
        tmpStatus |= CLKGEN2_GET_STATUS_TX(CLKGEN2_swStatusTx);
        tmpStatus &= ((uint8) ~CLKGEN2_STS_SPI_IDLE);

        CLKGEN2_swStatusTx = 0u;
        CLKGEN2_swStatusRx = 0u;

        CLKGEN2_EnableInt();

    #else

        tmpStatus  = CLKGEN2_RX_STATUS_REG;
        tmpStatus |= CLKGEN2_TX_STATUS_REG;
        tmpStatus &= ((uint8) ~CLKGEN2_STS_SPI_IDLE);

    #endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED || CLKGEN2_RX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/* [] END OF FILE */
