/*******************************************************************************
* File Name: CLKGEN2.h
* Version 2.50
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the SPI Master Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SPIM_CLKGEN2_H)
#define CY_SPIM_CLKGEN2_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define CLKGEN2_INTERNAL_CLOCK             (0u)

#if(0u != CLKGEN2_INTERNAL_CLOCK)
    #include "CLKGEN2_IntClock.h"
#endif /* (0u != CLKGEN2_INTERNAL_CLOCK) */

#define CLKGEN2_MODE                       (1u)
#define CLKGEN2_DATA_WIDTH                 (8u)
#define CLKGEN2_MODE_USE_ZERO              (1u)
#define CLKGEN2_BIDIRECTIONAL_MODE         (0u)

/* Internal interrupt handling */
#define CLKGEN2_TX_BUFFER_SIZE             (4u)
#define CLKGEN2_RX_BUFFER_SIZE             (4u)
#define CLKGEN2_INTERNAL_TX_INT_ENABLED    (0u)
#define CLKGEN2_INTERNAL_RX_INT_ENABLED    (0u)

#define CLKGEN2_SINGLE_REG_SIZE            (8u)
#define CLKGEN2_USE_SECOND_DATAPATH        (CLKGEN2_DATA_WIDTH > CLKGEN2_SINGLE_REG_SIZE)

#define CLKGEN2_FIFO_SIZE                  (4u)
#define CLKGEN2_TX_SOFTWARE_BUF_ENABLED    ((0u != CLKGEN2_INTERNAL_TX_INT_ENABLED) && \
                                                     (CLKGEN2_TX_BUFFER_SIZE > CLKGEN2_FIFO_SIZE))

#define CLKGEN2_RX_SOFTWARE_BUF_ENABLED    ((0u != CLKGEN2_INTERNAL_RX_INT_ENABLED) && \
                                                     (CLKGEN2_RX_BUFFER_SIZE > CLKGEN2_FIFO_SIZE))


/***************************************
*        Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
    uint8 cntrPeriod;
} CLKGEN2_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  CLKGEN2_Init(void)                           ;
void  CLKGEN2_Enable(void)                         ;
void  CLKGEN2_Start(void)                          ;
void  CLKGEN2_Stop(void)                           ;

void  CLKGEN2_EnableTxInt(void)                    ;
void  CLKGEN2_EnableRxInt(void)                    ;
void  CLKGEN2_DisableTxInt(void)                   ;
void  CLKGEN2_DisableRxInt(void)                   ;

void  CLKGEN2_Sleep(void)                          ;
void  CLKGEN2_Wakeup(void)                         ;
void  CLKGEN2_SaveConfig(void)                     ;
void  CLKGEN2_RestoreConfig(void)                  ;

void  CLKGEN2_SetTxInterruptMode(uint8 intSrc)     ;
void  CLKGEN2_SetRxInterruptMode(uint8 intSrc)     ;
uint8 CLKGEN2_ReadTxStatus(void)                   ;
uint8 CLKGEN2_ReadRxStatus(void)                   ;
void  CLKGEN2_WriteTxData(uint8 txData)  \
                                                            ;
uint8 CLKGEN2_ReadRxData(void) \
                                                            ;
uint8 CLKGEN2_GetRxBufferSize(void)                ;
uint8 CLKGEN2_GetTxBufferSize(void)                ;
void  CLKGEN2_ClearRxBuffer(void)                  ;
void  CLKGEN2_ClearTxBuffer(void)                  ;
void  CLKGEN2_ClearFIFO(void)                              ;
void  CLKGEN2_PutArray(const uint8 buffer[], uint8 byteCount) \
                                                            ;

#if(0u != CLKGEN2_BIDIRECTIONAL_MODE)
    void  CLKGEN2_TxEnable(void)                   ;
    void  CLKGEN2_TxDisable(void)                  ;
#endif /* (0u != CLKGEN2_BIDIRECTIONAL_MODE) */

CY_ISR_PROTO(CLKGEN2_TX_ISR);
CY_ISR_PROTO(CLKGEN2_RX_ISR);


/***************************************
*   Variable with external linkage
***************************************/

extern uint8 CLKGEN2_initVar;


/***************************************
*           API Constants
***************************************/

#define CLKGEN2_TX_ISR_NUMBER     ((uint8) (CLKGEN2_TxInternalInterrupt__INTC_NUMBER))
#define CLKGEN2_RX_ISR_NUMBER     ((uint8) (CLKGEN2_RxInternalInterrupt__INTC_NUMBER))

#define CLKGEN2_TX_ISR_PRIORITY   ((uint8) (CLKGEN2_TxInternalInterrupt__INTC_PRIOR_NUM))
#define CLKGEN2_RX_ISR_PRIORITY   ((uint8) (CLKGEN2_RxInternalInterrupt__INTC_PRIOR_NUM))


/***************************************
*    Initial Parameter Constants
***************************************/

#define CLKGEN2_INT_ON_SPI_DONE    ((uint8) (0u   << CLKGEN2_STS_SPI_DONE_SHIFT))
#define CLKGEN2_INT_ON_TX_EMPTY    ((uint8) (0u   << CLKGEN2_STS_TX_FIFO_EMPTY_SHIFT))
#define CLKGEN2_INT_ON_TX_NOT_FULL ((uint8) (0u << \
                                                                           CLKGEN2_STS_TX_FIFO_NOT_FULL_SHIFT))
#define CLKGEN2_INT_ON_BYTE_COMP   ((uint8) (0u  << CLKGEN2_STS_BYTE_COMPLETE_SHIFT))
#define CLKGEN2_INT_ON_SPI_IDLE    ((uint8) (0u   << CLKGEN2_STS_SPI_IDLE_SHIFT))

/* Disable TX_NOT_FULL if software buffer is used */
#define CLKGEN2_INT_ON_TX_NOT_FULL_DEF ((CLKGEN2_TX_SOFTWARE_BUF_ENABLED) ? \
                                                                        (0u) : (CLKGEN2_INT_ON_TX_NOT_FULL))

/* TX interrupt mask */
#define CLKGEN2_TX_INIT_INTERRUPTS_MASK    (CLKGEN2_INT_ON_SPI_DONE  | \
                                                     CLKGEN2_INT_ON_TX_EMPTY  | \
                                                     CLKGEN2_INT_ON_TX_NOT_FULL_DEF | \
                                                     CLKGEN2_INT_ON_BYTE_COMP | \
                                                     CLKGEN2_INT_ON_SPI_IDLE)

#define CLKGEN2_INT_ON_RX_FULL         ((uint8) (0u << \
                                                                          CLKGEN2_STS_RX_FIFO_FULL_SHIFT))
#define CLKGEN2_INT_ON_RX_NOT_EMPTY    ((uint8) (0u << \
                                                                          CLKGEN2_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define CLKGEN2_INT_ON_RX_OVER         ((uint8) (0u << \
                                                                          CLKGEN2_STS_RX_FIFO_OVERRUN_SHIFT))

/* RX interrupt mask */
#define CLKGEN2_RX_INIT_INTERRUPTS_MASK    (CLKGEN2_INT_ON_RX_FULL      | \
                                                     CLKGEN2_INT_ON_RX_NOT_EMPTY | \
                                                     CLKGEN2_INT_ON_RX_OVER)
/* Nubmer of bits to receive/transmit */
#define CLKGEN2_BITCTR_INIT            (((uint8) (CLKGEN2_DATA_WIDTH << 1u)) - 1u)


/***************************************
*             Registers
***************************************/
#if(CY_PSOC3 || CY_PSOC5)
    #define CLKGEN2_TXDATA_REG (* (reg8 *) \
                                                CLKGEN2_BSPIM_sR8_Dp_u0__F0_REG)
    #define CLKGEN2_TXDATA_PTR (  (reg8 *) \
                                                CLKGEN2_BSPIM_sR8_Dp_u0__F0_REG)
    #define CLKGEN2_RXDATA_REG (* (reg8 *) \
                                                CLKGEN2_BSPIM_sR8_Dp_u0__F1_REG)
    #define CLKGEN2_RXDATA_PTR (  (reg8 *) \
                                                CLKGEN2_BSPIM_sR8_Dp_u0__F1_REG)
#else   /* PSOC4 */
    #if(CLKGEN2_USE_SECOND_DATAPATH)
        #define CLKGEN2_TXDATA_REG (* (reg16 *) \
                                          CLKGEN2_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define CLKGEN2_TXDATA_PTR (  (reg16 *) \
                                          CLKGEN2_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define CLKGEN2_RXDATA_REG (* (reg16 *) \
                                          CLKGEN2_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
        #define CLKGEN2_RXDATA_PTR (  (reg16 *) \
                                          CLKGEN2_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
    #else
        #define CLKGEN2_TXDATA_REG (* (reg8 *) \
                                                CLKGEN2_BSPIM_sR8_Dp_u0__F0_REG)
        #define CLKGEN2_TXDATA_PTR (  (reg8 *) \
                                                CLKGEN2_BSPIM_sR8_Dp_u0__F0_REG)
        #define CLKGEN2_RXDATA_REG (* (reg8 *) \
                                                CLKGEN2_BSPIM_sR8_Dp_u0__F1_REG)
        #define CLKGEN2_RXDATA_PTR (  (reg8 *) \
                                                CLKGEN2_BSPIM_sR8_Dp_u0__F1_REG)
    #endif /* (CLKGEN2_USE_SECOND_DATAPATH) */
#endif     /* (CY_PSOC3 || CY_PSOC5) */

#define CLKGEN2_AUX_CONTROL_DP0_REG (* (reg8 *) \
                                        CLKGEN2_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)
#define CLKGEN2_AUX_CONTROL_DP0_PTR (  (reg8 *) \
                                        CLKGEN2_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)

#if(CLKGEN2_USE_SECOND_DATAPATH)
    #define CLKGEN2_AUX_CONTROL_DP1_REG  (* (reg8 *) \
                                        CLKGEN2_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
    #define CLKGEN2_AUX_CONTROL_DP1_PTR  (  (reg8 *) \
                                        CLKGEN2_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
#endif /* (CLKGEN2_USE_SECOND_DATAPATH) */

#define CLKGEN2_COUNTER_PERIOD_REG     (* (reg8 *) CLKGEN2_BSPIM_BitCounter__PERIOD_REG)
#define CLKGEN2_COUNTER_PERIOD_PTR     (  (reg8 *) CLKGEN2_BSPIM_BitCounter__PERIOD_REG)
#define CLKGEN2_COUNTER_CONTROL_REG    (* (reg8 *) CLKGEN2_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)
#define CLKGEN2_COUNTER_CONTROL_PTR    (  (reg8 *) CLKGEN2_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)

#define CLKGEN2_TX_STATUS_REG          (* (reg8 *) CLKGEN2_BSPIM_TxStsReg__STATUS_REG)
#define CLKGEN2_TX_STATUS_PTR          (  (reg8 *) CLKGEN2_BSPIM_TxStsReg__STATUS_REG)
#define CLKGEN2_RX_STATUS_REG          (* (reg8 *) CLKGEN2_BSPIM_RxStsReg__STATUS_REG)
#define CLKGEN2_RX_STATUS_PTR          (  (reg8 *) CLKGEN2_BSPIM_RxStsReg__STATUS_REG)

#define CLKGEN2_CONTROL_REG            (* (reg8 *) \
                                      CLKGEN2_BSPIM_BidirMode_CtrlReg__CONTROL_REG)
#define CLKGEN2_CONTROL_PTR            (  (reg8 *) \
                                      CLKGEN2_BSPIM_BidirMode_CtrlReg__CONTROL_REG)

#define CLKGEN2_TX_STATUS_MASK_REG     (* (reg8 *) CLKGEN2_BSPIM_TxStsReg__MASK_REG)
#define CLKGEN2_TX_STATUS_MASK_PTR     (  (reg8 *) CLKGEN2_BSPIM_TxStsReg__MASK_REG)
#define CLKGEN2_RX_STATUS_MASK_REG     (* (reg8 *) CLKGEN2_BSPIM_RxStsReg__MASK_REG)
#define CLKGEN2_RX_STATUS_MASK_PTR     (  (reg8 *) CLKGEN2_BSPIM_RxStsReg__MASK_REG)

#define CLKGEN2_TX_STATUS_ACTL_REG     (* (reg8 *) CLKGEN2_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define CLKGEN2_TX_STATUS_ACTL_PTR     (  (reg8 *) CLKGEN2_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define CLKGEN2_RX_STATUS_ACTL_REG     (* (reg8 *) CLKGEN2_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)
#define CLKGEN2_RX_STATUS_ACTL_PTR     (  (reg8 *) CLKGEN2_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)

#if(CLKGEN2_USE_SECOND_DATAPATH)
    #define CLKGEN2_AUX_CONTROLDP1     (CLKGEN2_AUX_CONTROL_DP1_REG)
#endif /* (CLKGEN2_USE_SECOND_DATAPATH) */


/***************************************
*       Register Constants
***************************************/

/* Status Register Definitions */
#define CLKGEN2_STS_SPI_DONE_SHIFT             (0x00u)
#define CLKGEN2_STS_TX_FIFO_EMPTY_SHIFT        (0x01u)
#define CLKGEN2_STS_TX_FIFO_NOT_FULL_SHIFT     (0x02u)
#define CLKGEN2_STS_BYTE_COMPLETE_SHIFT        (0x03u)
#define CLKGEN2_STS_SPI_IDLE_SHIFT             (0x04u)
#define CLKGEN2_STS_RX_FIFO_FULL_SHIFT         (0x04u)
#define CLKGEN2_STS_RX_FIFO_NOT_EMPTY_SHIFT    (0x05u)
#define CLKGEN2_STS_RX_FIFO_OVERRUN_SHIFT      (0x06u)

#define CLKGEN2_STS_SPI_DONE           ((uint8) (0x01u << CLKGEN2_STS_SPI_DONE_SHIFT))
#define CLKGEN2_STS_TX_FIFO_EMPTY      ((uint8) (0x01u << CLKGEN2_STS_TX_FIFO_EMPTY_SHIFT))
#define CLKGEN2_STS_TX_FIFO_NOT_FULL   ((uint8) (0x01u << CLKGEN2_STS_TX_FIFO_NOT_FULL_SHIFT))
#define CLKGEN2_STS_BYTE_COMPLETE      ((uint8) (0x01u << CLKGEN2_STS_BYTE_COMPLETE_SHIFT))
#define CLKGEN2_STS_SPI_IDLE           ((uint8) (0x01u << CLKGEN2_STS_SPI_IDLE_SHIFT))
#define CLKGEN2_STS_RX_FIFO_FULL       ((uint8) (0x01u << CLKGEN2_STS_RX_FIFO_FULL_SHIFT))
#define CLKGEN2_STS_RX_FIFO_NOT_EMPTY  ((uint8) (0x01u << CLKGEN2_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define CLKGEN2_STS_RX_FIFO_OVERRUN    ((uint8) (0x01u << CLKGEN2_STS_RX_FIFO_OVERRUN_SHIFT))

/* TX and RX masks for clear on read bits */
#define CLKGEN2_TX_STS_CLR_ON_RD_BYTES_MASK    (0x09u)
#define CLKGEN2_RX_STS_CLR_ON_RD_BYTES_MASK    (0x40u)

/* StatusI Register Interrupt Enable Control Bits */
/* As defined by the Register map for the AUX Control Register */
#define CLKGEN2_INT_ENABLE     (0x10u) /* Enable interrupt from statusi */
#define CLKGEN2_TX_FIFO_CLR    (0x01u) /* F0 - TX FIFO */
#define CLKGEN2_RX_FIFO_CLR    (0x02u) /* F1 - RX FIFO */
#define CLKGEN2_FIFO_CLR       (CLKGEN2_TX_FIFO_CLR | CLKGEN2_RX_FIFO_CLR)

/* Bit Counter (7-bit) Control Register Bit Definitions */
/* As defined by the Register map for the AUX Control Register */
#define CLKGEN2_CNTR_ENABLE    (0x20u) /* Enable CNT7 */

/* Bi-Directional mode control bit */
#define CLKGEN2_CTRL_TX_SIGNAL_EN  (0x01u)

/* Datapath Auxillary Control Register definitions */
#define CLKGEN2_AUX_CTRL_FIFO0_CLR         (0x01u)
#define CLKGEN2_AUX_CTRL_FIFO1_CLR         (0x02u)
#define CLKGEN2_AUX_CTRL_FIFO0_LVL         (0x04u)
#define CLKGEN2_AUX_CTRL_FIFO1_LVL         (0x08u)
#define CLKGEN2_STATUS_ACTL_INT_EN_MASK    (0x10u)

/* Component disabled */
#define CLKGEN2_DISABLED   (0u)


/***************************************
*       Macros
***************************************/

/* Returns true if componentn enabled */
#define CLKGEN2_IS_ENABLED (0u != (CLKGEN2_TX_STATUS_ACTL_REG & CLKGEN2_INT_ENABLE))

/* Retuns TX status register */
#define CLKGEN2_GET_STATUS_TX(swTxSts) ( (uint8)(CLKGEN2_TX_STATUS_REG | \
                                                          ((swTxSts) & CLKGEN2_TX_STS_CLR_ON_RD_BYTES_MASK)) )
/* Retuns RX status register */
#define CLKGEN2_GET_STATUS_RX(swRxSts) ( (uint8)(CLKGEN2_RX_STATUS_REG | \
                                                          ((swRxSts) & CLKGEN2_RX_STS_CLR_ON_RD_BYTES_MASK)) )


/***************************************
* The following code is DEPRECATED and 
* should not be used in new projects.
***************************************/

#define CLKGEN2_WriteByte   CLKGEN2_WriteTxData
#define CLKGEN2_ReadByte    CLKGEN2_ReadRxData
void  CLKGEN2_SetInterruptMode(uint8 intSrc)       ;
uint8 CLKGEN2_ReadStatus(void)                     ;
void  CLKGEN2_EnableInt(void)                      ;
void  CLKGEN2_DisableInt(void)                     ;

#define CLKGEN2_TXDATA                 (CLKGEN2_TXDATA_REG)
#define CLKGEN2_RXDATA                 (CLKGEN2_RXDATA_REG)
#define CLKGEN2_AUX_CONTROLDP0         (CLKGEN2_AUX_CONTROL_DP0_REG)
#define CLKGEN2_TXBUFFERREAD           (CLKGEN2_txBufferRead)
#define CLKGEN2_TXBUFFERWRITE          (CLKGEN2_txBufferWrite)
#define CLKGEN2_RXBUFFERREAD           (CLKGEN2_rxBufferRead)
#define CLKGEN2_RXBUFFERWRITE          (CLKGEN2_rxBufferWrite)

#define CLKGEN2_COUNTER_PERIOD         (CLKGEN2_COUNTER_PERIOD_REG)
#define CLKGEN2_COUNTER_CONTROL        (CLKGEN2_COUNTER_CONTROL_REG)
#define CLKGEN2_STATUS                 (CLKGEN2_TX_STATUS_REG)
#define CLKGEN2_CONTROL                (CLKGEN2_CONTROL_REG)
#define CLKGEN2_STATUS_MASK            (CLKGEN2_TX_STATUS_MASK_REG)
#define CLKGEN2_STATUS_ACTL            (CLKGEN2_TX_STATUS_ACTL_REG)

#define CLKGEN2_INIT_INTERRUPTS_MASK  (CLKGEN2_INT_ON_SPI_DONE     | \
                                                CLKGEN2_INT_ON_TX_EMPTY     | \
                                                CLKGEN2_INT_ON_TX_NOT_FULL_DEF  | \
                                                CLKGEN2_INT_ON_RX_FULL      | \
                                                CLKGEN2_INT_ON_RX_NOT_EMPTY | \
                                                CLKGEN2_INT_ON_RX_OVER      | \
                                                CLKGEN2_INT_ON_BYTE_COMP)
                                                
#define CLKGEN2_DataWidth                  (CLKGEN2_DATA_WIDTH)
#define CLKGEN2_InternalClockUsed          (CLKGEN2_INTERNAL_CLOCK)
#define CLKGEN2_InternalTxInterruptEnabled (CLKGEN2_INTERNAL_TX_INT_ENABLED)
#define CLKGEN2_InternalRxInterruptEnabled (CLKGEN2_INTERNAL_RX_INT_ENABLED)
#define CLKGEN2_ModeUseZero                (CLKGEN2_MODE_USE_ZERO)
#define CLKGEN2_BidirectionalMode          (CLKGEN2_BIDIRECTIONAL_MODE)
#define CLKGEN2_Mode                       (CLKGEN2_MODE)
#define CLKGEN2_DATAWIDHT                  (CLKGEN2_DATA_WIDTH)
#define CLKGEN2_InternalInterruptEnabled   (0u)

#define CLKGEN2_TXBUFFERSIZE   (CLKGEN2_TX_BUFFER_SIZE)
#define CLKGEN2_RXBUFFERSIZE   (CLKGEN2_RX_BUFFER_SIZE)

#define CLKGEN2_TXBUFFER       CLKGEN2_txBuffer
#define CLKGEN2_RXBUFFER       CLKGEN2_rxBuffer

#endif /* (CY_SPIM_CLKGEN2_H) */


/* [] END OF FILE */
