/*******************************************************************************
* File Name: CLKGEN2_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CLKGEN2_PVT.h"

static CLKGEN2_BACKUP_STRUCT CLKGEN2_backup =
{
    CLKGEN2_DISABLED,
    CLKGEN2_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: CLKGEN2_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CLKGEN2_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: CLKGEN2_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CLKGEN2_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: CLKGEN2_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  CLKGEN2_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN2_Sleep(void) 
{
    /* Save components enable state */
    CLKGEN2_backup.enableState = ((uint8) CLKGEN2_IS_ENABLED);

    CLKGEN2_Stop();
}


/*******************************************************************************
* Function Name: CLKGEN2_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  CLKGEN2_backup - used when non-retention registers are restored.
*  CLKGEN2_txBufferWrite - modified every function call - resets to
*  zero.
*  CLKGEN2_txBufferRead - modified every function call - resets to
*  zero.
*  CLKGEN2_rxBufferWrite - modified every function call - resets to
*  zero.
*  CLKGEN2_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CLKGEN2_Wakeup(void) 
{
    #if(CLKGEN2_RX_SOFTWARE_BUF_ENABLED)
        CLKGEN2_rxBufferFull  = 0u;
        CLKGEN2_rxBufferRead  = 0u;
        CLKGEN2_rxBufferWrite = 0u;
    #endif /* (CLKGEN2_RX_SOFTWARE_BUF_ENABLED) */

    #if(CLKGEN2_TX_SOFTWARE_BUF_ENABLED)
        CLKGEN2_txBufferFull  = 0u;
        CLKGEN2_txBufferRead  = 0u;
        CLKGEN2_txBufferWrite = 0u;
    #endif /* (CLKGEN2_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    CLKGEN2_ClearFIFO();

    /* Restore components block enable state */
    if(0u != CLKGEN2_backup.enableState)
    {
        CLKGEN2_Enable();
    }
}


/* [] END OF FILE */
