/*******************************************************************************
* File Name: DSPSPI_PM.c
* Version 2.70
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "DSPSPI_PVT.h"

static DSPSPI_BACKUP_STRUCT DSPSPI_backup = 
{
    DSPSPI_DISABLED,
    DSPSPI_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: DSPSPI_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DSPSPI_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: DSPSPI_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DSPSPI_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: DSPSPI_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPI Slave Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  DSPSPI_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void DSPSPI_Sleep(void) 
{
    /* Save components enable state */
    if ((DSPSPI_TX_STATUS_ACTL_REG & DSPSPI_INT_ENABLE) != 0u)
    {
        DSPSPI_backup.enableState = 1u;
    }
    else /* Components block is disabled */
    {
        DSPSPI_backup.enableState = 0u;
    }

    DSPSPI_Stop();

}


/*******************************************************************************
* Function Name: DSPSPI_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  DSPSPI_backup - used when non-retention registers are restored.
*  DSPSPI_txBufferWrite - modified every function call - resets to
*  zero.
*  DSPSPI_txBufferRead - modified every function call - resets to
*  zero.
*  DSPSPI_rxBufferWrite - modified every function call - resets to
*  zero.
*  DSPSPI_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void DSPSPI_Wakeup(void) 
{
    #if (DSPSPI_TX_SOFTWARE_BUF_ENABLED)
        DSPSPI_txBufferFull = 0u;
        DSPSPI_txBufferRead = 0u;
        DSPSPI_txBufferWrite = 0u;
    #endif /* DSPSPI_TX_SOFTWARE_BUF_ENABLED */

    #if (DSPSPI_RX_SOFTWARE_BUF_ENABLED)
        DSPSPI_rxBufferFull = 0u;
        DSPSPI_rxBufferRead = 0u;
        DSPSPI_rxBufferWrite = 0u;
    #endif /* DSPSPI_RX_SOFTWARE_BUF_ENABLED */

    DSPSPI_ClearFIFO();

    /* Restore components block enable state */
    if (DSPSPI_backup.enableState != 0u)
    {
         /* Components block was enabled */
         DSPSPI_Enable();
    } /* Do nothing if components block was disabled */
}


/* [] END OF FILE */
