/*******************************************************************************
* File Name: LEDDRIVER_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "LEDDRIVER_PVT.h"

static LEDDRIVER_BACKUP_STRUCT LEDDRIVER_backup =
{
    LEDDRIVER_DISABLED,
    LEDDRIVER_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: LEDDRIVER_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void LEDDRIVER_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: LEDDRIVER_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void LEDDRIVER_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: LEDDRIVER_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  LEDDRIVER_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void LEDDRIVER_Sleep(void) 
{
    /* Save components enable state */
    LEDDRIVER_backup.enableState = ((uint8) LEDDRIVER_IS_ENABLED);

    LEDDRIVER_Stop();
}


/*******************************************************************************
* Function Name: LEDDRIVER_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  LEDDRIVER_backup - used when non-retention registers are restored.
*  LEDDRIVER_txBufferWrite - modified every function call - resets to
*  zero.
*  LEDDRIVER_txBufferRead - modified every function call - resets to
*  zero.
*  LEDDRIVER_rxBufferWrite - modified every function call - resets to
*  zero.
*  LEDDRIVER_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void LEDDRIVER_Wakeup(void) 
{
    #if(LEDDRIVER_RX_SOFTWARE_BUF_ENABLED)
        LEDDRIVER_rxBufferFull  = 0u;
        LEDDRIVER_rxBufferRead  = 0u;
        LEDDRIVER_rxBufferWrite = 0u;
    #endif /* (LEDDRIVER_RX_SOFTWARE_BUF_ENABLED) */

    #if(LEDDRIVER_TX_SOFTWARE_BUF_ENABLED)
        LEDDRIVER_txBufferFull  = 0u;
        LEDDRIVER_txBufferRead  = 0u;
        LEDDRIVER_txBufferWrite = 0u;
    #endif /* (LEDDRIVER_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    LEDDRIVER_ClearFIFO();

    /* Restore components block enable state */
    if(0u != LEDDRIVER_backup.enableState)
    {
        LEDDRIVER_Enable();
    }
}


/* [] END OF FILE */
