/*******************************************************************************
* File Name: SPIM_LEDDRIVER_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SPIM_LEDDRIVER_PVT.h"

static SPIM_LEDDRIVER_BACKUP_STRUCT SPIM_LEDDRIVER_backup =
{
    SPIM_LEDDRIVER_DISABLED,
    SPIM_LEDDRIVER_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SPIM_LEDDRIVER_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_LEDDRIVER_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_LEDDRIVER_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_LEDDRIVER_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_LEDDRIVER_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_LEDDRIVER_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_LEDDRIVER_Sleep(void) 
{
    /* Save components enable state */
    SPIM_LEDDRIVER_backup.enableState = ((uint8) SPIM_LEDDRIVER_IS_ENABLED);

    SPIM_LEDDRIVER_Stop();
}


/*******************************************************************************
* Function Name: SPIM_LEDDRIVER_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_LEDDRIVER_backup - used when non-retention registers are restored.
*  SPIM_LEDDRIVER_txBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_LEDDRIVER_txBufferRead - modified every function call - resets to
*  zero.
*  SPIM_LEDDRIVER_rxBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_LEDDRIVER_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_LEDDRIVER_Wakeup(void) 
{
    #if(SPIM_LEDDRIVER_RX_SOFTWARE_BUF_ENABLED)
        SPIM_LEDDRIVER_rxBufferFull  = 0u;
        SPIM_LEDDRIVER_rxBufferRead  = 0u;
        SPIM_LEDDRIVER_rxBufferWrite = 0u;
    #endif /* (SPIM_LEDDRIVER_RX_SOFTWARE_BUF_ENABLED) */

    #if(SPIM_LEDDRIVER_TX_SOFTWARE_BUF_ENABLED)
        SPIM_LEDDRIVER_txBufferFull  = 0u;
        SPIM_LEDDRIVER_txBufferRead  = 0u;
        SPIM_LEDDRIVER_txBufferWrite = 0u;
    #endif /* (SPIM_LEDDRIVER_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SPIM_LEDDRIVER_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SPIM_LEDDRIVER_backup.enableState)
    {
        SPIM_LEDDRIVER_Enable();
    }
}


/* [] END OF FILE */
