/*******************************************************************************
* File Name: SPIS_DSP_PM.c
* Version 2.70
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SPIS_DSP_PVT.h"

static SPIS_DSP_BACKUP_STRUCT SPIS_DSP_backup = 
{
    SPIS_DSP_DISABLED,
    SPIS_DSP_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SPIS_DSP_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIS_DSP_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIS_DSP_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIS_DSP_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIS_DSP_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPI Slave Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIS_DSP_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIS_DSP_Sleep(void) 
{
    /* Save components enable state */
    if ((SPIS_DSP_TX_STATUS_ACTL_REG & SPIS_DSP_INT_ENABLE) != 0u)
    {
        SPIS_DSP_backup.enableState = 1u;
    }
    else /* Components block is disabled */
    {
        SPIS_DSP_backup.enableState = 0u;
    }

    SPIS_DSP_Stop();

}


/*******************************************************************************
* Function Name: SPIS_DSP_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIS_DSP_backup - used when non-retention registers are restored.
*  SPIS_DSP_txBufferWrite - modified every function call - resets to
*  zero.
*  SPIS_DSP_txBufferRead - modified every function call - resets to
*  zero.
*  SPIS_DSP_rxBufferWrite - modified every function call - resets to
*  zero.
*  SPIS_DSP_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIS_DSP_Wakeup(void) 
{
    #if (SPIS_DSP_TX_SOFTWARE_BUF_ENABLED)
        SPIS_DSP_txBufferFull = 0u;
        SPIS_DSP_txBufferRead = 0u;
        SPIS_DSP_txBufferWrite = 0u;
    #endif /* SPIS_DSP_TX_SOFTWARE_BUF_ENABLED */

    #if (SPIS_DSP_RX_SOFTWARE_BUF_ENABLED)
        SPIS_DSP_rxBufferFull = 0u;
        SPIS_DSP_rxBufferRead = 0u;
        SPIS_DSP_rxBufferWrite = 0u;
    #endif /* SPIS_DSP_RX_SOFTWARE_BUF_ENABLED */

    SPIS_DSP_ClearFIFO();

    /* Restore components block enable state */
    if (SPIS_DSP_backup.enableState != 0u)
    {
         /* Components block was enabled */
         SPIS_DSP_Enable();
    } /* Do nothing if components block was disabled */
}


/* [] END OF FILE */
