/*******************************************************************************
* File Name: SYSCLK.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_SYSCLK_H) /* Pins SYSCLK_H */
#define CY_PINS_SYSCLK_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "SYSCLK_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 SYSCLK__PORT == 15 && ((SYSCLK__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    SYSCLK_Write(uint8 value);
void    SYSCLK_SetDriveMode(uint8 mode);
uint8   SYSCLK_ReadDataReg(void);
uint8   SYSCLK_Read(void);
void    SYSCLK_SetInterruptMode(uint16 position, uint16 mode);
uint8   SYSCLK_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the SYSCLK_SetDriveMode() function.
     *  @{
     */
        #define SYSCLK_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define SYSCLK_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define SYSCLK_DM_RES_UP          PIN_DM_RES_UP
        #define SYSCLK_DM_RES_DWN         PIN_DM_RES_DWN
        #define SYSCLK_DM_OD_LO           PIN_DM_OD_LO
        #define SYSCLK_DM_OD_HI           PIN_DM_OD_HI
        #define SYSCLK_DM_STRONG          PIN_DM_STRONG
        #define SYSCLK_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define SYSCLK_MASK               SYSCLK__MASK
#define SYSCLK_SHIFT              SYSCLK__SHIFT
#define SYSCLK_WIDTH              1u

/* Interrupt constants */
#if defined(SYSCLK__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in SYSCLK_SetInterruptMode() function.
     *  @{
     */
        #define SYSCLK_INTR_NONE      (uint16)(0x0000u)
        #define SYSCLK_INTR_RISING    (uint16)(0x0001u)
        #define SYSCLK_INTR_FALLING   (uint16)(0x0002u)
        #define SYSCLK_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define SYSCLK_INTR_MASK      (0x01u) 
#endif /* (SYSCLK__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define SYSCLK_PS                     (* (reg8 *) SYSCLK__PS)
/* Data Register */
#define SYSCLK_DR                     (* (reg8 *) SYSCLK__DR)
/* Port Number */
#define SYSCLK_PRT_NUM                (* (reg8 *) SYSCLK__PRT) 
/* Connect to Analog Globals */                                                  
#define SYSCLK_AG                     (* (reg8 *) SYSCLK__AG)                       
/* Analog MUX bux enable */
#define SYSCLK_AMUX                   (* (reg8 *) SYSCLK__AMUX) 
/* Bidirectional Enable */                                                        
#define SYSCLK_BIE                    (* (reg8 *) SYSCLK__BIE)
/* Bit-mask for Aliased Register Access */
#define SYSCLK_BIT_MASK               (* (reg8 *) SYSCLK__BIT_MASK)
/* Bypass Enable */
#define SYSCLK_BYP                    (* (reg8 *) SYSCLK__BYP)
/* Port wide control signals */                                                   
#define SYSCLK_CTL                    (* (reg8 *) SYSCLK__CTL)
/* Drive Modes */
#define SYSCLK_DM0                    (* (reg8 *) SYSCLK__DM0) 
#define SYSCLK_DM1                    (* (reg8 *) SYSCLK__DM1)
#define SYSCLK_DM2                    (* (reg8 *) SYSCLK__DM2) 
/* Input Buffer Disable Override */
#define SYSCLK_INP_DIS                (* (reg8 *) SYSCLK__INP_DIS)
/* LCD Common or Segment Drive */
#define SYSCLK_LCD_COM_SEG            (* (reg8 *) SYSCLK__LCD_COM_SEG)
/* Enable Segment LCD */
#define SYSCLK_LCD_EN                 (* (reg8 *) SYSCLK__LCD_EN)
/* Slew Rate Control */
#define SYSCLK_SLW                    (* (reg8 *) SYSCLK__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define SYSCLK_PRTDSI__CAPS_SEL       (* (reg8 *) SYSCLK__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define SYSCLK_PRTDSI__DBL_SYNC_IN    (* (reg8 *) SYSCLK__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define SYSCLK_PRTDSI__OE_SEL0        (* (reg8 *) SYSCLK__PRTDSI__OE_SEL0) 
#define SYSCLK_PRTDSI__OE_SEL1        (* (reg8 *) SYSCLK__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define SYSCLK_PRTDSI__OUT_SEL0       (* (reg8 *) SYSCLK__PRTDSI__OUT_SEL0) 
#define SYSCLK_PRTDSI__OUT_SEL1       (* (reg8 *) SYSCLK__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define SYSCLK_PRTDSI__SYNC_OUT       (* (reg8 *) SYSCLK__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(SYSCLK__SIO_CFG)
    #define SYSCLK_SIO_HYST_EN        (* (reg8 *) SYSCLK__SIO_HYST_EN)
    #define SYSCLK_SIO_REG_HIFREQ     (* (reg8 *) SYSCLK__SIO_REG_HIFREQ)
    #define SYSCLK_SIO_CFG            (* (reg8 *) SYSCLK__SIO_CFG)
    #define SYSCLK_SIO_DIFF           (* (reg8 *) SYSCLK__SIO_DIFF)
#endif /* (SYSCLK__SIO_CFG) */

/* Interrupt Registers */
#if defined(SYSCLK__INTSTAT)
    #define SYSCLK_INTSTAT            (* (reg8 *) SYSCLK__INTSTAT)
    #define SYSCLK_SNAP               (* (reg8 *) SYSCLK__SNAP)
    
	#define SYSCLK_0_INTTYPE_REG 		(* (reg8 *) SYSCLK__0__INTTYPE)
#endif /* (SYSCLK__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_SYSCLK_H */


/* [] END OF FILE */
