/*******************************************************************************
* File Name: TempMonSMBusSlave.h
* Version 5.20
*
* Description:
*  This file provides constants and parameter values and API definition for the
*  SM/PM Bus Component.
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_SMBusSlave_TempMonSMBusSlave_H)
#define CY_SMBusSlave_TempMonSMBusSlave_H

#include "cytypes.h"
#include "TempMonSMBusSlave_I2C.h"

/*`#START ADDITIONAL_SMBUS_SLAVE_H_INCLUDE`*/

/*`#END`*/


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define TempMonSMBusSlave_MODE                       (0u)
#define TempMonSMBusSlave_RECEIVE_BYTE_PROTOCOL      (0u)
#define TempMonSMBusSlave_SMB_ALERT_PIN_ENABLED      (0u)
#define TempMonSMBusSlave_ENABLE_PEC                 (0u)

/* AlertReg_Sync_ctrl_reg__REMOVED is defined if SMBALERT# pin is enabled and
* left floating.
*/
#ifndef TempMonSMBusSlave_AlertReg_Sync_ctrl_reg__REMOVED
    #define TempMonSMBusSlave_SMBALERT_PIN_EXISTS    (TempMonSMBusSlave_SMB_ALERT_PIN_ENABLED != 0u)
#else
    #define TempMonSMBusSlave_SMBALERT_PIN_EXISTS    (0u != 0u)
#endif /* TempMonSMBusSlave_AlertReg_Sync_ctrl_reg__REMOVED */

#define TempMonSMBusSlave_RECEIVE_BYTE_PROT_ENABLED  (TempMonSMBusSlave_RECEIVE_BYTE_PROTOCOL != 0u)
#define TempMonSMBusSlave_SUPPORT_PEC                (TempMonSMBusSlave_ENABLE_PEC != 0u)

#if (CY_PSOC4)
    #define TempMonSMBusSlave_SW_ADDR_DECODE         (TempMonSMBusSlave_I2C_CHECK_I2C_ACCEPT_ADDRESS_CONST)
#else
    #define TempMonSMBusSlave_SW_ADDR_DECODE         (TempMonSMBusSlave_I2C_SW_ADRR_DECODE)
#endif /* CY_PSOC4 */


/***************************************
*     Data Struct Definitions
***************************************/

typedef struct
{
    uint8 read;          /* r/w flag - 1=read 0=write */
    uint8 commandCode;   /* SMBus/PMBus command code */
    uint8 page;          /* PMBus page (if applicable) */
    uint8 length;        /* bytes transferred */
    uint8 payload[65u];  /* payload for the transaction */
} TempMonSMBusSlave_TRANSACTION_STRUCT;


/* Define each command based on the inputs from the customizer. */
#if defined (__GNUC__)
    typedef struct __attribute__ ((packed))
#else
    typedef __packed struct
#endif /* (__GNUC__) */
{
    uint32 SMBUS_REGS_SIG;
    uint16 FLASH_CRC;
} TempMonSMBusSlave_REGS;


/***************************************
*        Function Prototypes
***************************************/

/* General APIs */
void  TempMonSMBusSlave_Init(void)                          ;
void  TempMonSMBusSlave_Enable(void)                        ;
void  TempMonSMBusSlave_Start(void)                         ;
void  TempMonSMBusSlave_Stop(void)                          ;

/* Transaction Specific APIs */
void  TempMonSMBusSlave_CompleteTransaction(void)           ;
TempMonSMBusSlave_TRANSACTION_STRUCT * TempMonSMBusSlave_GetNextTransaction(void)
                                                           ;
/* Protocol Specific APIs */
#if (TempMonSMBusSlave_SMBALERT_PIN_EXISTS)
    void  TempMonSMBusSlave_HandleSmbAlertResponse(void)    ;
    #if (CY_PSOC4)
        void TempMonSMBusSlave_SetSmbAlert(uint8 state)     ;
    #endif /* CY_PSOC4 */
#endif /* TempMonSMBusSlave_SMBALERT_PIN_EXISTS */

#if (TempMonSMBusSlave_RECEIVE_BYTE_PROT_ENABLED)
    uint8  TempMonSMBusSlave_GetReceiveByteResponse(void)   ;
#endif /* TempMonSMBusSlave_RECEIVE_BYTE_PROT_ENABLED */

void  TempMonSMBusSlave_HandleBusError(uint8 errorCode)     ;

/* Register Save/Restore APIs */
uint8 TempMonSMBusSlave_StoreUserAll(const uint8 * flashRegs)  ;
uint8 TempMonSMBusSlave_RestoreUserAll(const uint8 * flashRegs);
uint8 TempMonSMBusSlave_EraseUserAll(void)                     ;
uint8 TempMonSMBusSlave_RestoreDefaultAll(void)                ;
uint8 TempMonSMBusSlave_StoreComponentAll(void)                ;
uint8 TempMonSMBusSlave_RestoreComponentAll(void)              ;

/* Unit Conversion Helper APIs */
float32 TempMonSMBusSlave_Lin11ToFloat(uint16 linear11)        ;
uint16  TempMonSMBusSlave_FloatToLin11(float32 floatvar)       ;
float32 TempMonSMBusSlave_Lin16ToFloat(uint16 linear16, int8 inExponent)   
                                                              ;
uint16  TempMonSMBusSlave_FloatToLin16(float32 floatvar, int8 outExponent)
                                                              ;

/* Interrupt handlers */
CY_ISR_PROTO(TempMonSMBusSlave_ISR);
CY_ISR_PROTO(TempMonSMBusSlave_TIMEOUT_ISR);


/***************************************
*   Variables with external linkage
***************************************/

extern uint8 TempMonSMBusSlave_initVar;

/* Operating Memory Register Store (RAM) */
extern TempMonSMBusSlave_REGS TempMonSMBusSlave_regs;

/* Default Memory Register Store (Flash) */
extern const TempMonSMBusSlave_REGS CYCODE TempMonSMBusSlave_regsDefault;


/***************************************
*           API Constants
***************************************/

#define TempMonSMBusSlave_SMBUS_MODE                 (TempMonSMBusSlave_MODE == 0u)
#define TempMonSMBusSlave_PMBUS_MODE                 (TempMonSMBusSlave_MODE != 0u)
#define TempMonSMBusSlave_SIGNATURE                  (0x000055AAu)
#define TempMonSMBusSlave_REGS_SIZE                  (sizeof(TempMonSMBusSlave_REGS))
#define TempMonSMBusSlave_ADDR_POS                   (0x01u)
#define TempMonSMBusSlave_ADDR_MASK                  (0xFEu)
#define TempMonSMBusSlave_READ_FLAG                  (0x01u)

/* Default return value for TempMonSMBusSlave_GetReceiveByteResponse() */
#define TempMonSMBusSlave_RET_UNDEFINED              (0xFFu)

/* Constants for TempMonSMBusSlave_SetSmbAlertMode() */
#if (TempMonSMBusSlave_SMBALERT_PIN_EXISTS)   
    #define TempMonSMBusSlave_AUTO_MODE              (0x01u)
    #define TempMonSMBusSlave_MANUAL_MODE            (0x02u)
    #define TempMonSMBusSlave_DO_NOTHING             (0x00u)
#endif /* TempMonSMBusSlave_SMBALERT_PIN_EXISTS */

#define TempMonSMBusSlave_NEG_EXP_MIN                (-16)

/* Defines related to CRC calculation */
#define TempMonSMBusSlave_CRC_SEED                   (0xFFFFu)
#define TempMonSMBusSlave_CRC_BYTE_SHIFT             (0x8u)
#define TempMonSMBusSlave_CRC_BYTE_MASK              (0xFFu)

/* Error codes for TempMonSMBusSlave_HandleBusError() */
#define TempMonSMBusSlave_ERR_READ_FLAG              (0x01u)
#define TempMonSMBusSlave_ERR_RD_TOO_MANY_BYTES      (0x02u)
#define TempMonSMBusSlave_ERR_WR_TOO_MANY_BYTES      (0x04u)
#define TempMonSMBusSlave_ERR_UNSUPPORTED_CMD        (0x08u)
#define TempMonSMBusSlave_ERR_INVALID_DATA           (0x10u)
#define TempMonSMBusSlave_ERR_TIMEOUT                (0x20u)
#define TempMonSMBusSlave_ERR_WR_TOO_FEW_BYTES       (0x40u)
#define TempMonSMBusSlave_ERR_CORRUPTED_DATA         (0x80u)

/* Constants dedicated for work with FLASH */
#define TempMonSMBusSlave_FLASH_ROW_SIZE             (CYDEV_FLS_ROW_SIZE)
#define TempMonSMBusSlave_FLASH_END_ADDR             (CYDEV_FLS_SIZE - 1u)
#define TempMonSMBusSlave_FLASH_ROW_MASK             (0x0000FF00u)
#define TempMonSMBusSlave_FLASH_ARRYID_MASK          (0x00FF0000u)
#define TempMonSMBusSlave_BYTE_SHIFT                 (8u)
#define TempMonSMBusSlave_TWO_BYTES_SHIFT            (16u)


/***************************************
*    Initial Parameter Constants
***************************************/

#define TempMonSMBusSlave_NUM_COMMANDS               (0x00u)
#define TempMonSMBusSlave_MAX_PAGES                  (8u)
#define TempMonSMBusSlave_SMB_ALERT_MODE_INIT        (1u)
#define TempMonSMBusSlave_DEFAULT_ADDRESS            (32u)
#define TempMonSMBusSlave_ALERT_RESPONSE_ADDR        (0x0Cu)
#define TempMonSMBusSlave_GENERAL_CALL_ADDR          (0x00u)


/***************************************
*              Registers
***************************************/

#if (TempMonSMBusSlave_SMBALERT_PIN_EXISTS)
    #if(CY_PSOC4)
        #define TempMonSMBusSlave_SMBALERT_PIN_REG   (* (reg32 *) TempMonSMBusSlave_smbalert_pin__DR)
        #define TempMonSMBusSlave_SMBALERT_PIN_MASK     (uint32)  TempMonSMBusSlave_smbalert_pin__MASK
    #else
        #define TempMonSMBusSlave_SMBALERT_PIN_REG   (* (reg8  *) TempMonSMBusSlave_AlertReg_Sync_ctrl_reg__CONTROL_REG)
    #endif /* CY_PSOC4 */
#endif /* TempMonSMBusSlave_SMBALERT_PIN_EXISTS */


/***************************************
*              Macros
***************************************/

/* Enables I2C interrupt. Interrupts are required for most operations. */
#define TempMonSMBusSlave_EnableInt()                TempMonSMBusSlave_I2C_EnableInt()

/* Disables the I2C interrupts. Normally calling this is not required since the
* Stop() function disables the interrupt.
* Side Effects: If the I2C interrupt is disabled and the master is addressing
* the current slave, the bus will be locked until the interrupt is re-enabled.
*/
#define TempMonSMBusSlave_DisableInt()               TempMonSMBusSlave_I2C_DisableInt()

/* Sets the SM/PM Bus slave address. The address is the 7-bit right-justified
* address for the primary device. Does not include the R/W bit.
*/
#if (TempMonSMBusSlave_SW_ADDR_DECODE)
    /* When software address detection is enabled, the address is converted to an 8-bit
    * address with the R/W bit set to 0.
    */
    #define TempMonSMBusSlave_SetAddress(address)    \
        (TempMonSMBusSlave_address = (uint8)((address) << TempMonSMBusSlave_ADDR_POS))
#else
    #if (CY_PSOC4)
        #define TempMonSMBusSlave_SetAddress(address)    TempMonSMBusSlave_I2CSlaveSetAddress(address)
    #else
        #define TempMonSMBusSlave_SetAddress(address)    TempMonSMBusSlave_I2C_SlaveSetAddress(address)
    #endif /* CY_PSOC4 */
#endif

/* Returns the number of transaction records in the transaction queue */
#define TempMonSMBusSlave_GetTransactionCount()      TempMonSMBusSlave_trActiveCount

#if (TempMonSMBusSlave_SMBALERT_PIN_EXISTS)

    /* Sets the the Alert Response Address (ARA). The address is the 7-bit
    * right-justified address. Does not include the R/W bit.
    * The address is converted to 8-bit address witgh the R/W bit set to 1.
    */
    #define TempMonSMBusSlave_SetAlertResponseAddress(address)   (TempMonSMBusSlave_alertResponseAddress = \
        (uint8)((address) << TempMonSMBusSlave_ADDR_POS) | TempMonSMBusSlave_READ_FLAG)
    
    /* Sets the SMBALERT# signal to the specified state. If the device pulled
    * SMBALERT# low, it will acknowledge the ARA with the primary address of 
    * the device. On PSoC 4 this implemented as a function with critical section
    * protection of the read-modify-write to a port data register.
    */
    #if (!CY_PSOC4)
        #define TempMonSMBusSlave_SetSmbAlert(state)             (TempMonSMBusSlave_SMBALERT_PIN_REG = (state))
    #endif /* CY_PSOC4 */
    
    /* Determines how the component responds to a SMBus master read at the ARA.
    *  alertMode (uint8): A byte that defines SMBALERT pin mode.
    *   TempMonSMBusSlave_DO_NOTHING (0x00u) - no action will be taken
    *   TempMonSMBusSlave_AUTO_MODE  (0x01u) - SMBALERT# pin will be 
    *   de-asserted once the device responds to the ARA.
    *   TempMonSMBusSlave_MANUAL_MODE (0x02u) - the HandleSmbAlertResponse()
    *   API will be called allowing the user to implement its own algorithm
    *   in the custom user code section.
    */
    #define TempMonSMBusSlave_SetSmbAlertMode(alertMode)         (TempMonSMBusSlave_smbAlertMode = (alertMode))

#endif /* TempMonSMBusSlave_SMBALERT_PIN_EXISTS */

/* Converts the Flash address to Flash row */
#define TempMonSMBusSlave_FL_ADDR_TO_ROW(addr) \
    ((uint8)(((addr) & TempMonSMBusSlave_FLASH_ROW_MASK) >> TempMonSMBusSlave_BYTE_SHIFT))

/* Converts Flash row to Flash Array ID */
#define TempMonSMBusSlave_FL_ADDR_TO_ARRAYID(addr) \
    ((uint8)(((addr) & TempMonSMBusSlave_FLASH_ARRYID_MASK) >> TempMonSMBusSlave_TWO_BYTES_SHIFT))

#define TempMonSMBusSlave_SIZE_TO_ROW(size)  ((uint8)((size) >> TempMonSMBusSlave_BYTE_SHIFT) + 1u)

#define TempMonSMBusSlave_MAKE_FLASH_ADDR(arrayId, row) \
    (((uint32)(arrayId) << TempMonSMBusSlave_TWO_BYTES_SHIFT) | ((uint32)(row) << TempMonSMBusSlave_BYTE_SHIFT))

#endif /* CY_SMBusSlave_TempMonSMBusSlave_H */

/* [] END OF FILE */
