/*******************************************************************************
* File Name: TempMonSMBusSlave_I2C.c
* Version 3.50
*
* Description:
*  This file provides the source code of APIs for the I2C component.
*  The actual protocol and operation code resides in the interrupt service
*  routine file.
*
*******************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TempMonSMBusSlave_I2C_PVT.h"


/**********************************
*      System variables
**********************************/

uint8 TempMonSMBusSlave_I2C_initVar = 0u; /* Defines if component was initialized */

volatile uint8 TempMonSMBusSlave_I2C_state;  /* Current state of I2C FSM */


/*******************************************************************************
* Function Name: TempMonSMBusSlave_I2C_Init
********************************************************************************
*
* Summary:
*  Initializes I2C registers with initial values provided from customizer.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  None.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void TempMonSMBusSlave_I2C_Init(void) 
{
#if (TempMonSMBusSlave_I2C_FF_IMPLEMENTED)
    /* Configure fixed function block */
    TempMonSMBusSlave_I2C_CFG_REG  = TempMonSMBusSlave_I2C_DEFAULT_CFG;
    TempMonSMBusSlave_I2C_XCFG_REG = TempMonSMBusSlave_I2C_DEFAULT_XCFG;
    TempMonSMBusSlave_I2C_ADDR_REG = TempMonSMBusSlave_I2C_DEFAULT_ADDR;
    TempMonSMBusSlave_I2C_CLKDIV1_REG = LO8(TempMonSMBusSlave_I2C_DEFAULT_DIVIDE_FACTOR);
    TempMonSMBusSlave_I2C_CLKDIV2_REG = HI8(TempMonSMBusSlave_I2C_DEFAULT_DIVIDE_FACTOR);

#else
    uint8 intState;

    /* Configure control and interrupt sources */
    TempMonSMBusSlave_I2C_CFG_REG      = TempMonSMBusSlave_I2C_DEFAULT_CFG;
    TempMonSMBusSlave_I2C_INT_MASK_REG = TempMonSMBusSlave_I2C_DEFAULT_INT_MASK;

    /* Enable interrupt generation in status */
    intState = CyEnterCriticalSection();
    TempMonSMBusSlave_I2C_INT_ENABLE_REG |= TempMonSMBusSlave_I2C_INTR_ENABLE;
    CyExitCriticalSection(intState);

    /* Configure bit counter */
    #if (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED)
        TempMonSMBusSlave_I2C_PERIOD_REG = TempMonSMBusSlave_I2C_DEFAULT_PERIOD;
    #endif  /* (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED) */

    /* Configure clock generator */
    #if (TempMonSMBusSlave_I2C_MODE_MASTER_ENABLED)
        TempMonSMBusSlave_I2C_MCLK_PRD_REG = TempMonSMBusSlave_I2C_DEFAULT_MCLK_PRD;
        TempMonSMBusSlave_I2C_MCLK_CMP_REG = TempMonSMBusSlave_I2C_DEFAULT_MCLK_CMP;
    #endif /* (TempMonSMBusSlave_I2C_MODE_MASTER_ENABLED) */
#endif /* (TempMonSMBusSlave_I2C_FF_IMPLEMENTED) */

#if (TempMonSMBusSlave_I2C_TIMEOUT_ENABLED)
    TempMonSMBusSlave_I2C_TimeoutInit();
#endif /* (TempMonSMBusSlave_I2C_TIMEOUT_ENABLED) */

    /* Configure internal interrupt */
    CyIntDisable    (TempMonSMBusSlave_I2C_ISR_NUMBER);
    CyIntSetPriority(TempMonSMBusSlave_I2C_ISR_NUMBER, TempMonSMBusSlave_I2C_ISR_PRIORITY);
    #if (TempMonSMBusSlave_I2C_INTERN_I2C_INTR_HANDLER)
        (void) CyIntSetVector(TempMonSMBusSlave_I2C_ISR_NUMBER, &TempMonSMBusSlave_I2C_ISR);
    #endif /* (TempMonSMBusSlave_I2C_INTERN_I2C_INTR_HANDLER) */

    /* Set FSM to default state */
    TempMonSMBusSlave_I2C_state = TempMonSMBusSlave_I2C_SM_IDLE;

#if (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED)
    /* Clear status and buffers index */
    TempMonSMBusSlave_I2C_slStatus = 0u;
    TempMonSMBusSlave_I2C_slRdBufIndex = 0u;
    TempMonSMBusSlave_I2C_slWrBufIndex = 0u;

    /* Configure matched address */
    TempMonSMBusSlave_I2C_SlaveSetAddress(TempMonSMBusSlave_I2C_DEFAULT_ADDR);
#endif /* (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED) */

#if (TempMonSMBusSlave_I2C_MODE_MASTER_ENABLED)
    /* Clear status and buffers index */
    TempMonSMBusSlave_I2C_mstrStatus = 0u;
    TempMonSMBusSlave_I2C_mstrRdBufIndex = 0u;
    TempMonSMBusSlave_I2C_mstrWrBufIndex = 0u;
#endif /* (TempMonSMBusSlave_I2C_MODE_MASTER_ENABLED) */
}


/*******************************************************************************
* Function Name: TempMonSMBusSlave_I2C_Enable
********************************************************************************
*
* Summary:
*  Enables I2C operations.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  None.
*
*******************************************************************************/
void TempMonSMBusSlave_I2C_Enable(void) 
{
#if (TempMonSMBusSlave_I2C_FF_IMPLEMENTED)
    uint8 intState;

    /* Enable power to block */
    intState = CyEnterCriticalSection();
    TempMonSMBusSlave_I2C_ACT_PWRMGR_REG  |= TempMonSMBusSlave_I2C_ACT_PWR_EN;
    TempMonSMBusSlave_I2C_STBY_PWRMGR_REG |= TempMonSMBusSlave_I2C_STBY_PWR_EN;
    CyExitCriticalSection(intState);
#else
    #if (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED)
        /* Enable bit counter */
        uint8 intState = CyEnterCriticalSection();
        TempMonSMBusSlave_I2C_COUNTER_AUX_CTL_REG |= TempMonSMBusSlave_I2C_CNT7_ENABLE;
        CyExitCriticalSection(intState);
    #endif /* (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED) */

    /* Enable slave or master bits */
    TempMonSMBusSlave_I2C_CFG_REG |= TempMonSMBusSlave_I2C_ENABLE_MS;
#endif /* (TempMonSMBusSlave_I2C_FF_IMPLEMENTED) */

#if (TempMonSMBusSlave_I2C_TIMEOUT_ENABLED)
    TempMonSMBusSlave_I2C_TimeoutEnable();
#endif /* (TempMonSMBusSlave_I2C_TIMEOUT_ENABLED) */
}


/*******************************************************************************
* Function Name: TempMonSMBusSlave_I2C_Start
********************************************************************************
*
* Summary:
*  Starts the I2C hardware. Enables Active mode power template bits or clock
*  gating as appropriate. It is required to be executed before I2C bus
*  operation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Side Effects:
*  This component automatically enables its interrupt.  If I2C is enabled !
*  without the interrupt enabled, it can lock up the I2C bus.
*
* Global variables:
*  TempMonSMBusSlave_I2C_initVar - This variable is used to check the initial
*                             configuration, modified on the first
*                             function call.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void TempMonSMBusSlave_I2C_Start(void) 
{
    if (0u == TempMonSMBusSlave_I2C_initVar)
    {
        TempMonSMBusSlave_I2C_Init();
        TempMonSMBusSlave_I2C_initVar = 1u; /* Component initialized */
    }

    TempMonSMBusSlave_I2C_Enable();
    TempMonSMBusSlave_I2C_EnableInt();
}


/*******************************************************************************
* Function Name: TempMonSMBusSlave_I2C_Stop
********************************************************************************
*
* Summary:
*  Disables I2C hardware and disables I2C interrupt. Disables Active mode power
*  template bits or clock gating as appropriate.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void TempMonSMBusSlave_I2C_Stop(void) 
{
    TempMonSMBusSlave_I2C_DisableInt();

#if (TempMonSMBusSlave_I2C_TIMEOUT_ENABLED)
    TempMonSMBusSlave_I2C_TimeoutStop();
#endif  /* End (TempMonSMBusSlave_I2C_TIMEOUT_ENABLED) */

#if (TempMonSMBusSlave_I2C_FF_IMPLEMENTED)
    {
        uint8 intState;
        uint16 blockResetCycles;

        /* Store registers effected by block disable */
        TempMonSMBusSlave_I2C_backup.addr    = TempMonSMBusSlave_I2C_ADDR_REG;
        TempMonSMBusSlave_I2C_backup.clkDiv1 = TempMonSMBusSlave_I2C_CLKDIV1_REG;
        TempMonSMBusSlave_I2C_backup.clkDiv2 = TempMonSMBusSlave_I2C_CLKDIV2_REG;

        /* Calculate number of cycles to reset block */
        blockResetCycles = ((uint16) ((uint16) TempMonSMBusSlave_I2C_CLKDIV2_REG << 8u) | TempMonSMBusSlave_I2C_CLKDIV1_REG) + 1u;

        /* Disable block */
        TempMonSMBusSlave_I2C_CFG_REG &= (uint8) ~TempMonSMBusSlave_I2C_CFG_EN_SLAVE;
        /* Wait for block reset before disable power */
        CyDelayCycles((uint32) blockResetCycles);

        /* Disable power to block */
        intState = CyEnterCriticalSection();
        TempMonSMBusSlave_I2C_ACT_PWRMGR_REG  &= (uint8) ~TempMonSMBusSlave_I2C_ACT_PWR_EN;
        TempMonSMBusSlave_I2C_STBY_PWRMGR_REG &= (uint8) ~TempMonSMBusSlave_I2C_STBY_PWR_EN;
        CyExitCriticalSection(intState);

        /* Enable block */
        TempMonSMBusSlave_I2C_CFG_REG |= (uint8) TempMonSMBusSlave_I2C_ENABLE_MS;

        /* Restore registers effected by block disable. Ticket ID#198004 */
        TempMonSMBusSlave_I2C_ADDR_REG    = TempMonSMBusSlave_I2C_backup.addr;
        TempMonSMBusSlave_I2C_ADDR_REG    = TempMonSMBusSlave_I2C_backup.addr;
        TempMonSMBusSlave_I2C_CLKDIV1_REG = TempMonSMBusSlave_I2C_backup.clkDiv1;
        TempMonSMBusSlave_I2C_CLKDIV2_REG = TempMonSMBusSlave_I2C_backup.clkDiv2;
    }
#else

    /* Disable slave or master bits */
    TempMonSMBusSlave_I2C_CFG_REG &= (uint8) ~TempMonSMBusSlave_I2C_ENABLE_MS;

#if (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED)
    {
        /* Disable bit counter */
        uint8 intState = CyEnterCriticalSection();
        TempMonSMBusSlave_I2C_COUNTER_AUX_CTL_REG &= (uint8) ~TempMonSMBusSlave_I2C_CNT7_ENABLE;
        CyExitCriticalSection(intState);
    }
#endif /* (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED) */

    /* Clear interrupt source register */
    (void) TempMonSMBusSlave_I2C_CSR_REG;
#endif /* (TempMonSMBusSlave_I2C_FF_IMPLEMENTED) */

    /* Disable interrupt on stop (enabled by write transaction) */
    TempMonSMBusSlave_I2C_DISABLE_INT_ON_STOP;
    TempMonSMBusSlave_I2C_ClearPendingInt();

    /* Reset FSM to default state */
    TempMonSMBusSlave_I2C_state = TempMonSMBusSlave_I2C_SM_IDLE;

    /* Clear busy statuses */
#if (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED)
    TempMonSMBusSlave_I2C_slStatus &= (uint8) ~(TempMonSMBusSlave_I2C_SSTAT_RD_BUSY | TempMonSMBusSlave_I2C_SSTAT_WR_BUSY);
#endif /* (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED) */
}


/* [] END OF FILE */
