/*******************************************************************************
* File Name: TempMonSMBusSlave_I2C_TMOUT_INT.c
* Version 3.50
*
* Description:
*  This file provides the source code of Interrupt Service Routine (ISR)
*  for the timeout feature of the I2C component.
*
*  Note:
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TempMonSMBusSlave_I2C_PVT.h"
#include "cyapicallbacks.h"


/*******************************************************************************
*  Place your includes, defines and code here
*******************************************************************************/
/* `#START TempMonSMBusSlave_I2C_TMOUT_ISR_intc` */

/* `#END` */


/*******************************************************************************
* Function Name: TempMonSMBusSlave_I2C_TimeoutReset
********************************************************************************
*
* Summary:
*  Resets the component into the known state (default) and enables it.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Reentrant:
*  No
*
*******************************************************************************/
void TempMonSMBusSlave_I2C_TimeoutReset(void) 
{
    /* Reset component into known state (default) */
    TempMonSMBusSlave_I2C_Stop();

    /* `#START TempMonSMBusSlave_I2C_TMOUT_ISR_BEFORE_BUF_RESET` */

    /* `#END` */
    
#ifdef TempMonSMBusSlave_I2C_TIMEOUT_RESET_CALLBACK
    TempMonSMBusSlave_I2C_TimeoutReset_Callback();
#endif /* TempMonSMBusSlave_I2C_TIMEOUT_RESET_CALLBACK */

#if (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED)
    /* Clear status and buffers */
    TempMonSMBusSlave_I2C_SlaveClearReadBuf();
    TempMonSMBusSlave_I2C_SlaveClearWriteBuf();
    (void) TempMonSMBusSlave_I2C_SlaveClearReadStatus();
    (void) TempMonSMBusSlave_I2C_SlaveClearWriteStatus();
#endif /* (TempMonSMBusSlave_I2C_MODE_SLAVE_ENABLED) */

#if (TempMonSMBusSlave_I2C_MODE_MASTER_ENABLED)
    /* Clear status and buffers */
    TempMonSMBusSlave_I2C_MasterClearReadBuf();
    TempMonSMBusSlave_I2C_MasterClearWriteBuf();
    (void) TempMonSMBusSlave_I2C_MasterClearStatus();
#endif /* (TempMonSMBusSlave_I2C_MODE_MASTER_ENABLED) */

    /* Enable component operation */
    TempMonSMBusSlave_I2C_Enable();
    TempMonSMBusSlave_I2C_EnableInt();
}


#if (TempMonSMBusSlave_I2C_TIMEOUT_UDB_ENABLED)
    /*******************************************************************************
    * Function Name: TempMonSMBusSlave_I2C_TMOUT_ISR
    ********************************************************************************
    *
    * Summary:
    *  The handler of the I2C timeout interrupt.
    *  Triggers when SCL or SDA remain in the low state greater than a defined
    *  timeout. Resets the component into the known state and enables it for
    *  the following operations.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    CY_ISR(TempMonSMBusSlave_I2C_TMOUT_ISR)
    {
    #ifdef TempMonSMBusSlave_I2C_TMOUT_ISR_ENTRY_CALLBACK
        TempMonSMBusSlave_I2C_TMOUT_ISR_EntryCallback();
    #endif /* TempMonSMBusSlave_I2C_TMOUT_ISR_ENTRY_CALLBACK */
        
        TempMonSMBusSlave_I2C_TimeoutReset();

    #ifdef TempMonSMBusSlave_I2C_TMOUT_ISR_EXIT_CALLBACK
        TempMonSMBusSlave_I2C_TMOUT_ISR_ExitCallback();
    #endif /* TempMonSMBusSlave_I2C_TMOUT_ISR_EXIT_CALLBACK*/
    }
#endif /* (TempMonSMBusSlave_I2C_TIMEOUT_UDB_ENABLED) */


/* [] END OF FILE */
