/*******************************************************************************
* File Name: TempMonSMBusSlave_INT.c
* Version 5.20
*
* Description:
*  This file provides the source code of the Interrupt Service Routine (ISR)
*  for the SM/PMBus component.
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TempMonSMBusSlave_PVT.h"
#include "cyapicallbacks.h"

/* User section to add header files and variable declarations */
/*`#START VAR_INCLUDE_REGION`*/

/*`#END`*/

static uint8 TempMonSMBusSlave_isCmdReceived = 0u;
static uint8 TempMonSMBusSlave_error = 0u;
        
        
/*******************************************************************************
* Function Name: TempMonSMBusSlave_ISR
********************************************************************************
*
* Summary:
*  The Interrupt Service Routine for the SM/PMBus Interrupt.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Reentrant:
*  No
*
*******************************************************************************/
CY_ISR(TempMonSMBusSlave_ISR)
{
    /* Computed CRC value (after the process runs). For each byte received in a 
    * packet a new CRC is computed. For the first byte in a packet the CRC is
    * reset. The last byte in a packet is a CRC  (PEC) for the packet. The 
    * received PEC is compared with a computed CRC to verify the correctness of
	* the PEC.
    */
    #if (TempMonSMBusSlave_SUPPORT_PEC)
        static uint8 TempMonSMBusSlave_crc_value = 0u;
    #endif /* TempMonSMBusSlave_SUPPORT_PEC */

    uint8 tmpCsr;   /* Local copy of I2C Control/Status Register */
    uint8 newByte;  /* Data byte received in given transaction */

    #ifdef TempMonSMBusSlave_ISR_ENTRY_CALLBACK
        TempMonSMBusSlave_ISR_EntryCallback();
    #endif /* TempMonSMBusSlave_ISR_ENTRY_CALLBACK */

    /* Add your custom code between the following #START and #END tags */
    /* `#START ISR_ENTRY_REGION` */

    /* `#END` */
    
    tmpCsr = TempMonSMBusSlave_I2C_CSR_REG;   /* Make copy as interrupts clear */

    /* Complete write transaction and execute command if Stop bit was received */
    if(TempMonSMBusSlave_I2C_CHECK_STOP_STS(tmpCsr))
    {
        /* The component detects any Stop condition on the bus. Therefore an
        * additional check of the internal FSM state is required to determine
        * whether the host finishes the transaction to the component.
        */
        if(TempMonSMBusSlave_I2C_SM_SL_WR_DATA == TempMonSMBusSlave_I2C_state)
        {
            TempMonSMBusSlave_I2C_DISABLE_INT_ON_STOP;
            TempMonSMBusSlave_I2C_state = TempMonSMBusSlave_I2C_SM_IDLE;
            
            /* Process and execute command */
            TempMonSMBusSlave_isCmdReceived = 0u;
            if(0u == TempMonSMBusSlave_error)
            {
                TempMonSMBusSlave_WriteHandler();
            }
            else
            {
                TempMonSMBusSlave_HandleBusError(TempMonSMBusSlave_error);
            }
        }
    }

    if(TempMonSMBusSlave_I2C_CHECK_BYTE_COMPLETE(tmpCsr))
    {
        if(TempMonSMBusSlave_I2C_CHECK_ADDRESS_STS(tmpCsr))
        {            
            newByte = TempMonSMBusSlave_I2C_DATA_REG;

        #if (TempMonSMBusSlave_SW_ADDR_DECODE)
            if(((newByte & TempMonSMBusSlave_ADDR_MASK) == TempMonSMBusSlave_address) ||
                (newByte == TempMonSMBusSlave_GENERAL_CALL_ADDR))
        #endif /* TempMonSMBusSlave_SW_ADDR_DECODE */
            {
                /* Add your custom code between the following #START and #END tags */
                /* `#START PRIMARY_ADDRESS_MATCH_REGION` */

                /* `#END` */
                
                #ifdef TempMonSMBusSlave_PRIMARY_ADDRESS_MATCH_CALLBACK
                    TempMonSMBusSlave_ISR_PrimaryAddressMatch_Callback();
                #endif /* TempMonSMBusSlave_PRIMARY_ADDRESS_MATCH_CALLBACK */
                
                /* Check for read or write transaction */
                if(0u != (newByte & TempMonSMBusSlave_I2C_READ_FLAG))
                {
                    if(0u != TempMonSMBusSlave_isCmdReceived)
                    {
                        /* Determine if the received command is supported */
                        if(0u == TempMonSMBusSlave_error)
                        {
                            TempMonSMBusSlave_error = TempMonSMBusSlave_ReadHandler();
                            #if (TempMonSMBusSlave_SUPPORT_PEC)
                                newByte ^= TempMonSMBusSlave_crc_value;
                            #endif /* TempMonSMBusSlave_SUPPORT_PEC */
                        }
                    }
                    else
                    {
                        #if(TempMonSMBusSlave_SMBUS_MODE && TempMonSMBusSlave_RECEIVE_BYTE_PROT_ENABLED)

                            /* If command is not received, service the receive byte protocol.
                            * Call user defined API to provide data byte for this transaction.
                            */
                            TempMonSMBusSlave_buffer[0u] = TempMonSMBusSlave_GetReceiveByteResponse();
                            TempMonSMBusSlave_I2C_DATA_REG = TempMonSMBusSlave_buffer[0u];
                            TempMonSMBusSlave_I2C_ACK_AND_TRANSMIT;
                            TempMonSMBusSlave_bufferSize = 1u;
                        #else
                            TempMonSMBusSlave_error = TempMonSMBusSlave_ERR_READ_FLAG;
                        #endif /*TempMonSMBusSlave_SMBUS_MODE && TempMonSMBusSlave_RECEIVE_BYTE_PROT_ENABLED */
                    }
                    if(0u != TempMonSMBusSlave_error)
                    {
                        /* Data Content Fault. Send FFh as host keeps clocking. */
                        TempMonSMBusSlave_I2C_DATA_REG = 0xFFu;
                        TempMonSMBusSlave_I2C_ACK_AND_TRANSMIT;
                    }
                    TempMonSMBusSlave_I2C_state = TempMonSMBusSlave_I2C_SM_SL_RD_DATA;
                }
                else  /* Start of Write transaction, ready to write first byte */
                { 
                    TempMonSMBusSlave_I2C_ENABLE_INT_ON_STOP;
                    TempMonSMBusSlave_I2C_ACK_AND_RECEIVE;
                    TempMonSMBusSlave_I2C_state = TempMonSMBusSlave_I2C_SM_SL_WR_DATA;
                }
                #if (TempMonSMBusSlave_SUPPORT_PEC)
                    TempMonSMBusSlave_crc_value = TempMonSMBusSlave_crc_table[newByte];
                #endif /* TempMonSMBusSlave_SUPPORT_PEC */

                TempMonSMBusSlave_bufferIndex = 0u; /* Reset buffer index */
            }
        #if(TempMonSMBusSlave_SMBALERT_PIN_EXISTS)
            /* When SMBALERT# pin is exposed in the component, it is required
            * to monitor if the master is broadcasting the Alert Response Address.
            * If ARA was detected and SMBALERT# pin is asserted by the device,
            * respond with the device address and handle SMBALERT# pin.
            */
            else if((0u == TempMonSMBusSlave_SMBALERT_PIN_REG) && (newByte == TempMonSMBusSlave_alertResponseAddress))
            {
                #if (TempMonSMBusSlave_SUPPORT_PEC)
                    TempMonSMBusSlave_crc_value  = TempMonSMBusSlave_crc_table[newByte];
                #endif /* TempMonSMBusSlave_SUPPORT_PEC */
            
                TempMonSMBusSlave_I2C_DATA_REG = TempMonSMBusSlave_address;
                TempMonSMBusSlave_I2C_ACK_AND_TRANSMIT;
                TempMonSMBusSlave_buffer[0u] = TempMonSMBusSlave_address;
                TempMonSMBusSlave_bufferSize = 1u;

                switch(TempMonSMBusSlave_smbAlertMode)
                {
                case TempMonSMBusSlave_AUTO_MODE:  
                    TempMonSMBusSlave_SetSmbAlert(1u); /* De-assert SMBALERT# pin (active low) */
                    break;
                case TempMonSMBusSlave_MANUAL_MODE:
                    TempMonSMBusSlave_HandleSmbAlertResponse(); /* Call user provided API to handle SMBALERT# pin */
                    break;
                default:
                    break;  /* DO_NOTHING mode: component takes no action */
                }
                
                /* Move to Read Data state to send last byte (0xFF) */
                TempMonSMBusSlave_I2C_state = TempMonSMBusSlave_I2C_SM_SL_RD_DATA;
                TempMonSMBusSlave_bufferIndex = 0u;  /* Reset buffer index */
            }
        #endif /* TempMonSMBusSlave_SMBALERT_PIN_EXISTS */
            
        #if (TempMonSMBusSlave_SW_ADDR_DECODE)
            else /* No address match */
            {
                TempMonSMBusSlave_I2C_NAK_AND_RECEIVE;   /* NACK received address */
            }
        #endif /* TempMonSMBusSlave_SW_ADDR_DECODE */

        }

        /* Write transaction from master to slave */
        else if(TempMonSMBusSlave_I2C_SM_SL_WR_DATA == TempMonSMBusSlave_I2C_state)
        {
             newByte = TempMonSMBusSlave_I2C_DATA_REG;

            /* Check if command code was received and supported */
            if(0u == TempMonSMBusSlave_isCmdReceived)
            {
                TempMonSMBusSlave_error = TempMonSMBusSlave_CheckCommand(newByte);
                TempMonSMBusSlave_isCmdReceived = 1u;
            }
            /* Data portion of write transaction */
            else
            {
                if(TempMonSMBusSlave_bufferIndex < TempMonSMBusSlave_bufferSize)
                {
                    TempMonSMBusSlave_buffer[TempMonSMBusSlave_bufferIndex] = newByte;
                }
            #if (TempMonSMBusSlave_SUPPORT_PEC)
                else if(TempMonSMBusSlave_bufferIndex == TempMonSMBusSlave_bufferSize)
                {
                    if(newByte != TempMonSMBusSlave_crc_value)
                    {
                        TempMonSMBusSlave_error = TempMonSMBusSlave_ERR_CORRUPTED_DATA;
                    }
                }
            #endif /* TempMonSMBusSlave_SUPPORT_PEC */
                else /* Data Transmission Fault: Host Sends Too Many Bytes */
                {
                    TempMonSMBusSlave_error = TempMonSMBusSlave_ERR_WR_TO_MANY_BYTES;
                }
                ++TempMonSMBusSlave_bufferIndex;
            }

            if(0u == TempMonSMBusSlave_error)
            {
                TempMonSMBusSlave_I2C_ACK_AND_RECEIVE;
                #if (TempMonSMBusSlave_SUPPORT_PEC)
                    TempMonSMBusSlave_crc_value ^= newByte;
                    TempMonSMBusSlave_crc_value = TempMonSMBusSlave_crc_table[TempMonSMBusSlave_crc_value];
                #endif /* TempMonSMBusSlave_SUPPORT_PEC */
            }
            else /* NACK received byte */
            {
                TempMonSMBusSlave_I2C_NAK_AND_RECEIVE;
            }
        }
        /* Read transaction from slave to master */
        else if(TempMonSMBusSlave_I2C_SM_SL_RD_DATA == TempMonSMBusSlave_I2C_state)
        {
            if(TempMonSMBusSlave_I2C_CHECK_DATA_ACK(tmpCsr))
            {
                if(0u == TempMonSMBusSlave_error)
                {
                    #if (TempMonSMBusSlave_SUPPORT_PEC)
                        TempMonSMBusSlave_crc_value ^= TempMonSMBusSlave_buffer[TempMonSMBusSlave_bufferIndex];
                        TempMonSMBusSlave_crc_value = TempMonSMBusSlave_crc_table[TempMonSMBusSlave_crc_value];
                    #endif /* TempMonSMBusSlave_SUPPORT_PEC */
                    
                    /* First byte is sent in address state. Increment index to next byte. */
                    ++TempMonSMBusSlave_bufferIndex;
                    if(TempMonSMBusSlave_bufferIndex < TempMonSMBusSlave_bufferSize)
                    {
                        TempMonSMBusSlave_I2C_DATA_REG = TempMonSMBusSlave_buffer[TempMonSMBusSlave_bufferIndex];
                    }
                #if (TempMonSMBusSlave_SUPPORT_PEC)
                    else if(TempMonSMBusSlave_bufferIndex == TempMonSMBusSlave_bufferSize)
                    {
                        /* Last data byte was sent. Supply PEC. */
                        TempMonSMBusSlave_I2C_DATA_REG = TempMonSMBusSlave_crc_value;
                    }
                #endif /* TempMonSMBusSlave_SUPPORT_PEC */
                    else /* Master attempts to read to many bytes. Send 0xFF and ACK */
                    {
                        TempMonSMBusSlave_I2C_DATA_REG = 0xFFu;
                        TempMonSMBusSlave_error = TempMonSMBusSlave_ERR_RD_TO_MANY_BYTES;
                    }
                }
                else /* Data Content Fault. Send 0xFF and ACK */
                {
                    TempMonSMBusSlave_I2C_DATA_REG = 0xFFu;
                }
                TempMonSMBusSlave_I2C_TRANSMIT_DATA;
            }
            else  /* Last byte NACKed, done */
            {                
                TempMonSMBusSlave_I2C_DATA_REG = 0xFFu;
                TempMonSMBusSlave_I2C_NAK_AND_TRANSMIT;
                TempMonSMBusSlave_I2C_DISABLE_INT_ON_STOP;
                TempMonSMBusSlave_I2C_state = TempMonSMBusSlave_I2C_SM_IDLE;
                
                #ifdef TempMonSMBusSlave_BTLDR_READ_EN
                    TempMonSMBusSlave_btldrStatus |= TempMonSMBusSlave_BTLDR_RD_CMPT;
                #endif /* TempMonSMBusSlave_BTLDR_READ_EN */
                
                TempMonSMBusSlave_isCmdReceived = 0u;
                if(TempMonSMBusSlave_error != 0u)
                {
                    TempMonSMBusSlave_HandleBusError(TempMonSMBusSlave_error);
                    TempMonSMBusSlave_error = 0u;
                }
            }
        }
        else /* This is invalid state and should not occur */
        {
            TempMonSMBusSlave_I2C_NAK_AND_RECEIVE;
        }
    }
    
    #ifdef TempMonSMBusSlave_ISR_EXIT_CALLBACK
        TempMonSMBusSlave_ISR_ExitCallback();
    #endif /* TempMonSMBusSlave_ISR_EXIT_CALLBACK */
}


/*******************************************************************************
* Function Name: TempMonSMBusSlave_TIMEOUT_ISR
********************************************************************************
*
* Summary:
*  Handles a bus timeout occurrence event.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Reentrant:
*  No
*
*******************************************************************************/
CY_ISR(TempMonSMBusSlave_TIMEOUT_ISR)
{
    #ifdef TempMonSMBusSlave_TIMEOUT_ISR_ENTRY_CALLBACK
        TempMonSMBusSlave_TIMEOUT_ISR_EntryCallback();
    #endif /* TempMonSMBusSlave_TIMEOUT_ISR_ENTRY_CALLBACK */
    
    TempMonSMBusSlave_I2C_Stop();
    
    /* Inform user that timeout occurred */
    TempMonSMBusSlave_HandleBusError(TempMonSMBusSlave_ERR_TIMEOUT);
    
    /* Reset all variables */
    TempMonSMBusSlave_trActiveCount = 0u;
    TempMonSMBusSlave_isCmdReceived = 0u;
    TempMonSMBusSlave_error = 0u;
    TempMonSMBusSlave_I2C_Enable();
    TempMonSMBusSlave_EnableInt();

    #ifdef TempMonSMBusSlave_TIMEOUT_ISR_EXIT_CALLBACK
        TempMonSMBusSlave_TIMEOUT_ISR_ExitCallback();
    #endif /* TempMonSMBusSlave_TIMEOUT_ISR_EXIT_CALLBACK */
}


/* [] END OF FILE */
