/*******************************************************************************
* File Name: .h
* Version 5.20
*
* Description:
*  This file provides private constants and parameter values for the SM/PM Bus
*  Slave component.
*
* Note:
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SMBusSlave_PVT_TempMonSMBusSlave_H)
#define CY_SMBusSlave_PVT_TempMonSMBusSlave_H

#include "TempMonSMBusSlave.h"
#include "TempMonSMBusSlave_cmd.h"
#include "TempMonSMBusSlave_I2C_TMOUT.h"


/***************************************
*         API Constants
***************************************/

#define TempMonSMBusSlave_TRANS_QUEUE_SIZE           (1u)
#define TempMonSMBusSlave_MAX_BUFFER_SIZE            (65u)
#define TempMonSMBusSlave_CRC8_LUT_SIZE              (256u)

/***************************************
*       Global variables
***************************************/
    
/* I2C Buffer */
extern uint8 TempMonSMBusSlave_buffer[TempMonSMBusSlave_MAX_BUFFER_SIZE];
extern uint8 TempMonSMBusSlave_bufferIndex;
extern uint8 TempMonSMBusSlave_bufferSize;

extern volatile uint8 TempMonSMBusSlave_I2C_state;

/* I2C Software Address */
#if (TempMonSMBusSlave_SW_ADDR_DECODE)
    extern uint8 TempMonSMBusSlave_address;
#endif  /* (TempMonSMBusSlave_I2C_SW_ADRR_DECODE) */

/* Number of active manual transaction records in Transaction Queue */
extern volatile uint8 TempMonSMBusSlave_trActiveCount;

/* Transaction Queue */
extern TempMonSMBusSlave_TRANSACTION_STRUCT TempMonSMBusSlave_transactionData[TempMonSMBusSlave_TRANS_QUEUE_SIZE];

/* SMB Alert mode and Alert Response */
#if (TempMonSMBusSlave_SMBALERT_PIN_EXISTS)
    extern uint8 TempMonSMBusSlave_smbAlertMode;
    extern uint8 TempMonSMBusSlave_alertResponseAddress;
#endif /* TempMonSMBusSlave_SMBALERT_PIN_EXISTS */

#if (defined(TempMonSMBusSlave_BTLDR_READ_EN) || defined(TempMonSMBusSlave_BTLDR_WRITE_EN))
    extern uint8 TempMonSMBusSlave_btldrStatus;
#endif /* defined(TempMonSMBusSlave_BTLDR_READ_EN) || defined(TempMonSMBusSlave_BTLDR_WRITE_EN) */

#ifdef TempMonSMBusSlave_BTLDR_READ_EN
    extern uint8 TempMonSMBusSlave_btldrReadBuf[TempMonSMBusSlave_MAX_BUFFER_SIZE];
#endif /* TempMonSMBusSlave_BTLDR_READ_EN */

#ifdef TempMonSMBusSlave_BTLDR_WRITE_EN
    extern uint8 TempMonSMBusSlave_btldrWriteBuf[TempMonSMBusSlave_MAX_BUFFER_SIZE];
#endif /* TempMonSMBusSlave_BTLDR_WRITE_EN */

/* Pre-computed CRC-8 data */
#if (TempMonSMBusSlave_SUPPORT_PEC)
    extern const uint8 CYCODE TempMonSMBusSlave_crc_table[TempMonSMBusSlave_CRC8_LUT_SIZE];
#endif /* TempMonSMBusSlave_SUPPORT_PEC */


/***************************************
*           Local Macros
***************************************/

#define TempMonSMBusSlave_ISR_NUMBER                 (TempMonSMBusSlave_I2C_ISR_NUMBER)

#if(CY_PSOC4)
    #define TempMonSMBusSlave_TMOUT_ISR_NUMBER       (TempMonSMBusSlave_TMOUT_INT__INTC_NUMBER)
    #define TempMonSMBusSlave_TMOUT_ISR_PRIORITY     (TempMonSMBusSlave_TMOUT_INT__INTC_PRIOR_NUM)
    
    /* Enables timeout hardware and interrupt */
    #define TempMonSMBusSlave_Timeout_Enable()    \
        do{ \
            TempMonSMBusSlave_I2C_TMOUT_Enable(); \
            CyIntEnable(TempMonSMBusSlave_TMOUT_ISR_NUMBER); \
        }while(0)

    /* Initializes timeout hardware and interrupt */
    #define TempMonSMBusSlave_Timeout_Init() \
        do{ \
            TempMonSMBusSlave_I2C_TMOUT_Init(); \
            CyIntDisable(TempMonSMBusSlave_TMOUT_ISR_NUMBER); \
            CyIntSetPriority(TempMonSMBusSlave_TMOUT_ISR_NUMBER, TempMonSMBusSlave_TMOUT_ISR_PRIORITY); \
        }while(0)
    
    /* Disables timeout hardware and interrupt */
    #define TempMonSMBusSlave_Timeout_Stop() \
        do{ \
            TempMonSMBusSlave_I2C_TMOUT_Stop(); \
            CyIntDisable(TempMonSMBusSlave_TMOUT_ISR_NUMBER); \
            CyIntClearPending(TempMonSMBusSlave_TMOUT_ISR_NUMBER); \
        }while(0)

    #define TempMonSMBusSlave_EnableGeneralCallAddress() \
        (TempMonSMBusSlave_I2C_I2C_CTRL_REG &= (uint32)~TempMonSMBusSlave_I2C_I2C_CTRL_S_GENERAL_IGNORE)
        
    #define TempMonSMBusSlave_I2C_SM_SL_RD_DATA      (TempMonSMBusSlave_I2C_I2C_FSM_SL_RD)
#else
    #define TempMonSMBusSlave_TMOUT_ISR_NUMBER       (TempMonSMBusSlave_I2C_TMOUT_ISR_NUMBER)
#endif /* CY_PSOC4 */


/* Format conversion macro helpers */
#define TempMonSMBusSlave_LIN11_TO_EXP(val)              ((uint8) ((val) >> 11u))
#define TempMonSMBusSlave_LIN11_TO_MAN(val)              ((uint16)((val) & 0x07FFu))
#define TempMonSMBusSlave_EXP_TO_LIN11(val)              ((uint16)((uint16)(val) << 11u))
#define TempMonSMBusSlave_MAN_TO_LIN11(val)              ((uint16)((val) & 0x07FFu))
#define TempMonSMBusSlave_EXP_LIN11_MASK                 (0x1Fu)
#define TempMonSMBusSlave_LIN11_TO_EXP_SIGN(val)         ((((val) & 0x10u) != 0u) ? 1u : 0u)
#define TempMonSMBusSlave_LIN11_TO_MAN_SIGN(val)         ((((val) & 0x0400u) != 0u) ? 1u : 0u)
#define TempMonSMBusSlave_11BIT_2S_COMPLEMENT(val)       (((val) ^ 0x07FFu) + 1u)
#define TempMonSMBusSlave_5BIT_2S_COMPLEMENT(val)        (((val) ^ 0x1Fu) + 1u)
#define TempMonSMBusSlave_FLOAT_10MSB_MAN(val)           ((uint16)(((val) >> 14u) & 0x03FFu) | 0x0200u)
#define TempMonSMBusSlave_FLOAT_16MSB_MAN(val)           ((uint16)((val) >> 8u) | 0x8000u)
#define TempMonSMBusSlave_FLOAT_EXP(val)                 ((uint8)((val) >> 23u))
#define TempMonSMBusSlave_MAX_5BIT_EXP                   (16u)
#define TempMonSMBusSlave_MAX_POWER                      (65536.0f)
#define TempMonSMBusSlave_IEEE754_IMPLICIT_MAGNITUDE     (127)
#define TempMonSMBusSlave_LIN11_EXP_SCALING_FACTOR       (9)
#define TempMonSMBusSlave_LIN16_EXP_SCALING_FACTOR       (15)
#define TempMonSMBusSlave_LIN16_MAN_MAX_VAL              (0xFFFFu)
#define TempMonSMBusSlave_SIGN_EXTEND(val)               ((((val) & 0x10u) != 0u) ? ((val) | 0xE0u) : (val))

/* The following defines are obsolete and are no longer recommended for use */
#define TempMonSMBusSlave_ERR_RD_TO_MANY_BYTES          TempMonSMBusSlave_ERR_RD_TOO_MANY_BYTES
#define TempMonSMBusSlave_ERR_WR_TO_MANY_BYTES          TempMonSMBusSlave_ERR_WR_TOO_MANY_BYTES
#define TempMonSMBusSlave_ERR_WR_TO_FEW_BYTES           TempMonSMBusSlave_ERR_WR_TOO_FEW_BYTES
#define TempMonSMBusSlave_FIRMWARE_MODE                 TempMonSMBusSlave_MANUAL_MODE

#endif /* CY_SMBusSlave_PVT_TempMonSMBusSlave_H */


/* [] END OF FILE */
