/*******************************************************************************
* File Name: TempMonSMBusSlave_cmd.h
* Version 5.20
*
* Description:
*  This file provides constants and parameter values and API definition related
*  to the SM/PMBus command processing.
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_SMBusSlave_TempMonSMBusSlave_cmd_H)
#define CY_SMBusSlave_TempMonSMBusSlave_cmd_H

/*`#START ADDITIONAL_SMBUS_SLAVE_CMD_H_INCLUDE`*/

/*`#END`*/


/***************************************
*   Conditional Compilation Parameters
***************************************/

/* Command list based on customizer settings */


/* Check if the component is bootloader component or project type is loadable */
#if((defined(CYDEV_BOOTLOADER_IO_COMP) && (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface)) || \
    (CYDEV_PROJ_TYPE == CYDEV_PROJ_TYPE_LOADABLE))
    
    /* Check if bootloader commands are enabled */
    #ifdef TempMonSMBusSlave_BOOTLOAD_READ
        #define TempMonSMBusSlave_BTLDR_READ_EN  (1u)
    #endif /* TempMonSMBusSlave_BOOTLOAD_READ */
    #ifdef TempMonSMBusSlave_BOOTLOAD_WRITE
        #define TempMonSMBusSlave_BTLDR_WRITE_EN (1u)
    #endif /* TempMonSMBusSlave_BOOTLOAD_WRITE */

#endif /* (defined(CYDEV_BOOTLOADER_IO_COMP) && (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface)) ||
    (CYDEV_PROJ_TYPE == CYDEV_PROJ_TYPE_LOADABLE) */


/***************************************
*      Data Struct Definitions
***************************************/

#if (CY_PSOC3)
    typedef struct
#elif defined (__GNUC__)
    typedef struct __attribute__ ((packed))
#else
    typedef __packed struct
#endif /* (__GNUC__) */
{
    uint8   command;
    uint8   dataLength;
    uint8 * dataPtr;
    uint8   cmdProp;               /* command properties (read/write/page-indexed) */
} TempMonSMBusSlave_CMD_TABLE_ENTRY;


/***************************************
*        Function Prototypes
***************************************/

uint8 TempMonSMBusSlave_CheckCommand(uint8 command)    ;
uint8 TempMonSMBusSlave_ReadHandler(void)              ;
void  TempMonSMBusSlave_WriteHandler(void)             ;
void  TempMonSMBusSlave_CompleteRead(void)             ;

/* Bootloader Specific APIs */
#if(defined(TempMonSMBusSlave_BTLDR_READ_EN) || defined(TempMonSMBusSlave_BTLDR_WRITE_EN))
    void     TempMonSMBusSlave_CyBtldrCommStart(void) CYSMALL ;
    void     TempMonSMBusSlave_CyBtldrCommStop(void) CYSMALL ;
    void     TempMonSMBusSlave_CyBtldrCommReset(void) CYSMALL ;
#endif /* defined(TempMonSMBusSlave_BTLDR_READ_EN) || defined(TempMonSMBusSlave_BTLDR_WRITE_EN) */

#ifdef TempMonSMBusSlave_BTLDR_READ_EN
    cystatus TempMonSMBusSlave_CyBtldrCommWrite(const uint8 * pData, uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
#endif /* TempMonSMBusSlave_BTLDR_READ_EN */

#ifdef TempMonSMBusSlave_BTLDR_WRITE_EN
    cystatus TempMonSMBusSlave_CyBtldrCommRead(uint8 * pData, uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
#endif /* TempMonSMBusSlave_BTLDR_WRITE_EN */


/***************************************
*           API Constants
***************************************/

/* Command properties */
#define TempMonSMBusSlave_CMD_WR_SUPPORT                 (0x40u)
#define TempMonSMBusSlave_CMD_WR_MANUAL                  (0x40u)
#define TempMonSMBusSlave_CMD_WR_AUTO                    (0x02u)
#define TempMonSMBusSlave_CMD_RD_SUPPORT                 (0x20u)
#define TempMonSMBusSlave_CMD_RD_MANUAL                  (0x20u)
#define TempMonSMBusSlave_CMD_RD_AUTO                    (0x01u)
#define TempMonSMBusSlave_CMD_PAGED                      (0x80u)
#define TempMonSMBusSlave_CMD_FMT_MASK                   (0x1Cu)
#define TempMonSMBusSlave_CMD_FMT_NON_NUMERIC            (0x1Cu)
#define TempMonSMBusSlave_CMD_FMT_LINEAR                 (0x00u)
#define TempMonSMBusSlave_CMD_FMT_SIGNED                 (0x04u)
#define TempMonSMBusSlave_CMD_FMT_DIRECT                 (0x0Cu)
#define TempMonSMBusSlave_CMD_FMT_UNSIGNED               (0x10u)
#define TempMonSMBusSlave_CMD_FMT_VID_MODE               (0x14u)
#define TempMonSMBusSlave_CMD_FMT_MANUFACTURER           (0x18u)
#define TempMonSMBusSlave_CMD_SUPPORTED                  (0x80u)

/* Command types and flags */
#define TempMonSMBusSlave_CMD_VALID                      (0x00u)
#define TempMonSMBusSlave_CMD_READ                       (0x01u)
#define TempMonSMBusSlave_CMD_WRITE                      (0x00u)
#define TempMonSMBusSlave_CMD_UNDEFINED                  (0xFFu)
#define TempMonSMBusSlave_NON_BLOCK_CMD                  (0x00u)
#define TempMonSMBusSlave_BLOCK_CMD                      (0x01u)

/* "All Pages" wild card */
#define TempMonSMBusSlave_CMD_ALL_PAGES                  (0xFFu)
#define TempMonSMBusSlave_SUPPORT_PAGE_CMD               (0u)

/* Bootloader status */
#define TempMonSMBusSlave_BTLDR_WR_CMPT                  (0x10u)
#define TempMonSMBusSlave_BTLDR_RD_CMPT                  (0x01u)

/* Helpers to check if a command size is valid. Greater or equal is used to take
* into account the PEC byte. For example, when the PEC is enabled and a host
* writes to a word command, the correct index value is 2 if the host does not
* send PEC, and 3 if it does. The index value greater than 3 results in a Host
* Sends Too Many Bytes fault and is detected in the ISR.
*/
#define TempMonSMBusSlave_CMD_LEN_VALID                  (TempMonSMBusSlave_bufferIndex >= TempMonSMBusSlave_bufferSize)

/* Byte and word commands have fixed number of bytes */ 
#define TempMonSMBusSlave_BYTE_CMD_LEN_VALID             (TempMonSMBusSlave_bufferIndex >= 1u)
#define TempMonSMBusSlave_WORD_CMD_LEN_VALID             (TempMonSMBusSlave_bufferIndex >= 2u)

#endif /* !defined(CY_SMBusSlave_TempMonSMBusSlave_cmd_H) */


/* [] END OF FILE */
