/*******************************************************************************
* File Name: TempSMBus.h
* Version 5.20
*
* Description:
*  This file provides constants and parameter values and API definition for the
*  SM/PM Bus Component.
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_SMBusSlave_TempSMBus_H)
#define CY_SMBusSlave_TempSMBus_H

#include "cytypes.h"
#include "TempSMBus_I2C.h"

/*`#START ADDITIONAL_SMBUS_SLAVE_H_INCLUDE`*/

/*`#END`*/


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define TempSMBus_MODE                       (0u)
#define TempSMBus_RECEIVE_BYTE_PROTOCOL      (0u)
#define TempSMBus_SMB_ALERT_PIN_ENABLED      (0u)
#define TempSMBus_ENABLE_PEC                 (0u)

/* AlertReg_Sync_ctrl_reg__REMOVED is defined if SMBALERT# pin is enabled and
* left floating.
*/
#ifndef TempSMBus_AlertReg_Sync_ctrl_reg__REMOVED
    #define TempSMBus_SMBALERT_PIN_EXISTS    (TempSMBus_SMB_ALERT_PIN_ENABLED != 0u)
#else
    #define TempSMBus_SMBALERT_PIN_EXISTS    (0u != 0u)
#endif /* TempSMBus_AlertReg_Sync_ctrl_reg__REMOVED */

#define TempSMBus_RECEIVE_BYTE_PROT_ENABLED  (TempSMBus_RECEIVE_BYTE_PROTOCOL != 0u)
#define TempSMBus_SUPPORT_PEC                (TempSMBus_ENABLE_PEC != 0u)

#if (CY_PSOC4)
    #define TempSMBus_SW_ADDR_DECODE         (TempSMBus_I2C_CHECK_I2C_ACCEPT_ADDRESS_CONST)
#else
    #define TempSMBus_SW_ADDR_DECODE         (TempSMBus_I2C_SW_ADRR_DECODE)
#endif /* CY_PSOC4 */


/***************************************
*     Data Struct Definitions
***************************************/

typedef struct
{
    uint8 read;          /* r/w flag - 1=read 0=write */
    uint8 commandCode;   /* SMBus/PMBus command code */
    uint8 page;          /* PMBus page (if applicable) */
    uint8 length;        /* bytes transferred */
    uint8 payload[65u];  /* payload for the transaction */
} TempSMBus_TRANSACTION_STRUCT;


/* Define each command based on the inputs from the customizer. */
#if defined (__GNUC__)
    typedef struct __attribute__ ((packed))
#else
    typedef __packed struct
#endif /* (__GNUC__) */
{
    uint32 SMBUS_REGS_SIG;
    uint16 FLASH_CRC;
} TempSMBus_REGS;


/***************************************
*        Function Prototypes
***************************************/

/* General APIs */
void  TempSMBus_Init(void)                          ;
void  TempSMBus_Enable(void)                        ;
void  TempSMBus_Start(void)                         ;
void  TempSMBus_Stop(void)                          ;

/* Transaction Specific APIs */
void  TempSMBus_CompleteTransaction(void)           ;
TempSMBus_TRANSACTION_STRUCT * TempSMBus_GetNextTransaction(void)
                                                           ;
/* Protocol Specific APIs */
#if (TempSMBus_SMBALERT_PIN_EXISTS)
    void  TempSMBus_HandleSmbAlertResponse(void)    ;
    #if (CY_PSOC4)
        void TempSMBus_SetSmbAlert(uint8 state)     ;
    #endif /* CY_PSOC4 */
#endif /* TempSMBus_SMBALERT_PIN_EXISTS */

#if (TempSMBus_RECEIVE_BYTE_PROT_ENABLED)
    uint8  TempSMBus_GetReceiveByteResponse(void)   ;
#endif /* TempSMBus_RECEIVE_BYTE_PROT_ENABLED */

void  TempSMBus_HandleBusError(uint8 errorCode)     ;

/* Register Save/Restore APIs */
uint8 TempSMBus_StoreUserAll(const uint8 * flashRegs)  ;
uint8 TempSMBus_RestoreUserAll(const uint8 * flashRegs);
uint8 TempSMBus_EraseUserAll(void)                     ;
uint8 TempSMBus_RestoreDefaultAll(void)                ;
uint8 TempSMBus_StoreComponentAll(void)                ;
uint8 TempSMBus_RestoreComponentAll(void)              ;

/* Unit Conversion Helper APIs */
float32 TempSMBus_Lin11ToFloat(uint16 linear11)        ;
uint16  TempSMBus_FloatToLin11(float32 floatvar)       ;
float32 TempSMBus_Lin16ToFloat(uint16 linear16, int8 inExponent)   
                                                              ;
uint16  TempSMBus_FloatToLin16(float32 floatvar, int8 outExponent)
                                                              ;

/* Interrupt handlers */
CY_ISR_PROTO(TempSMBus_ISR);
CY_ISR_PROTO(TempSMBus_TIMEOUT_ISR);


/***************************************
*   Variables with external linkage
***************************************/

extern uint8 TempSMBus_initVar;

/* Operating Memory Register Store (RAM) */
extern TempSMBus_REGS TempSMBus_regs;

/* Default Memory Register Store (Flash) */
extern const TempSMBus_REGS CYCODE TempSMBus_regsDefault;


/***************************************
*           API Constants
***************************************/

#define TempSMBus_SMBUS_MODE                 (TempSMBus_MODE == 0u)
#define TempSMBus_PMBUS_MODE                 (TempSMBus_MODE != 0u)
#define TempSMBus_SIGNATURE                  (0x000055AAu)
#define TempSMBus_REGS_SIZE                  (sizeof(TempSMBus_REGS))
#define TempSMBus_ADDR_POS                   (0x01u)
#define TempSMBus_ADDR_MASK                  (0xFEu)
#define TempSMBus_READ_FLAG                  (0x01u)

/* Default return value for TempSMBus_GetReceiveByteResponse() */
#define TempSMBus_RET_UNDEFINED              (0xFFu)

/* Constants for TempSMBus_SetSmbAlertMode() */
#if (TempSMBus_SMBALERT_PIN_EXISTS)   
    #define TempSMBus_AUTO_MODE              (0x01u)
    #define TempSMBus_MANUAL_MODE            (0x02u)
    #define TempSMBus_DO_NOTHING             (0x00u)
#endif /* TempSMBus_SMBALERT_PIN_EXISTS */

#define TempSMBus_NEG_EXP_MIN                (-16)

/* Defines related to CRC calculation */
#define TempSMBus_CRC_SEED                   (0xFFFFu)
#define TempSMBus_CRC_BYTE_SHIFT             (0x8u)
#define TempSMBus_CRC_BYTE_MASK              (0xFFu)

/* Error codes for TempSMBus_HandleBusError() */
#define TempSMBus_ERR_READ_FLAG              (0x01u)
#define TempSMBus_ERR_RD_TOO_MANY_BYTES      (0x02u)
#define TempSMBus_ERR_WR_TOO_MANY_BYTES      (0x04u)
#define TempSMBus_ERR_UNSUPPORTED_CMD        (0x08u)
#define TempSMBus_ERR_INVALID_DATA           (0x10u)
#define TempSMBus_ERR_TIMEOUT                (0x20u)
#define TempSMBus_ERR_WR_TOO_FEW_BYTES       (0x40u)
#define TempSMBus_ERR_CORRUPTED_DATA         (0x80u)

/* Constants dedicated for work with FLASH */
#define TempSMBus_FLASH_ROW_SIZE             (CYDEV_FLS_ROW_SIZE)
#define TempSMBus_FLASH_END_ADDR             (CYDEV_FLS_SIZE - 1u)
#define TempSMBus_FLASH_ROW_MASK             (0x0000FF00u)
#define TempSMBus_FLASH_ARRYID_MASK          (0x00FF0000u)
#define TempSMBus_BYTE_SHIFT                 (8u)
#define TempSMBus_TWO_BYTES_SHIFT            (16u)


/***************************************
*    Initial Parameter Constants
***************************************/

#define TempSMBus_NUM_COMMANDS               (0x00u)
#define TempSMBus_MAX_PAGES                  (8u)
#define TempSMBus_SMB_ALERT_MODE_INIT        (1u)
#define TempSMBus_DEFAULT_ADDRESS            (32u)
#define TempSMBus_ALERT_RESPONSE_ADDR        (0x0Cu)
#define TempSMBus_GENERAL_CALL_ADDR          (0x00u)


/***************************************
*              Registers
***************************************/

#if (TempSMBus_SMBALERT_PIN_EXISTS)
    #if(CY_PSOC4)
        #define TempSMBus_SMBALERT_PIN_REG   (* (reg32 *) TempSMBus_smbalert_pin__DR)
        #define TempSMBus_SMBALERT_PIN_MASK     (uint32)  TempSMBus_smbalert_pin__MASK
    #else
        #define TempSMBus_SMBALERT_PIN_REG   (* (reg8  *) TempSMBus_AlertReg_Sync_ctrl_reg__CONTROL_REG)
    #endif /* CY_PSOC4 */
#endif /* TempSMBus_SMBALERT_PIN_EXISTS */


/***************************************
*              Macros
***************************************/

/* Enables I2C interrupt. Interrupts are required for most operations. */
#define TempSMBus_EnableInt()                TempSMBus_I2C_EnableInt()

/* Disables the I2C interrupts. Normally calling this is not required since the
* Stop() function disables the interrupt.
* Side Effects: If the I2C interrupt is disabled and the master is addressing
* the current slave, the bus will be locked until the interrupt is re-enabled.
*/
#define TempSMBus_DisableInt()               TempSMBus_I2C_DisableInt()

/* Sets the SM/PM Bus slave address. The address is the 7-bit right-justified
* address for the primary device. Does not include the R/W bit.
*/
#if (TempSMBus_SW_ADDR_DECODE)
    /* When software address detection is enabled, the address is converted to an 8-bit
    * address with the R/W bit set to 0.
    */
    #define TempSMBus_SetAddress(address)    \
        (TempSMBus_address = (uint8)((address) << TempSMBus_ADDR_POS))
#else
    #if (CY_PSOC4)
        #define TempSMBus_SetAddress(address)    TempSMBus_I2CSlaveSetAddress(address)
    #else
        #define TempSMBus_SetAddress(address)    TempSMBus_I2C_SlaveSetAddress(address)
    #endif /* CY_PSOC4 */
#endif

/* Returns the number of transaction records in the transaction queue */
#define TempSMBus_GetTransactionCount()      TempSMBus_trActiveCount

#if (TempSMBus_SMBALERT_PIN_EXISTS)

    /* Sets the the Alert Response Address (ARA). The address is the 7-bit
    * right-justified address. Does not include the R/W bit.
    * The address is converted to 8-bit address witgh the R/W bit set to 1.
    */
    #define TempSMBus_SetAlertResponseAddress(address)   (TempSMBus_alertResponseAddress = \
        (uint8)((address) << TempSMBus_ADDR_POS) | TempSMBus_READ_FLAG)
    
    /* Sets the SMBALERT# signal to the specified state. If the device pulled
    * SMBALERT# low, it will acknowledge the ARA with the primary address of 
    * the device. On PSoC 4 this implemented as a function with critical section
    * protection of the read-modify-write to a port data register.
    */
    #if (!CY_PSOC4)
        #define TempSMBus_SetSmbAlert(state)             (TempSMBus_SMBALERT_PIN_REG = (state))
    #endif /* CY_PSOC4 */
    
    /* Determines how the component responds to a SMBus master read at the ARA.
    *  alertMode (uint8): A byte that defines SMBALERT pin mode.
    *   TempSMBus_DO_NOTHING (0x00u) - no action will be taken
    *   TempSMBus_AUTO_MODE  (0x01u) - SMBALERT# pin will be 
    *   de-asserted once the device responds to the ARA.
    *   TempSMBus_MANUAL_MODE (0x02u) - the HandleSmbAlertResponse()
    *   API will be called allowing the user to implement its own algorithm
    *   in the custom user code section.
    */
    #define TempSMBus_SetSmbAlertMode(alertMode)         (TempSMBus_smbAlertMode = (alertMode))

#endif /* TempSMBus_SMBALERT_PIN_EXISTS */

/* Converts the Flash address to Flash row */
#define TempSMBus_FL_ADDR_TO_ROW(addr) \
    ((uint8)(((addr) & TempSMBus_FLASH_ROW_MASK) >> TempSMBus_BYTE_SHIFT))

/* Converts Flash row to Flash Array ID */
#define TempSMBus_FL_ADDR_TO_ARRAYID(addr) \
    ((uint8)(((addr) & TempSMBus_FLASH_ARRYID_MASK) >> TempSMBus_TWO_BYTES_SHIFT))

#define TempSMBus_SIZE_TO_ROW(size)  ((uint8)((size) >> TempSMBus_BYTE_SHIFT) + 1u)

#define TempSMBus_MAKE_FLASH_ADDR(arrayId, row) \
    (((uint32)(arrayId) << TempSMBus_TWO_BYTES_SHIFT) | ((uint32)(row) << TempSMBus_BYTE_SHIFT))

#endif /* CY_SMBusSlave_TempSMBus_H */

/* [] END OF FILE */
