/*******************************************************************************
* File Name: TempSMBus_I2C_INT.c
* Version 3.50
*
* Description:
*  This file provides the source code of Interrupt Service Routine (ISR)
*  for the I2C component.
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TempSMBus_I2C_PVT.h"
#include "cyapicallbacks.h"


/*******************************************************************************
*  Place your includes, defines and code here.
********************************************************************************/
/* `#START TempSMBus_I2C_ISR_intc` */

/* `#END` */


/*******************************************************************************
* Function Name: TempSMBus_I2C_ISR
********************************************************************************
*
* Summary:
*  The handler for the I2C interrupt. The slave and master operations are
*  handled here.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Reentrant:
*  No.
*
*******************************************************************************/
CY_ISR(TempSMBus_I2C_ISR)
{
#if (TempSMBus_I2C_MODE_SLAVE_ENABLED)
   uint8  tmp8;
#endif  /* (TempSMBus_I2C_MODE_SLAVE_ENABLED) */

    uint8  tmpCsr;
    
#ifdef TempSMBus_I2C_ISR_ENTRY_CALLBACK
    TempSMBus_I2C_ISR_EntryCallback();
#endif /* TempSMBus_I2C_ISR_ENTRY_CALLBACK */
    

#if(TempSMBus_I2C_TIMEOUT_FF_ENABLED)
    if(0u != TempSMBus_I2C_TimeoutGetStatus())
    {
        TempSMBus_I2C_TimeoutReset();
        TempSMBus_I2C_state = TempSMBus_I2C_SM_EXIT_IDLE;
        /* TempSMBus_I2C_CSR_REG should be cleared after reset */
    }
#endif /* (TempSMBus_I2C_TIMEOUT_FF_ENABLED) */


    tmpCsr = TempSMBus_I2C_CSR_REG;      /* Make copy as interrupts clear */

#if(TempSMBus_I2C_MODE_MULTI_MASTER_SLAVE_ENABLED)
    if(TempSMBus_I2C_CHECK_START_GEN(TempSMBus_I2C_MCSR_REG))
    {
        TempSMBus_I2C_CLEAR_START_GEN;

        /* Set transfer complete and error flags */
        TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_ERR_XFER |
                                        TempSMBus_I2C_GET_MSTAT_CMPLT);

        /* Slave was addressed */
        TempSMBus_I2C_state = TempSMBus_I2C_SM_SLAVE;
    }
#endif /* (TempSMBus_I2C_MODE_MULTI_MASTER_SLAVE_ENABLED) */


#if(TempSMBus_I2C_MODE_MULTI_MASTER_ENABLED)
    if(TempSMBus_I2C_CHECK_LOST_ARB(tmpCsr))
    {
        /* Set errors */
        TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_ERR_XFER     |
                                        TempSMBus_I2C_MSTAT_ERR_ARB_LOST |
                                        TempSMBus_I2C_GET_MSTAT_CMPLT);

        TempSMBus_I2C_DISABLE_INT_ON_STOP; /* Interrupt on Stop is enabled by write */

        #if(TempSMBus_I2C_MODE_MULTI_MASTER_SLAVE_ENABLED)
            if(TempSMBus_I2C_CHECK_ADDRESS_STS(tmpCsr))
            {
                /* Slave was addressed */
                TempSMBus_I2C_state = TempSMBus_I2C_SM_SLAVE;
            }
            else
            {
                TempSMBus_I2C_BUS_RELEASE;

                TempSMBus_I2C_state = TempSMBus_I2C_SM_EXIT_IDLE;
            }
        #else
            TempSMBus_I2C_BUS_RELEASE;

            TempSMBus_I2C_state = TempSMBus_I2C_SM_EXIT_IDLE;

        #endif /* (TempSMBus_I2C_MODE_MULTI_MASTER_SLAVE_ENABLED) */
    }
#endif /* (TempSMBus_I2C_MODE_MULTI_MASTER_ENABLED) */

    /* Check for master operation mode */
    if(TempSMBus_I2C_CHECK_SM_MASTER)
    {
    #if(TempSMBus_I2C_MODE_MASTER_ENABLED)
        if(TempSMBus_I2C_CHECK_BYTE_COMPLETE(tmpCsr))
        {
            switch (TempSMBus_I2C_state)
            {
            case TempSMBus_I2C_SM_MSTR_WR_ADDR:  /* After address is sent, write data */
            case TempSMBus_I2C_SM_MSTR_RD_ADDR:  /* After address is sent, read data */

                tmpCsr &= ((uint8) ~TempSMBus_I2C_CSR_STOP_STATUS); /* Clear Stop bit history on address phase */

                if(TempSMBus_I2C_CHECK_ADDR_ACK(tmpCsr))
                {
                    /* Setup for transmit or receive of data */
                    if(TempSMBus_I2C_state == TempSMBus_I2C_SM_MSTR_WR_ADDR)   /* TRANSMIT data */
                    {
                        /* Check if at least one byte to transfer */
                        if(TempSMBus_I2C_mstrWrBufSize > 0u)
                        {
                            /* Load the 1st data byte */
                            TempSMBus_I2C_DATA_REG = TempSMBus_I2C_mstrWrBufPtr[0u];
                            TempSMBus_I2C_TRANSMIT_DATA;
                            TempSMBus_I2C_mstrWrBufIndex = 1u;   /* Set index to 2nd element */

                            /* Set transmit state until done */
                            TempSMBus_I2C_state = TempSMBus_I2C_SM_MSTR_WR_DATA;
                        }
                        /* End of buffer: complete writing */
                        else if(TempSMBus_I2C_CHECK_NO_STOP(TempSMBus_I2C_mstrControl))
                        {
                            /* Set write complete and master halted */
                            TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_XFER_HALT |
                                                            TempSMBus_I2C_MSTAT_WR_CMPLT);

                            TempSMBus_I2C_state = TempSMBus_I2C_SM_MSTR_HALT; /* Expect ReStart */
                            TempSMBus_I2C_DisableInt();
                        }
                        else
                        {
                            TempSMBus_I2C_ENABLE_INT_ON_STOP; /* Enable interrupt on Stop, to catch it */
                            TempSMBus_I2C_GENERATE_STOP;
                        }
                    }
                    else  /* Master receive data */
                    {
                        TempSMBus_I2C_READY_TO_READ; /* Release bus to read data */

                        TempSMBus_I2C_state  = TempSMBus_I2C_SM_MSTR_RD_DATA;
                    }
                }
                /* Address is NACKed */
                else if(TempSMBus_I2C_CHECK_ADDR_NAK(tmpCsr))
                {
                    /* Set Address NAK error */
                    TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_ERR_XFER |
                                                    TempSMBus_I2C_MSTAT_ERR_ADDR_NAK);

                    if(TempSMBus_I2C_CHECK_NO_STOP(TempSMBus_I2C_mstrControl))
                    {
                        TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_XFER_HALT |
                                                        TempSMBus_I2C_GET_MSTAT_CMPLT);

                        TempSMBus_I2C_state = TempSMBus_I2C_SM_MSTR_HALT; /* Expect RESTART */
                        TempSMBus_I2C_DisableInt();
                    }
                    else  /* Do normal Stop */
                    {
                        TempSMBus_I2C_ENABLE_INT_ON_STOP; /* Enable interrupt on Stop, to catch it */
                        TempSMBus_I2C_GENERATE_STOP;
                    }
                }
                else
                {
                    /* Address phase is not set for some reason: error */
                    #if(TempSMBus_I2C_TIMEOUT_ENABLED)
                        /* Exit interrupt to take chance for timeout timer to handle this case */
                        TempSMBus_I2C_DisableInt();
                        TempSMBus_I2C_ClearPendingInt();
                    #else
                        /* Block execution flow: unexpected condition */
                        CYASSERT(0u != 0u);
                    #endif /* (TempSMBus_I2C_TIMEOUT_ENABLED) */
                }
                break;

            case TempSMBus_I2C_SM_MSTR_WR_DATA:

                if(TempSMBus_I2C_CHECK_DATA_ACK(tmpCsr))
                {
                    /* Check if end of buffer */
                    if(TempSMBus_I2C_mstrWrBufIndex  < TempSMBus_I2C_mstrWrBufSize)
                    {
                        TempSMBus_I2C_DATA_REG =
                                                 TempSMBus_I2C_mstrWrBufPtr[TempSMBus_I2C_mstrWrBufIndex];
                        TempSMBus_I2C_TRANSMIT_DATA;
                        TempSMBus_I2C_mstrWrBufIndex++;
                    }
                    /* End of buffer: complete writing */
                    else if(TempSMBus_I2C_CHECK_NO_STOP(TempSMBus_I2C_mstrControl))
                    {
                        /* Set write complete and master halted */
                        TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_XFER_HALT |
                                                        TempSMBus_I2C_MSTAT_WR_CMPLT);

                        TempSMBus_I2C_state = TempSMBus_I2C_SM_MSTR_HALT;    /* Expect restart */
                        TempSMBus_I2C_DisableInt();
                    }
                    else  /* Do normal Stop */
                    {
                        TempSMBus_I2C_ENABLE_INT_ON_STOP;    /* Enable interrupt on Stop, to catch it */
                        TempSMBus_I2C_GENERATE_STOP;
                    }
                }
                /* Last byte NAKed: end writing */
                else if(TempSMBus_I2C_CHECK_NO_STOP(TempSMBus_I2C_mstrControl))
                {
                    /* Set write complete, short transfer and master halted */
                    TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_ERR_XFER       |
                                                    TempSMBus_I2C_MSTAT_ERR_SHORT_XFER |
                                                    TempSMBus_I2C_MSTAT_XFER_HALT      |
                                                    TempSMBus_I2C_MSTAT_WR_CMPLT);

                    TempSMBus_I2C_state = TempSMBus_I2C_SM_MSTR_HALT;    /* Expect ReStart */
                    TempSMBus_I2C_DisableInt();
                }
                else  /* Do normal Stop */
                {
                    TempSMBus_I2C_ENABLE_INT_ON_STOP;    /* Enable interrupt on Stop, to catch it */
                    TempSMBus_I2C_GENERATE_STOP;

                    /* Set short transfer and error flag */
                    TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_ERR_SHORT_XFER |
                                                    TempSMBus_I2C_MSTAT_ERR_XFER);
                }

                break;

            case TempSMBus_I2C_SM_MSTR_RD_DATA:

                TempSMBus_I2C_mstrRdBufPtr[TempSMBus_I2C_mstrRdBufIndex] = TempSMBus_I2C_DATA_REG;
                TempSMBus_I2C_mstrRdBufIndex++;

                /* Check if end of buffer */
                if(TempSMBus_I2C_mstrRdBufIndex < TempSMBus_I2C_mstrRdBufSize)
                {
                    TempSMBus_I2C_ACK_AND_RECEIVE;       /* ACK and receive byte */
                }
                /* End of buffer: complete reading */
                else if(TempSMBus_I2C_CHECK_NO_STOP(TempSMBus_I2C_mstrControl))
                {
                    /* Set read complete and master halted */
                    TempSMBus_I2C_mstrStatus |= (TempSMBus_I2C_MSTAT_XFER_HALT |
                                                    TempSMBus_I2C_MSTAT_RD_CMPLT);

                    TempSMBus_I2C_state = TempSMBus_I2C_SM_MSTR_HALT;    /* Expect ReStart */
                    TempSMBus_I2C_DisableInt();
                }
                else
                {
                    TempSMBus_I2C_ENABLE_INT_ON_STOP;
                    TempSMBus_I2C_NAK_AND_RECEIVE;       /* NACK and TRY to generate Stop */
                }
                break;

            default: /* This is an invalid state and should not occur */

            #if(TempSMBus_I2C_TIMEOUT_ENABLED)
                /* Exit interrupt to take chance for timeout timer to handles this case */
                TempSMBus_I2C_DisableInt();
                TempSMBus_I2C_ClearPendingInt();
            #else
                /* Block execution flow: unexpected condition */
                CYASSERT(0u != 0u);
            #endif /* (TempSMBus_I2C_TIMEOUT_ENABLED) */

                break;
            }
        }

        /* Catches Stop: end of transaction */
        if(TempSMBus_I2C_CHECK_STOP_STS(tmpCsr))
        {
            TempSMBus_I2C_mstrStatus |= TempSMBus_I2C_GET_MSTAT_CMPLT;

            TempSMBus_I2C_DISABLE_INT_ON_STOP;
            TempSMBus_I2C_state = TempSMBus_I2C_SM_IDLE;
        }
    #endif /* (TempSMBus_I2C_MODE_MASTER_ENABLED) */
    }
    else if(TempSMBus_I2C_CHECK_SM_SLAVE)
    {
    #if(TempSMBus_I2C_MODE_SLAVE_ENABLED)

        if((TempSMBus_I2C_CHECK_STOP_STS(tmpCsr)) || /* Stop || Restart */
           (TempSMBus_I2C_CHECK_BYTE_COMPLETE(tmpCsr) && TempSMBus_I2C_CHECK_ADDRESS_STS(tmpCsr)))
        {
            /* Catch end of master write transaction: use interrupt on Stop */
            /* The Stop bit history on address phase does not have correct state */
            if(TempSMBus_I2C_SM_SL_WR_DATA == TempSMBus_I2C_state)
            {
                TempSMBus_I2C_DISABLE_INT_ON_STOP;

                TempSMBus_I2C_slStatus &= ((uint8) ~TempSMBus_I2C_SSTAT_WR_BUSY);
                TempSMBus_I2C_slStatus |= ((uint8)  TempSMBus_I2C_SSTAT_WR_CMPLT);

                TempSMBus_I2C_state = TempSMBus_I2C_SM_IDLE;
            }
        }

        if(TempSMBus_I2C_CHECK_BYTE_COMPLETE(tmpCsr))
        {
            /* The address only issued after Start or ReStart: so check the address
               to catch these events:
                FF : sets an address phase with a byte_complete interrupt trigger.
                UDB: sets an address phase immediately after Start or ReStart. */
            if(TempSMBus_I2C_CHECK_ADDRESS_STS(tmpCsr))
            {
            /* Check for software address detection */
            #if(TempSMBus_I2C_SW_ADRR_DECODE)
                tmp8 = TempSMBus_I2C_GET_SLAVE_ADDR(TempSMBus_I2C_DATA_REG);

                if(tmp8 == TempSMBus_I2C_slAddress)   /* Check for address match */
                {
                    if(0u != (TempSMBus_I2C_DATA_REG & TempSMBus_I2C_READ_FLAG))
                    {
                        /* Place code to prepare read buffer here                  */
                        /* `#START TempSMBus_I2C_SW_PREPARE_READ_BUF_interrupt` */

                        /* `#END` */

                    #ifdef TempSMBus_I2C_SW_PREPARE_READ_BUF_CALLBACK
                        TempSMBus_I2C_SwPrepareReadBuf_Callback();
                    #endif /* TempSMBus_I2C_SW_PREPARE_READ_BUF_CALLBACK */
                        
                        /* Prepare next operation to read, get data and place in data register */
                        if(TempSMBus_I2C_slRdBufIndex < TempSMBus_I2C_slRdBufSize)
                        {
                            /* Load first data byte from array */
                            TempSMBus_I2C_DATA_REG = TempSMBus_I2C_slRdBufPtr[TempSMBus_I2C_slRdBufIndex];
                            TempSMBus_I2C_ACK_AND_TRANSMIT;
                            TempSMBus_I2C_slRdBufIndex++;

                            TempSMBus_I2C_slStatus |= TempSMBus_I2C_SSTAT_RD_BUSY;
                        }
                        else    /* Overflow: provide 0xFF on bus */
                        {
                            TempSMBus_I2C_DATA_REG = TempSMBus_I2C_OVERFLOW_RETURN;
                            TempSMBus_I2C_ACK_AND_TRANSMIT;

                            TempSMBus_I2C_slStatus  |= (TempSMBus_I2C_SSTAT_RD_BUSY |
                                                           TempSMBus_I2C_SSTAT_RD_ERR_OVFL);
                        }

                        TempSMBus_I2C_state = TempSMBus_I2C_SM_SL_RD_DATA;
                    }
                    else  /* Write transaction: receive 1st byte */
                    {
                        TempSMBus_I2C_ACK_AND_RECEIVE;
                        TempSMBus_I2C_state = TempSMBus_I2C_SM_SL_WR_DATA;

                        TempSMBus_I2C_slStatus |= TempSMBus_I2C_SSTAT_WR_BUSY;
                        TempSMBus_I2C_ENABLE_INT_ON_STOP;
                    }
                }
                else
                {
                    /*     Place code to compare for additional address here    */
                    /* `#START TempSMBus_I2C_SW_ADDR_COMPARE_interruptStart` */

                    /* `#END` */

                #ifdef TempSMBus_I2C_SW_ADDR_COMPARE_ENTRY_CALLBACK
                    TempSMBus_I2C_SwAddrCompare_EntryCallback();
                #endif /* TempSMBus_I2C_SW_ADDR_COMPARE_ENTRY_CALLBACK */
                    
                    TempSMBus_I2C_NAK_AND_RECEIVE;   /* NACK address */

                    /* Place code to end of condition for NACK generation here */
                    /* `#START TempSMBus_I2C_SW_ADDR_COMPARE_interruptEnd`  */

                    /* `#END` */

                #ifdef TempSMBus_I2C_SW_ADDR_COMPARE_EXIT_CALLBACK
                    TempSMBus_I2C_SwAddrCompare_ExitCallback();
                #endif /* TempSMBus_I2C_SW_ADDR_COMPARE_EXIT_CALLBACK */
                }

            #else /* (TempSMBus_I2C_HW_ADRR_DECODE) */

                if(0u != (TempSMBus_I2C_DATA_REG & TempSMBus_I2C_READ_FLAG))
                {
                    /* Place code to prepare read buffer here                  */
                    /* `#START TempSMBus_I2C_HW_PREPARE_READ_BUF_interrupt` */

                    /* `#END` */
                    
                #ifdef TempSMBus_I2C_HW_PREPARE_READ_BUF_CALLBACK
                    TempSMBus_I2C_HwPrepareReadBuf_Callback();
                #endif /* TempSMBus_I2C_HW_PREPARE_READ_BUF_CALLBACK */

                    /* Prepare next operation to read, get data and place in data register */
                    if(TempSMBus_I2C_slRdBufIndex < TempSMBus_I2C_slRdBufSize)
                    {
                        /* Load first data byte from array */
                        TempSMBus_I2C_DATA_REG = TempSMBus_I2C_slRdBufPtr[TempSMBus_I2C_slRdBufIndex];
                        TempSMBus_I2C_ACK_AND_TRANSMIT;
                        TempSMBus_I2C_slRdBufIndex++;

                        TempSMBus_I2C_slStatus |= TempSMBus_I2C_SSTAT_RD_BUSY;
                    }
                    else    /* Overflow: provide 0xFF on bus */
                    {
                        TempSMBus_I2C_DATA_REG = TempSMBus_I2C_OVERFLOW_RETURN;
                        TempSMBus_I2C_ACK_AND_TRANSMIT;

                        TempSMBus_I2C_slStatus  |= (TempSMBus_I2C_SSTAT_RD_BUSY |
                                                       TempSMBus_I2C_SSTAT_RD_ERR_OVFL);
                    }

                    TempSMBus_I2C_state = TempSMBus_I2C_SM_SL_RD_DATA;
                }
                else  /* Write transaction: receive 1st byte */
                {
                    TempSMBus_I2C_ACK_AND_RECEIVE;
                    TempSMBus_I2C_state = TempSMBus_I2C_SM_SL_WR_DATA;

                    TempSMBus_I2C_slStatus |= TempSMBus_I2C_SSTAT_WR_BUSY;
                    TempSMBus_I2C_ENABLE_INT_ON_STOP;
                }

            #endif /* (TempSMBus_I2C_SW_ADRR_DECODE) */
            }
            /* Data states */
            /* Data master writes into slave */
            else if(TempSMBus_I2C_state == TempSMBus_I2C_SM_SL_WR_DATA)
            {
                if(TempSMBus_I2C_slWrBufIndex < TempSMBus_I2C_slWrBufSize)
                {
                    tmp8 = TempSMBus_I2C_DATA_REG;
                    TempSMBus_I2C_ACK_AND_RECEIVE;
                    TempSMBus_I2C_slWrBufPtr[TempSMBus_I2C_slWrBufIndex] = tmp8;
                    TempSMBus_I2C_slWrBufIndex++;
                }
                else  /* of array: complete write, send NACK */
                {
                    TempSMBus_I2C_NAK_AND_RECEIVE;

                    TempSMBus_I2C_slStatus |= TempSMBus_I2C_SSTAT_WR_ERR_OVFL;
                }
            }
            /* Data master reads from slave */
            else if(TempSMBus_I2C_state == TempSMBus_I2C_SM_SL_RD_DATA)
            {
                if(TempSMBus_I2C_CHECK_DATA_ACK(tmpCsr))
                {
                    if(TempSMBus_I2C_slRdBufIndex < TempSMBus_I2C_slRdBufSize)
                    {
                         /* Get data from array */
                        TempSMBus_I2C_DATA_REG = TempSMBus_I2C_slRdBufPtr[TempSMBus_I2C_slRdBufIndex];
                        TempSMBus_I2C_TRANSMIT_DATA;
                        TempSMBus_I2C_slRdBufIndex++;
                    }
                    else   /* Overflow: provide 0xFF on bus */
                    {
                        TempSMBus_I2C_DATA_REG = TempSMBus_I2C_OVERFLOW_RETURN;
                        TempSMBus_I2C_TRANSMIT_DATA;

                        TempSMBus_I2C_slStatus |= TempSMBus_I2C_SSTAT_RD_ERR_OVFL;
                    }
                }
                else  /* Last byte was NACKed: read complete */
                {
                    /* Only NACK appears on bus */
                    TempSMBus_I2C_DATA_REG = TempSMBus_I2C_OVERFLOW_RETURN;
                    TempSMBus_I2C_NAK_AND_TRANSMIT;

                    TempSMBus_I2C_slStatus &= ((uint8) ~TempSMBus_I2C_SSTAT_RD_BUSY);
                    TempSMBus_I2C_slStatus |= ((uint8)  TempSMBus_I2C_SSTAT_RD_CMPLT);

                    TempSMBus_I2C_state = TempSMBus_I2C_SM_IDLE;
                }
            }
            else
            {
            #if(TempSMBus_I2C_TIMEOUT_ENABLED)
                /* Exit interrupt to take chance for timeout timer to handle this case */
                TempSMBus_I2C_DisableInt();
                TempSMBus_I2C_ClearPendingInt();
            #else
                /* Block execution flow: unexpected condition */
                CYASSERT(0u != 0u);
            #endif /* (TempSMBus_I2C_TIMEOUT_ENABLED) */
            }
        }
    #endif /* (TempSMBus_I2C_MODE_SLAVE_ENABLED) */
    }
    else
    {
        /* The FSM skips master and slave processing: return to IDLE */
        TempSMBus_I2C_state = TempSMBus_I2C_SM_IDLE;
    }

#ifdef TempSMBus_I2C_ISR_EXIT_CALLBACK
    TempSMBus_I2C_ISR_ExitCallback();
#endif /* TempSMBus_I2C_ISR_EXIT_CALLBACK */    
}


#if ((TempSMBus_I2C_FF_IMPLEMENTED) && (TempSMBus_I2C_WAKEUP_ENABLED))
    /*******************************************************************************
    * Function Name: TempSMBus_I2C_WAKEUP_ISR
    ********************************************************************************
    *
    * Summary:
    *  The interrupt handler to trigger after a wakeup.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    CY_ISR(TempSMBus_I2C_WAKEUP_ISR)
    {
    #ifdef TempSMBus_I2C_WAKEUP_ISR_ENTRY_CALLBACK
        TempSMBus_I2C_WAKEUP_ISR_EntryCallback();
    #endif /* TempSMBus_I2C_WAKEUP_ISR_ENTRY_CALLBACK */
         
        /* Set flag to notify that matched address is received */
        TempSMBus_I2C_wakeupSource = 1u;

        /* SCL is stretched until the I2C_Wake() is called */

    #ifdef TempSMBus_I2C_WAKEUP_ISR_EXIT_CALLBACK
        TempSMBus_I2C_WAKEUP_ISR_ExitCallback();
    #endif /* TempSMBus_I2C_WAKEUP_ISR_EXIT_CALLBACK */
    }
#endif /* ((TempSMBus_I2C_FF_IMPLEMENTED) && (TempSMBus_I2C_WAKEUP_ENABLED)) */


/* [] END OF FILE */
