/*******************************************************************************
* File Name: TempSMBus_I2C_TMOUT.c
* Version 3.50
*
* Description:
*  This file provides the source code of APIs for the timeout feature of
*  the I2C component.
*
* Note:
*
*******************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TempSMBus_I2C_PVT.h"


/*******************************************************************************
* Function Name: TempSMBus_I2C_TimeoutInit
********************************************************************************
*
* Summary:
*  Initialize the timeout timer hardware.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void TempSMBus_I2C_TimeoutInit(void) 
{
#if (TempSMBus_I2C_TIMEOUT_UDB_ENABLED)
    uint8 enableInterrupts;

    /* Configure timeout interrupt */
    CyIntDisable    (TempSMBus_I2C_TMOUT_ISR_NUMBER);
    CyIntSetPriority(TempSMBus_I2C_TMOUT_ISR_NUMBER, TempSMBus_I2C_TMOUT_ISR_PRIORITY);
    #if (TempSMBus_I2C_INTERN_TMOUT_INTR_HANDLER)
        (void) CyIntSetVector(TempSMBus_I2C_TMOUT_ISR_NUMBER, &TempSMBus_I2C_TMOUT_ISR);
    #endif /* (TempSMBus_I2C_INTERN_TMOUT_INTR_HANDLER) */

    TempSMBus_I2C_TimeoutSetIntrMode(TempSMBus_I2C_DEFAULT_TMOUT_INTR_MASK);

    /* Configure interrupt sources */
    enableInterrupts = CyEnterCriticalSection();
    TempSMBus_I2C_TMOUT_INTR_ENABLE_REG |= TempSMBus_I2C_TMOUT_ENABLE_INTR;
    CyExitCriticalSection(enableInterrupts);

    #if (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED)
        TempSMBus_I2C_TMOUT_SCL_ADDER_REG = TempSMBus_I2C_DEFAULT_TMOUT_ADDER;

        /* Configure F0 and F1 operation */
        enableInterrupts = CyEnterCriticalSection();
        TempSMBus_I2C_TMOUT_SCL_AUX_CTRL_REG |= TempSMBus_I2C_TMOUT_FIFO_SINGLE_REG;
        CyExitCriticalSection(enableInterrupts);
    #endif /* (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED) */


    #if (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED)
        TempSMBus_I2C_TMOUT_SDA_ADDER_REG = TempSMBus_I2C_DEFAULT_TMOUT_ADDER;

        /* Configure F0 and F1 operation */
        enableInterrupts = CyEnterCriticalSection();
        TempSMBus_I2C_TMOUT_SDA_AUX_CTRL_REG |= TempSMBus_I2C_TMOUT_FIFO_SINGLE_REG;
        CyExitCriticalSection(enableInterrupts);
    #endif /* (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED) */


    #if (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED)
        TempSMBus_I2C_TimeoutSetPrescalerPeriod(TempSMBus_I2C_DEFAULT_TMOUT_PRESCALER_PRD);

        /* Enable counter for prescaler */
        enableInterrupts = CyEnterCriticalSection();
    #if (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED)
        TempSMBus_I2C_SCL_PRESCALER_AUX_CTRL_REG |= TempSMBus_I2C_TMOUT_PRESCALER_CNT7_EN;
    #endif /* (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED) */

    #if (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED)
        TempSMBus_I2C_SDA_PRESCALER_AUX_CTRL_REG |= TempSMBus_I2C_TMOUT_PRESCALER_CNT7_EN;
    #endif /* (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED) */
        CyExitCriticalSection(enableInterrupts);

    #endif /* (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED)  */
#endif     /* (TempSMBus_I2C_TIMEOUT_UDB_ENABLED)        */

    /* Set default parameters */
    TempSMBus_I2C_TimeoutSetPeriod(TempSMBus_I2C_DEFAULT_TMOUT_PERIOD);
    TempSMBus_I2C_TimeoutSetIntrMode(TempSMBus_I2C_DEFAULT_TMOUT_INTR_MASK);
}


/*******************************************************************************
* Function Name: TempSMBus_I2C_TimeoutEnable
********************************************************************************
*
* Summary:
*  Enables the timeout interrupt and timer. The timeout timer starts operation
*  depending on the bus event.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void TempSMBus_I2C_TimeoutEnable(void) 
{
#if (TempSMBus_I2C_TIMEOUT_UDB_ENABLED)
    TempSMBus_I2C_TMOUT_CTRL_REG |= TempSMBus_I2C_TMOUT_CTRL_ENABLE;
#endif /* (TempSMBus_I2C_TIMEOUT_UDB_ENABLED) */

    TempSMBus_I2C_TimeoutEnableInt(); /* Enable interrupt on timeout event */
}


/*******************************************************************************
* Function Name: TempSMBus_I2C_TimeoutStop
********************************************************************************
*
* Summary:
*   Disables the timeout timer hardware. Disable interrupt and clear pending
*   if exist.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void TempSMBus_I2C_TimeoutStop(void) 
{
    TempSMBus_I2C_TimeoutDisableInt();
    TempSMBus_I2C_TimeoutClearPendingInt();

    /* Re-arm timeout */
#if (TempSMBus_I2C_TIMEOUT_FF_ENABLED)
    TempSMBus_I2C_TimeoutClearStatus(TempSMBus_I2C_TMOUT_SR_PINS_TMOUT_MASK);
#else
    TempSMBus_I2C_TMOUT_CTRL_REG &= (uint8) ~TempSMBus_I2C_TMOUT_CTRL_ENABLE;
#endif /* (TempSMBus_I2C_TIMEOUT_UDB_ENABLED) */
}


/*******************************************************************************
* Function Name: TempSMBus_I2C_TimeoutSetPeriod
********************************************************************************
*
* Summary:
*  Sets period of the scl and sda timeout counters.
*
* Parameters:
*  period:  the period of the scl and sda timeout. This number depends on
*           BUSCLK for FF implementation on PSOC5LP and on input
*           clock (16*DataRate) for UDB implementation.
*
* Return:
*  None.
*
*******************************************************************************/
void TempSMBus_I2C_TimeoutSetPeriod(uint16 period) 
{
#if (TempSMBus_I2C_TIMEOUT_FF_ENABLED)
    TempSMBus_I2C_TMOUT_CFG0_REG = LO8(period);
    TempSMBus_I2C_TMOUT_CFG1_REG = HI8(period);

#else
    #if (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED)
        TempSMBus_I2C_TMOUT_SCL_PRD0_REG = LO8(period);
        TempSMBus_I2C_TMOUT_SCL_PRD1_REG = HI8(period);
    #endif /* (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED) */

    #if (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED)
        TempSMBus_I2C_TMOUT_SDA_PRD0_REG = LO8(period);
        TempSMBus_I2C_TMOUT_SDA_PRD1_REG = HI8(period);
    #endif /* (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED)  */
#endif     /* (TempSMBus_I2C_FF_TIMEOUT_ENABLED) */
}


/*******************************************************************************
* Function Name: TempSMBus_I2C_TimeoutSetPeriod
********************************************************************************
*
* Summary:
*  Returns a period of the scl and sda timeout counters.
*
* Parameters:
*  None.
*
* Return:
*  Returns a period of the scl and sda timeout.
*
*******************************************************************************/
uint16 TempSMBus_I2C_TimeoutGetPeriod(void) 
{
    uint16 period;

#if (TempSMBus_I2C_TIMEOUT_FF_ENABLED)
    period  = ((uint16) TempSMBus_I2C_TMOUT_CFG1_REG) << 8u;
    period |= TempSMBus_I2C_TMOUT_CFG0_REG;

#else
    #if (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED)
        period  = ((uint16) TempSMBus_I2C_TMOUT_SCL_PRD1_REG) << 8u;
        period |= TempSMBus_I2C_TMOUT_SCL_PRD0_REG;
    #else
        period  = ((uint16) TempSMBus_I2C_TMOUT_SDA_PRD1_REG) << 8u;
        period |= TempSMBus_I2C_TMOUT_SDA_PRD0_REG;
    #endif /* (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED) */
#endif /* (TempSMBus_I2C_FF_TIMEOUT_ENABLED) */

    return(period);
}


#if (TempSMBus_I2C_TIMEOUT_UDB_ENABLED && TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED)
    /*******************************************************************************
    * Function Name: TempSMBus_I2C_TimeoutSetPrescalerPeriod
    ********************************************************************************
    *
    * Summary:
    *  Sets a prescaler value to increase the divider possibility for the UDB
    *  timeout feature.
    *
    * Parameters:
    *  period: The prescaler period value.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void TempSMBus_I2C_TimeoutSetPrescalerPeriod(uint8 period)
                                                    
    {
    #if (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED)
        TempSMBus_I2C_SCL_PRESCALER_PRD_REG = period;
    #endif /* (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED) */

    #if (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED)
        TempSMBus_I2C_SDA_PRESCALER_PRD_REG = period;
    #endif /* (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED) */
    }


    /*******************************************************************************
    * Function Name: TempSMBus_I2C_TimeoutGetPrescalerPeriod
    ********************************************************************************
    *
    * Summary:
    *  Returns a prescaler value.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Returns a prescaler value.
    *
    *******************************************************************************/
    uint8 TempSMBus_I2C_TimeoutGetPrescalerPeriod(void)
                                                    
    {
    #if (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED)
        return (TempSMBus_I2C_SCL_PRESCALER_PRD_REG);
    #else
        return (TempSMBus_I2C_SDA_PRESCALER_PRD_REG);
    #endif /* (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED) */
    }
#endif /* (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED) */


/*******************************************************************************
* Function Name: TempSMBus_I2C_TimeoutSaveConfig
********************************************************************************
*
* Summary:
*  Saves the configuration of the timeout timer.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void TempSMBus_I2C_TimeoutSaveConfig(void) 
{
    TempSMBus_I2C_backup.tmoutCfg  = TempSMBus_I2C_TimeoutGetPeriod();
    TempSMBus_I2C_backup.tmoutIntr = TempSMBus_I2C_TimeoutGetIntrMode();
}


/*******************************************************************************
* Function Name: TempSMBus_I2C_TimeoutRestoreConfig
********************************************************************************
*
* Summary:
*  Restores the configuration of the timeout timer.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void TempSMBus_I2C_TimeoutRestoreConfig(void) 
{
    TempSMBus_I2C_TimeoutSetPeriod  (TempSMBus_I2C_backup.tmoutCfg);
    TempSMBus_I2C_TimeoutSetIntrMode(TempSMBus_I2C_backup.tmoutIntr);
}


/* [] END OF FILE */
