/*******************************************************************************
* File Name: TempSMBus_I2C_TMOUT.h
* Version 3.50
*
* Description:
*  This file provides constants and parameter values for the I2C component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_I2C_TMOUT_TempSMBus_I2C_H)
#define CY_I2C_TMOUT_TempSMBus_I2C_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h"
#include "TempSMBus_I2C.h"


/***************************************
*        Function Prototypes
***************************************/

void TempSMBus_I2C_TimeoutInit(void)                 ;
void TempSMBus_I2C_TimeoutEnable(void)               ;
void TempSMBus_I2C_TimeoutStop(void)                 ;

void TempSMBus_I2C_TimeoutReset(void)                ;

void TempSMBus_I2C_TimeoutSaveConfig(void)           ;
void TempSMBus_I2C_TimeoutRestoreConfig(void)        ;

void TempSMBus_I2C_TimeoutSetPeriod(uint16 period)   ;
uint16 TempSMBus_I2C_TimeoutGetPeriod(void)          ;

#if (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED)
    void  TempSMBus_I2C_TimeoutSetPrescalerPeriod(uint8 period)
                                                        ;
    uint8 TempSMBus_I2C_TimeoutGetPrescalerPeriod(void)
                                                        ;
#endif /* (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED) */

#if (TempSMBus_I2C_TIMEOUT_FF_ENABLED)
    #define TempSMBus_I2C_TimeoutEnableInt() \
            do{                                 \
                TempSMBus_I2C_TMOUT_CSR_REG |= (uint8)  TempSMBus_I2C_TMOUT_CSR_I2C_TMOUT_IE; \
            }while(0)

    #define TempSMBus_I2C_TimeoutDisableInt() \
            do{                                  \
                TempSMBus_I2C_TMOUT_CSR_REG &= (uint8) ~TempSMBus_I2C_TMOUT_CSR_I2C_TMOUT_IE; \
            }while(0)

    #define TempSMBus_I2C_TimeoutClearPendingInt()       CyIntClearPending(TempSMBus_I2C_ISR_NUMBER)

    #define TempSMBus_I2C_TimeoutSetIntrMode(intrSource) \
            do{                                             \
                TempSMBus_I2C_TMOUT_CSR_REG |= ((intrSource) & TempSMBus_I2C_TMOUT_CSR_INTR_MASK); \
            }while(0)

    #define TempSMBus_I2C_TimeoutGetIntrMode()           (TempSMBus_I2C_TMOUT_CSR_REG & \
                                                             TempSMBus_I2C_TMOUT_CSR_INTR_MASK)

    #define TempSMBus_I2C_TimeoutGetStatus()             (TempSMBus_I2C_TMOUT_SR_REG)
    #define TempSMBus_I2C_TimeoutClearStatus(intrStatus) {TempSMBus_I2C_TMOUT_SR_REG = (intrStatus);}

#else
    CY_ISR_PROTO(TempSMBus_I2C_TMOUT_ISR);    /* Timeout interrupt handler */

    #define TempSMBus_I2C_TimeoutEnableInt()         CyIntEnable      (TempSMBus_I2C_TMOUT_ISR_NUMBER)
    #define TempSMBus_I2C_TimeoutDisableInt()        CyIntDisable     (TempSMBus_I2C_TMOUT_ISR_NUMBER)
    #define TempSMBus_I2C_TimeoutClearPendingInt()   CyIntClearPending(TempSMBus_I2C_TMOUT_ISR_NUMBER)

    #define TempSMBus_I2C_TimeoutSetIntrMode(intrSource) \
            do{                                             \
            TempSMBus_I2C_TMOUT_INTR_MASK_REG = ((intrSource) & TempSMBus_I2C_TMOUT_STS_INTR_MASK); \
            }while(0)

    #define TempSMBus_I2C_TimeoutGetIntrMode() \
            (TempSMBus_I2C_TMOUT_INTR_MASK_REG & TempSMBus_I2C_TMOUT_STS_INTR_MASK)

    #define TempSMBus_I2C_TimeoutGetStatus() \
            (TempSMBus_I2C_TMOUT_STS_REG & TempSMBus_I2C_TMOUT_STS_INTR_MASK)

    #define TempSMBus_I2C_TimeoutClearStatus(intrStatus) /* There is no implementation for UDB version */

#endif /* (TempSMBus_I2C_TIMEOUT_FF_ENABLED) */


/***************************************
*        API constants
***************************************/


/***************************************
*              Registers
***************************************/

#if (TempSMBus_I2C_TIMEOUT_FF_ENABLED)
    /* I2C FF timeout hardware */
    #define TempSMBus_I2C_TMOUT_CSR_REG  (*(reg8 *) TempSMBus_I2C_I2C_FF__TMOUT_CSR)
    #define TempSMBus_I2C_TMOUT_CSR_PTR  ( (reg8 *) TempSMBus_I2C_I2C_FF__TMOUT_CSR)

    #define TempSMBus_I2C_TMOUT_SR_REG   (*(reg8 *) TempSMBus_I2C_I2C_FF__TMOUT_SR)
    #define TempSMBus_I2C_TMOUT_SR_PTR   ( (reg8 *) TempSMBus_I2C_I2C_FF__TMOUT_SR)

    #define TempSMBus_I2C_TMOUT_CFG0_REG (*(reg8 *) TempSMBus_I2C_I2C_FF__TMOUT_CFG0)
    #define TempSMBus_I2C_TMOUT_CFG0_PTR ( (reg8 *) TempSMBus_I2C_I2C_FF__TMOUT_CFG0)

    #define TempSMBus_I2C_TMOUT_CFG1_REG (*(reg8 *) TempSMBus_I2C_I2C_FF__TMOUT_CFG1)
    #define TempSMBus_I2C_TMOUT_CFG1_PTR ( (reg8 *) TempSMBus_I2C_I2C_FF__TMOUT_CFG1)

#else

    #define TempSMBus_I2C_TMOUT_CTRL_REG \
                        (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_SyncCtl_CtrlReg__CONTROL_REG)
    #define TempSMBus_I2C_TMOUT_CTRL_PTR \
                        ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_SyncCtl_CtrlReg__CONTROL_REG)

    #define TempSMBus_I2C_TMOUT_STS_REG          (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_StsReg__STATUS_REG)
    #define TempSMBus_I2C_TMOUT_STS_PTR          ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_StsReg__STATUS_REG)

    #define TempSMBus_I2C_TMOUT_INTR_MASK_REG    (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_StsReg__MASK_REG)
    #define TempSMBus_I2C_TMOUT_INTR_MASK_PTR    ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_StsReg__MASK_REG)

    #define TempSMBus_I2C_TMOUT_INTR_ENABLE_REG  (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_StsReg__STATUS_AUX_CTL_REG)
    #define TempSMBus_I2C_TMOUT_INTR_ENABLE_PTR  ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_StsReg__STATUS_AUX_CTL_REG)

    #if (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED)
        #define TempSMBus_I2C_TMOUT_SCL_PRD0_REG     (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_Scl_dpScl_u0__F0_REG)
        #define TempSMBus_I2C_TMOUT_SCL_PRD0_PTR     ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_Scl_dpScl_u0__F0_REG)

        #define TempSMBus_I2C_TMOUT_SCL_PRD1_REG     (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_Scl_dpScl_u0__F1_REG)
        #define TempSMBus_I2C_TMOUT_SCL_PRD1_PTR     ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_Scl_dpScl_u0__F1_REG)

        #define TempSMBus_I2C_TMOUT_SCL_ADDER_REG    (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_Scl_dpScl_u0__D0_REG)
        #define TempSMBus_I2C_TMOUT_SCL_ADDER_PTR    ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_Scl_dpScl_u0__D0_REG)

        #define TempSMBus_I2C_TMOUT_SCL_AUX_CTRL_REG \
                                                (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_Scl_dpScl_u0__DP_AUX_CTL_REG)
        #define TempSMBus_I2C_TMOUT_SCL_AUX_CTRL_PTR \
                                                ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_Scl_dpScl_u0__DP_AUX_CTL_REG)

        #if (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED)
            #define TempSMBus_I2C_SCL_PRESCALER_AUX_CTRL_REG \
                                    (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_SclPrescaler_prScl__CONTROL_AUX_CTL_REG)
            #define TempSMBus_I2C_SCL_PRESCALER_AUX_CTRL_PTR \
                                    ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_SclPrescaler_prScl__CONTROL_AUX_CTL_REG)

            #define TempSMBus_I2C_SCL_PRESCALER_PRD_REG  \
                                    (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_SclPrescaler_prScl__PERIOD_REG)
            #define TempSMBus_I2C_SCL_PRESCALER_PRD_PTR  \
                                    ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_SclPrescaler_prScl__PERIOD_REG)

        #endif /* (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED) */
    #endif     /* (TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLED) */

    #if (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED)
        #define TempSMBus_I2C_TMOUT_SDA_PRD0_REG     (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_Sda_dpSda_u0__F0_REG)
        #define TempSMBus_I2C_TMOUT_SDA_PRD0_PTR     ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_Sda_dpSda_u0__F0_REG)

        #define TempSMBus_I2C_TMOUT_SDA_PRD1_REG     (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_Sda_dpSda_u0__F1_REG)
        #define TempSMBus_I2C_TMOUT_SDA_PRD1_PTR     ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_Sda_dpSda_u0__F1_REG)

        #define TempSMBus_I2C_TMOUT_SDA_ADDER_REG    (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_Sda_dpSda_u0__D0_REG)
        #define TempSMBus_I2C_TMOUT_SDA_ADDER_PTR    ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_Sda_dpSda_u0__D0_REG)

        #define TempSMBus_I2C_TMOUT_SDA_AUX_CTRL_REG \
                                                (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_Sda_dpSda_u0__DP_AUX_CTL_REG)
        #define TempSMBus_I2C_TMOUT_SDA_AUX_CTRL_PTR \
                                                ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_Sda_dpSda_u0__DP_AUX_CTL_REG)

        #if (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED)
            #define TempSMBus_I2C_SDA_PRESCALER_AUX_CTRL_REG \
                                    (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_SdaPrescaler_prSda__CONTROL_AUX_CTL_REG)
            #define TempSMBus_I2C_SDA_PRESCALER_AUX_CTRL_PTR \
                                    ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_SdaPrescaler_prSda__CONTROL_AUX_CTL_REG)

            #define TempSMBus_I2C_SDA_PRESCALER_PRD_REG \
                                    (*(reg8 *) TempSMBus_I2C_bTimeoutTimer_SdaPrescaler_prSda__PERIOD_REG)
            #define TempSMBus_I2C_SDA_PRESCALER_PRD_PTR \
                                    ( (reg8 *) TempSMBus_I2C_bTimeoutTimer_SdaPrescaler_prSda__PERIOD_REG)

        #endif /* (TempSMBus_I2C_TIMEOUT_PRESCALER_ENABLED) */
    #endif /* (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLED) */

#endif /*(TempSMBus_I2C_TIMEOUT_FF_ENABLED) */


/***************************************
*        Registers Constants
***************************************/

#if (TempSMBus_I2C_TIMEOUT_FF_ENABLED)
    /* TempSMBus_I2C_TMOUT_CSR */
    #define TempSMBus_I2C_TMOUT_CSR_SDA_PIN_POS      (4u)
    #define TempSMBus_I2C_TMOUT_CSR_SCL_PIN_POS      (3u)
    #define TempSMBus_I2C_TMOUT_CSR_I2C_TMOUT_IE_POS (2u)
    #define TempSMBus_I2C_TMOUT_CSR_SDA_TMOUT_IE_POS (1u)
    #define TempSMBus_I2C_TMOUT_CSR_SCL_TMOUT_IE_POS (0u)
    #define TempSMBus_I2C_TMOUT_CSR_SDA_PIN_STS  ((uint8) (0x01u << TempSMBus_I2C_TMOUT_CSR_SDA_PIN_POS))
    #define TempSMBus_I2C_TMOUT_CSR_SCL_PIN_STS  ((uint8) (0x01u << TempSMBus_I2C_TMOUT_CSR_SCL_PIN_POS))
    #define TempSMBus_I2C_TMOUT_CSR_I2C_TMOUT_IE ((uint8) (0x01u << TempSMBus_I2C_TMOUT_CSR_I2C_TMOUT_IE_POS))
    #define TempSMBus_I2C_TMOUT_CSR_SDA_TMOUT_IE ((uint8) (0x01u << TempSMBus_I2C_TMOUT_CSR_SDA_TMOUT_IE_POS))
    #define TempSMBus_I2C_TMOUT_CSR_SCL_TMOUT_IE ((uint8) (0x01u << TempSMBus_I2C_TMOUT_CSR_SCL_TMOUT_IE_POS))
    #define TempSMBus_I2C_TMOUT_CSR_INTR_MASK    ((uint8) (0x03u << TempSMBus_I2C_TMOUT_CSR_SCL_TMOUT_IE_POS))

    /* TempSMBus_I2C_TMOUT_SR */
    #define TempSMBus_I2C_TMOUT_SR_SDA_PIN_TMOUT_POS (1u)
    #define TempSMBus_I2C_TMOUT_SR_SCL_PIN_TMOUT_POS (0u)
    #define TempSMBus_I2C_TMOUT_SR_SDA_PIN_TMOUT ((uint8) (0x01u << TempSMBus_I2C_TMOUT_SR_SDA_PIN_TMOUT_STS_POS))
    #define TempSMBus_I2C_TMOUT_SR_SCL_PIN_TMOUT ((uint8) (0x01u << TempSMBus_I2C_TMOUT_SR_SCL_PIN_TMOUT_STS_POS))
    #define TempSMBus_I2C_TMOUT_SR_PINS_TMOUT_MASK   ((uint8) (0x03u << TempSMBus_I2C_TMOUT_SR_SCL_PIN_TMOUT_POS))

    /*TempSMBus_I2C_TMOUT_CFG0 and TempSMBus_I2C_TMOUT_CFG1 */
    #define TempSMBus_I2C_TMOUT_CFG0__MASK   (0xFFu)
    #define TempSMBus_I2C_TMOUT_CFG1__MASK   (0x0Fu)

#else

    /* Interrupt setup */
    #define TempSMBus_I2C_TMOUT_ISR_NUMBER   ((uint8) TempSMBus_I2C_I2C_TMOUT__INTC_NUMBER)
    #define TempSMBus_I2C_TMOUT_ISR_PRIORITY ((uint8) TempSMBus_I2C_I2C_TMOUT__INTC_PRIOR_NUM)

    /* Timeout STATUS register constants */
    #define TempSMBus_I2C_TMOUT_CTRL_ENABLE_POS  (0u)
    #define TempSMBus_I2C_TMOUT_CTRL_ENABLE      ((uint8) (0x01u << TempSMBus_I2C_TMOUT_CTRL_ENABLE_POS))

    /* Timeout STATUS register constants */
    #define TempSMBus_I2C_TMOUT_STS_SDA_PIN_POS  (3u)
    #define TempSMBus_I2C_TMOUT_STS_SCL_PIN_POS  (4u)
    #define TempSMBus_I2C_TMOUT_STS_SDA_INTR_POS (1u)
    #define TempSMBus_I2C_TMOUT_STS_SCL_INTR_POS (0u)
    #define TempSMBus_I2C_TMOUT_STS_SCL_PINS     ((uint8) (0x01u << TempSMBus_I2C_TMOUT_STS_SDA_PIN_POS))
    #define TempSMBus_I2C_TMOUT_STS_SDA_PIN      ((uint8) (0x01u << TempSMBus_I2C_TMOUT_STS_SCL_PIN_POS))
    #define TempSMBus_I2C_TMOUT_STS_SCL_INTR     ((uint8) (0x01u << TempSMBus_I2C_TMOUT_STS_SDA_INTR_POS))
    #define TempSMBus_I2C_TMOUT_STS_SDA_INTR     ((uint8) (0x01u << TempSMBus_I2C_TMOUT_STS_SCL_INTR_POS))
    #define TempSMBus_I2C_TMOUT_STS_INTR_MASK    ((uint8) (0x03u << TempSMBus_I2C_TMOUT_STS_SCL_INTR_POS))

    /* AUX_CTL bits definition */
    #define TempSMBus_I2C_TMOUT_FIFO_SINGLE_REG      (0x03u) /* Makes f0 and f1 as single reg */
    #define TempSMBus_I2C_TMOUT_PRESCALER_CNT7_EN    (0x20u) /* Enable 7-bit counter */
    #define TempSMBus_I2C_TMOUT_ENABLE_INTR          (0x10u) /* Enable interrupt from status register */

#endif /* (TempSMBus_I2C_TIMEOUT_FF_ENABLED) */


/***************************************
*        Marco
***************************************/

#if (TempSMBus_I2C_TIMEOUT_FF_ENABLED)
    /* Returns true if timeout functionality is enabled */
    #define TempSMBus_I2C_IS_TIMEOUT_ENABLED (0u != (TempSMBus_I2C_TMOUT_CSR_REG & \
                                                        TempSMBus_I2C_TMOUT_CSR_I2C_TMOUT_IE))

#else
    /* Returns true if timeout functionality is enabled */
    #define TempSMBus_I2C_IS_TIMEOUT_ENABLED (0u != (TempSMBus_I2C_TMOUT_CTRL_ENABLE & \
                                                        TempSMBus_I2C_TMOUT_CTRL_REG))
#endif /* (TempSMBus_I2C_TIMEOUT_FF_ENABLED) */


/***************************************
*     Default register init constants
***************************************/

#define TempSMBus_I2C_DEFAULT_TMOUT_PERIOD   ((TempSMBus_I2C_TIMEOUT_FF_ENABLED) ? \
                                                    ((uint16) 1563u) : ((uint16) 39062u))
#define TempSMBus_I2C_DEFAULT_TMOUT_PRESCALER_PRD    (0u)
#define TempSMBus_I2C_DEFAULT_TMOUT_INTR_MASK        ((uint8) (TempSMBus_I2C_TIMEOUT_SDA_TMOUT_ENABLE << 1u) | \
                                                                  TempSMBus_I2C_TIMEOUT_SCL_TMOUT_ENABLE)
#define TempSMBus_I2C_DEFAULT_TMOUT_ADDER    (0xFFu)

#endif /* (CY_I2C_TMOUT_TempSMBus_I2C_H) */


/* [] END OF FILE */
