/*******************************************************************************
* File Name: .h
* Version 5.20
*
* Description:
*  This file provides private constants and parameter values for the SM/PM Bus
*  Slave component.
*
* Note:
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SMBusSlave_PVT_TempSMBus_H)
#define CY_SMBusSlave_PVT_TempSMBus_H

#include "TempSMBus.h"
#include "TempSMBus_cmd.h"
#include "TempSMBus_I2C_TMOUT.h"


/***************************************
*         API Constants
***************************************/

#define TempSMBus_TRANS_QUEUE_SIZE           (1u)
#define TempSMBus_MAX_BUFFER_SIZE            (65u)
#define TempSMBus_CRC8_LUT_SIZE              (256u)

/***************************************
*       Global variables
***************************************/
    
/* I2C Buffer */
extern uint8 TempSMBus_buffer[TempSMBus_MAX_BUFFER_SIZE];
extern uint8 TempSMBus_bufferIndex;
extern uint8 TempSMBus_bufferSize;

extern volatile uint8 TempSMBus_I2C_state;

/* I2C Software Address */
#if (TempSMBus_SW_ADDR_DECODE)
    extern uint8 TempSMBus_address;
#endif  /* (TempSMBus_I2C_SW_ADRR_DECODE) */

/* Number of active manual transaction records in Transaction Queue */
extern volatile uint8 TempSMBus_trActiveCount;

/* Transaction Queue */
extern TempSMBus_TRANSACTION_STRUCT TempSMBus_transactionData[TempSMBus_TRANS_QUEUE_SIZE];

/* SMB Alert mode and Alert Response */
#if (TempSMBus_SMBALERT_PIN_EXISTS)
    extern uint8 TempSMBus_smbAlertMode;
    extern uint8 TempSMBus_alertResponseAddress;
#endif /* TempSMBus_SMBALERT_PIN_EXISTS */

#if (defined(TempSMBus_BTLDR_READ_EN) || defined(TempSMBus_BTLDR_WRITE_EN))
    extern uint8 TempSMBus_btldrStatus;
#endif /* defined(TempSMBus_BTLDR_READ_EN) || defined(TempSMBus_BTLDR_WRITE_EN) */

#ifdef TempSMBus_BTLDR_READ_EN
    extern uint8 TempSMBus_btldrReadBuf[TempSMBus_MAX_BUFFER_SIZE];
#endif /* TempSMBus_BTLDR_READ_EN */

#ifdef TempSMBus_BTLDR_WRITE_EN
    extern uint8 TempSMBus_btldrWriteBuf[TempSMBus_MAX_BUFFER_SIZE];
#endif /* TempSMBus_BTLDR_WRITE_EN */

/* Pre-computed CRC-8 data */
#if (TempSMBus_SUPPORT_PEC)
    extern const uint8 CYCODE TempSMBus_crc_table[TempSMBus_CRC8_LUT_SIZE];
#endif /* TempSMBus_SUPPORT_PEC */


/***************************************
*           Local Macros
***************************************/

#define TempSMBus_ISR_NUMBER                 (TempSMBus_I2C_ISR_NUMBER)

#if(CY_PSOC4)
    #define TempSMBus_TMOUT_ISR_NUMBER       (TempSMBus_TMOUT_INT__INTC_NUMBER)
    #define TempSMBus_TMOUT_ISR_PRIORITY     (TempSMBus_TMOUT_INT__INTC_PRIOR_NUM)
    
    /* Enables timeout hardware and interrupt */
    #define TempSMBus_Timeout_Enable()    \
        do{ \
            TempSMBus_I2C_TMOUT_Enable(); \
            CyIntEnable(TempSMBus_TMOUT_ISR_NUMBER); \
        }while(0)

    /* Initializes timeout hardware and interrupt */
    #define TempSMBus_Timeout_Init() \
        do{ \
            TempSMBus_I2C_TMOUT_Init(); \
            CyIntDisable(TempSMBus_TMOUT_ISR_NUMBER); \
            CyIntSetPriority(TempSMBus_TMOUT_ISR_NUMBER, TempSMBus_TMOUT_ISR_PRIORITY); \
        }while(0)
    
    /* Disables timeout hardware and interrupt */
    #define TempSMBus_Timeout_Stop() \
        do{ \
            TempSMBus_I2C_TMOUT_Stop(); \
            CyIntDisable(TempSMBus_TMOUT_ISR_NUMBER); \
            CyIntClearPending(TempSMBus_TMOUT_ISR_NUMBER); \
        }while(0)

    #define TempSMBus_EnableGeneralCallAddress() \
        (TempSMBus_I2C_I2C_CTRL_REG &= (uint32)~TempSMBus_I2C_I2C_CTRL_S_GENERAL_IGNORE)
        
    #define TempSMBus_I2C_SM_SL_RD_DATA      (TempSMBus_I2C_I2C_FSM_SL_RD)
#else
    #define TempSMBus_TMOUT_ISR_NUMBER       (TempSMBus_I2C_TMOUT_ISR_NUMBER)
#endif /* CY_PSOC4 */


/* Format conversion macro helpers */
#define TempSMBus_LIN11_TO_EXP(val)              ((uint8) ((val) >> 11u))
#define TempSMBus_LIN11_TO_MAN(val)              ((uint16)((val) & 0x07FFu))
#define TempSMBus_EXP_TO_LIN11(val)              ((uint16)((uint16)(val) << 11u))
#define TempSMBus_MAN_TO_LIN11(val)              ((uint16)((val) & 0x07FFu))
#define TempSMBus_EXP_LIN11_MASK                 (0x1Fu)
#define TempSMBus_LIN11_TO_EXP_SIGN(val)         ((((val) & 0x10u) != 0u) ? 1u : 0u)
#define TempSMBus_LIN11_TO_MAN_SIGN(val)         ((((val) & 0x0400u) != 0u) ? 1u : 0u)
#define TempSMBus_11BIT_2S_COMPLEMENT(val)       (((val) ^ 0x07FFu) + 1u)
#define TempSMBus_5BIT_2S_COMPLEMENT(val)        (((val) ^ 0x1Fu) + 1u)
#define TempSMBus_FLOAT_10MSB_MAN(val)           ((uint16)(((val) >> 14u) & 0x03FFu) | 0x0200u)
#define TempSMBus_FLOAT_16MSB_MAN(val)           ((uint16)((val) >> 8u) | 0x8000u)
#define TempSMBus_FLOAT_EXP(val)                 ((uint8)((val) >> 23u))
#define TempSMBus_MAX_5BIT_EXP                   (16u)
#define TempSMBus_MAX_POWER                      (65536.0f)
#define TempSMBus_IEEE754_IMPLICIT_MAGNITUDE     (127)
#define TempSMBus_LIN11_EXP_SCALING_FACTOR       (9)
#define TempSMBus_LIN16_EXP_SCALING_FACTOR       (15)
#define TempSMBus_LIN16_MAN_MAX_VAL              (0xFFFFu)
#define TempSMBus_SIGN_EXTEND(val)               ((((val) & 0x10u) != 0u) ? ((val) | 0xE0u) : (val))

/* The following defines are obsolete and are no longer recommended for use */
#define TempSMBus_ERR_RD_TO_MANY_BYTES          TempSMBus_ERR_RD_TOO_MANY_BYTES
#define TempSMBus_ERR_WR_TO_MANY_BYTES          TempSMBus_ERR_WR_TOO_MANY_BYTES
#define TempSMBus_ERR_WR_TO_FEW_BYTES           TempSMBus_ERR_WR_TOO_FEW_BYTES
#define TempSMBus_FIRMWARE_MODE                 TempSMBus_MANUAL_MODE

#endif /* CY_SMBusSlave_PVT_TempSMBus_H */


/* [] END OF FILE */
