/*******************************************************************************
* File Name: TempSMBus_cmd.h
* Version 5.20
*
* Description:
*  This file provides constants and parameter values and API definition related
*  to the SM/PMBus command processing.
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_SMBusSlave_TempSMBus_cmd_H)
#define CY_SMBusSlave_TempSMBus_cmd_H

/*`#START ADDITIONAL_SMBUS_SLAVE_CMD_H_INCLUDE`*/

/*`#END`*/


/***************************************
*   Conditional Compilation Parameters
***************************************/

/* Command list based on customizer settings */


/* Check if the component is bootloader component or project type is loadable */
#if((defined(CYDEV_BOOTLOADER_IO_COMP) && (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface)) || \
    (CYDEV_PROJ_TYPE == CYDEV_PROJ_TYPE_LOADABLE))
    
    /* Check if bootloader commands are enabled */
    #ifdef TempSMBus_BOOTLOAD_READ
        #define TempSMBus_BTLDR_READ_EN  (1u)
    #endif /* TempSMBus_BOOTLOAD_READ */
    #ifdef TempSMBus_BOOTLOAD_WRITE
        #define TempSMBus_BTLDR_WRITE_EN (1u)
    #endif /* TempSMBus_BOOTLOAD_WRITE */

#endif /* (defined(CYDEV_BOOTLOADER_IO_COMP) && (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface)) ||
    (CYDEV_PROJ_TYPE == CYDEV_PROJ_TYPE_LOADABLE) */


/***************************************
*      Data Struct Definitions
***************************************/

#if (CY_PSOC3)
    typedef struct
#elif defined (__GNUC__)
    typedef struct __attribute__ ((packed))
#else
    typedef __packed struct
#endif /* (__GNUC__) */
{
    uint8   command;
    uint8   dataLength;
    uint8 * dataPtr;
    uint8   cmdProp;               /* command properties (read/write/page-indexed) */
} TempSMBus_CMD_TABLE_ENTRY;


/***************************************
*        Function Prototypes
***************************************/

uint8 TempSMBus_CheckCommand(uint8 command)    ;
uint8 TempSMBus_ReadHandler(void)              ;
void  TempSMBus_WriteHandler(void)             ;
void  TempSMBus_CompleteRead(void)             ;

/* Bootloader Specific APIs */
#if(defined(TempSMBus_BTLDR_READ_EN) || defined(TempSMBus_BTLDR_WRITE_EN))
    void     TempSMBus_CyBtldrCommStart(void) CYSMALL ;
    void     TempSMBus_CyBtldrCommStop(void) CYSMALL ;
    void     TempSMBus_CyBtldrCommReset(void) CYSMALL ;
#endif /* defined(TempSMBus_BTLDR_READ_EN) || defined(TempSMBus_BTLDR_WRITE_EN) */

#ifdef TempSMBus_BTLDR_READ_EN
    cystatus TempSMBus_CyBtldrCommWrite(const uint8 * pData, uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
#endif /* TempSMBus_BTLDR_READ_EN */

#ifdef TempSMBus_BTLDR_WRITE_EN
    cystatus TempSMBus_CyBtldrCommRead(uint8 * pData, uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
#endif /* TempSMBus_BTLDR_WRITE_EN */


/***************************************
*           API Constants
***************************************/

/* Command properties */
#define TempSMBus_CMD_WR_SUPPORT                 (0x40u)
#define TempSMBus_CMD_WR_MANUAL                  (0x40u)
#define TempSMBus_CMD_WR_AUTO                    (0x02u)
#define TempSMBus_CMD_RD_SUPPORT                 (0x20u)
#define TempSMBus_CMD_RD_MANUAL                  (0x20u)
#define TempSMBus_CMD_RD_AUTO                    (0x01u)
#define TempSMBus_CMD_PAGED                      (0x80u)
#define TempSMBus_CMD_FMT_MASK                   (0x1Cu)
#define TempSMBus_CMD_FMT_NON_NUMERIC            (0x1Cu)
#define TempSMBus_CMD_FMT_LINEAR                 (0x00u)
#define TempSMBus_CMD_FMT_SIGNED                 (0x04u)
#define TempSMBus_CMD_FMT_DIRECT                 (0x0Cu)
#define TempSMBus_CMD_FMT_UNSIGNED               (0x10u)
#define TempSMBus_CMD_FMT_VID_MODE               (0x14u)
#define TempSMBus_CMD_FMT_MANUFACTURER           (0x18u)
#define TempSMBus_CMD_SUPPORTED                  (0x80u)

/* Command types and flags */
#define TempSMBus_CMD_VALID                      (0x00u)
#define TempSMBus_CMD_READ                       (0x01u)
#define TempSMBus_CMD_WRITE                      (0x00u)
#define TempSMBus_CMD_UNDEFINED                  (0xFFu)
#define TempSMBus_NON_BLOCK_CMD                  (0x00u)
#define TempSMBus_BLOCK_CMD                      (0x01u)

/* "All Pages" wild card */
#define TempSMBus_CMD_ALL_PAGES                  (0xFFu)
#define TempSMBus_SUPPORT_PAGE_CMD               (0u)

/* Bootloader status */
#define TempSMBus_BTLDR_WR_CMPT                  (0x10u)
#define TempSMBus_BTLDR_RD_CMPT                  (0x01u)

/* Helpers to check if a command size is valid. Greater or equal is used to take
* into account the PEC byte. For example, when the PEC is enabled and a host
* writes to a word command, the correct index value is 2 if the host does not
* send PEC, and 3 if it does. The index value greater than 3 results in a Host
* Sends Too Many Bytes fault and is detected in the ISR.
*/
#define TempSMBus_CMD_LEN_VALID                  (TempSMBus_bufferIndex >= TempSMBus_bufferSize)

/* Byte and word commands have fixed number of bytes */ 
#define TempSMBus_BYTE_CMD_LEN_VALID             (TempSMBus_bufferIndex >= 1u)
#define TempSMBus_WORD_CMD_LEN_VALID             (TempSMBus_bufferIndex >= 2u)

#endif /* !defined(CY_SMBusSlave_TempSMBus_cmd_H) */


/* [] END OF FILE */
