/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/


#define BIT_SET(v,m)    ( (v) |= (m)) )
#define BIT_CLEAR(v,m)  ( (v) &= ~(m) )
#define BIT_TOGGLE(v,m) ( (v) ^= (m)  )
#define BIT_READ(v,m)   ( (v) & (1<<m)) >> m

#define RESET_OFF   1
#define RESET_ON    0

#define DISABLE     0
#define ENABLE      1

#define SET_LO     0
#define SET_HI      1

#define LED_WRITE_CMD 0
#define LED_READ_CMD  0x8000


#define RESET_DSP_CMD 1


#define Wait(x)					      // Just for readability

// XRA1403 IO Expander SPI registers, page 5 in datasheet
#define GPIOSTATE1  (0x00)     // read only, states of p0-p7
#define GPIOSTATE2  (0x01)     // read only, states of p8-p15
#define OUTPUTCTRL1 (0x02)     // read/write, output control of p0-p7
#define OUTPUTCTRL2 (0x03)    // read/write, output control of p8-p15
#define POLARITY1   (0x04)    // read/write, input polarity: inversion for p0-p7
#define POLARITY2   (0x05)    // read/write, input polarity: inversion for p8-p15
#define GPIOCONF1   (0x06)    // read/write, GPIO config for p0-p7
#define GPIOCONF2   (0x07)    // read/write, GPIO config for p8-p15
#define PULLUP1     (0x08)    // read/write, enable/disable pullups on p0-p7
#define PULLUP2     (0x09)    // read/write, enable/disable pullups on p8-p15
#define IER1        (0x0A)    // read/write, input interrupt enable p0-p7
#define IER2        (0x0B)    // read/write, input interrupt enable p8-p15
#define TSCR1       (0x0C)    // read/write, output three state control for p0-p7
#define TSCR2       (0x0D)    // read/write, output three state control for p8-p15
#define ISR1        (0x0E)    // read, input interrupt status for p0-p7
#define ISR2        (0x0F)    // read, input interrupt status for p8-p15
#define REIR1       (0x10)    // read/write input rising edge interrupt enable for p0-p7
#define REIR2       (0x11)    // read/write input rising edge interrupt enable for p8-p15
#define FEIR1       (0x12)    // read/write input falling edge interrupt enable for p0-p7
#define FEIR2       (0x13)    // read/write input falling edge interrupt enable for p8-p15
#define IFR1        (0x14)    // read/write input filter enable/disable p0-p7
#define IFR2        (0x15)    // read/write input filter enable/disable p8-p15




#define ALL_LED_OFF   0xFF
#define ALL_LED_ON   0x0
#define TURNON_RUN_MODE 1


#define TEMPI2C_RDBUFFSIZE  8


// MAX6581 REGISTERS
/* I2C slave address to communicate with */
#define TEMP_I2C_SLAVE_ADDR  (0x9Eu)


#define REMOTE1       0x01
#define REMOTE2       0x02
#define REMOTE3       0x03
#define REMOTE4       0x04
#define REMOTE5       0x05
#define REMOTE6       0x06
#define LOCAL         0x07
#define REMOTE7       0x08
#define REMOTE1EXT    0x09
#define MANUF_ID      0x0A
#define REV_IF        0x0F
#define REMOTE1_ALERT 0x11
#define REMOTE2_ALERT 0x12
#define REMOTE3_ALERT 0x13
#define REMOTE4_ALERT 0x14
#define REMOTE5_ALERT 0x15
#define REMOTE6_ALERT 0x16
#define LOCAL_ALERT   0x17
#define REMOTE7_ALERT 0x18
#define LOCAL_OVERT   0x20
#define REMOTE1_OVERT 0x21
#define REMOTE2_OVERT 0x22
#define REMOTE3_OVERT 0x23
#define REMOTE4_OVERT 0x24
#define REMOTE5_OVERT 0x25
#define REMOTE6_OVERT 0x26
#define REMOTE7_OVERT 0x27
#define ALERT_LOWLIM_ALL 0x30   // read/write all channel alert low-tmep threshold limit
#define CONFIG           0x41   // read/write configuration
#define ALERT_MASK       0x42   // read/write alert mask
#define OVERT_MASK       0x43
#define ALERT_HI_MASK    0x44
#define OVERT_STATUS     0x45  
#define DIODE_FAULT_STATUS 0x46
#define ALERT_LOW_STATUS   0x47
#define ALERT_LOW_DISABLE  0x48
#define RESISTANCE_CANCEL  0x4A
#define TRANS_IDEALITY     0x4B
#define IDEALITY_SELECT    0x4C
#define OFFSET             0x4D
#define OFFSET_SELECT      0x4E
#define REMOTE1_EXTBITS    0x51 // Read Channel 1 remote extended temp
#define REMOTE2_EXTBITS    0x52 // Read Channel 2 remote extended temp
#define REMOTE3_EXTBITS    0x53 // Read Channel 3 remote extended temp
#define REMOTE4_EXTBITS    0x54 // Read Channel 4 remote extended temp
#define REMOTE5_EXTBITS    0x55 // Read Channel 5 remote extended temp
#define REMOTE6_EXTBITS    0x56 // Read Channel 6 remote extended temp
#define LOCAL_EXTBITS      0x57 // Read Local Channel remote extended temp
#define REMOTE7_EXTBITS    0x58 // Read Channel 7 remote extended temp

//____________________________
#define BUFFER_SIZE     (3u)
#define PACKET_SIZE     (BUFFER_SIZE)

/* Packet positions */
#define PACKET_SOP_POS  (0u)
#define PACKET_CMD_POS  (1u)
#define PACKET_STS_POS  (PACKET_CMD_POS)
#define PACKET_EOP_POS  (2u)

/* Start and end of packet markers */
#define PACKET_SOP      (0x01u)
#define PACKET_EOP      (0x17u)

/* Command valid status */
#define STS_CMD_DONE    (0x00u)
#define STS_CMD_FAIL    (0xFFu)

/* Command valid status */
#define TRANSFER_CMPLT    (0x00u)
#define TRANSFER_ERROR    (0xFFu)

/* Commands set */
#define CMD_SET_OFF     (0u)
#define CMD_SET_RED     (1u)
#define CMD_SET_GREEN   (2u)
#define CMD_SET_BLUE    (3u)